'use strict';

var index = require('./index-CVtxT0q5.js');

const intentConfig = {
    solid: 'solid'};
const iconStyleConfig = {
    filled: 'filled',
    outline: 'outline',
};
const variantConfig = {
    info: 'info'};
const styleConfig = {
    info: {
        icon: 'Error Circle',
        subtle: {
            iconColor: 'var(--sfe-color-icon-info-secondary)',
        },
    },
    error: {
        icon: 'Warning',
        subtle: {
            iconColor: 'var(--sfe-color-icon-critical-secondary)',
        },
    },
    success: {
        icon: 'Checkmark Circle',
        subtle: {
            iconColor: 'var(--sfe-color-icon-positive-secondary)',
        },
    },
    warning: {
        icon: 'Error Circle',
        subtle: {
            iconColor: 'var(--sfe-color-icon-warning-secondary)',
        },
    },
};
const positionConfig = {
    top: 'top'};

const swcAlertCss = ".sc-swc-alert-h{display:block}.sfe-alert.sc-swc-alert{display:flex;position:fixed;z-index:var(--sfe-stack-level-alert);justify-content:space-between;width:100%;border-radius:var(--sfe-sizing-radius-xsmall);padding:var(--sfe-sizing-padding-mid)}.sfe-alert.top.sc-swc-alert{top:0;left:0}.sfe-alert.bottom.sc-swc-alert{bottom:0;left:0}.sfe-alert__icon-group.sc-swc-alert{position:relative;cursor:pointer}.sfe-alert__icon-group.sc-swc-alert:hover::after{content:\"\";position:absolute;inset:0;border-radius:var(--sfe-sizing-radius-default, 8px);background-color:transparent;z-index:0}.sfe-alert.solid.sc-swc-alert{color:var(--sfe-color-text-default-inverted-primary)}.sfe-alert.solid.info.sc-swc-alert{background-color:var(--sfe-color-fill-info-solid)}.sfe-alert.solid.error.sc-swc-alert{background-color:var(--sfe-color-fill-critical-solid)}.sfe-alert.solid.success.sc-swc-alert{background-color:var(--sfe-color-fill-positive-solid)}.sfe-alert.solid.warning.sc-swc-alert{background-color:var(--sfe-color-fill-warning-solid)}.sfe-alert.subtle.sc-swc-alert{color:var(--sfe-color-text-default-primary)}.sfe-alert.subtle.info.sc-swc-alert{background-color:var(--sfe-color-fill-info-lightest);border-top:2px solid var(--sfe-color-border-info-solid)}.sfe-alert.subtle.error.sc-swc-alert{background-color:var(--sfe-color-fill-critical-lightest);border-top:2px solid var(--sfe-color-border-critical-solid)}.sfe-alert.subtle.success.sc-swc-alert{background-color:var(--sfe-color-fill-positive-lightest);border-top:2px solid var(--sfe-color-border-positive-solid)}.sfe-alert.subtle.warning.sc-swc-alert{background-color:var(--sfe-color-fill-warning-lightest);border-top:2px solid var(--sfe-color-border-warning-solid)}.sfe-alert__display-text.sc-swc-alert{margin:0;margin-left:4px;font-size:14px;font-weight:400}.sfe-alert__message-group.sc-swc-alert{display:flex;align-items:center}.shr-alert-enter-active.sc-swc-alert-h,.shr-alert-leave-active.sc-swc-alert-h{transition:opacity 0.5s ease}.shr-alert-enter.sc-swc-alert-h,.shr-alert-leave-to.sc-swc-alert-h{opacity:0}";

const SwcAlert = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.alertDismissed = index.createEvent(this, "alertDismissed");
    }
    get hostElement() { return index.getElement(this); }
    /** Display message */
    message = 'Display the message here';
    /** Intent: solid | subtle */
    intent = intentConfig.solid;
    /** Variant: info | error | success | warning */
    variant = variantConfig.info;
    /** Position: top | bottom */
    position = positionConfig.top;
    isVisible = false;
    /** Aria label for dismiss button */
    iconButtonAriaLabel = 'Dismiss alert';
    alertDismissed;
    alertIcon = {};
    dismissIconColor = this.computeDismissIconColor();
    handlePropChange() {
        this.alertIcon = this.computeAlertIcon();
        this.dismissIconColor = this.computeDismissIconColor();
    }
    async show() {
        this.isVisible = true;
        return Promise.resolve();
    }
    async hide() {
        this.isVisible = false;
        this.alertDismissed.emit();
        return Promise.resolve();
    }
    computeAlertIcon() {
        const iconColor = this.intent === intentConfig.solid
            ? 'var(--sfe-color-icon-default-inverted-secondary)'
            : styleConfig[this.variant][this.intent].iconColor;
        const alertIconVariant = this.intent === intentConfig.solid ? iconStyleConfig.outline : iconStyleConfig.filled;
        return {
            name: styleConfig[this.variant].icon,
            color: iconColor,
            variant: alertIconVariant,
        };
    }
    computeDismissIconColor() {
        return this.intent === intentConfig.solid
            ? 'var(--sfe-color-icon-default-inverted-secondary)'
            : 'var(--sfe-color-icon-default-primary)';
    }
    dismissAlert = () => this.hide();
    componentWillLoad() {
        this.handlePropChange();
    }
    render() {
        return (index.h(index.Host, { key: 'd4c66e0f5f7ace4245a8cb2afafe96f543387a4e' }, this.isVisible && (index.h("div", { key: '0c5afa3f1c7852945afcef9d6f495a80afeebb01', role: "alert", class: `sfe-alert ${this.variant} ${this.intent} ${this.position}`, "aria-labelledby": "sfe-alert__display-text-id", "data-testid": "sfe-alert" }, index.h("div", { key: '00b21e2aacb9ccb9f4d495b6059500a05fc0eed0', class: "sfe-alert__message-group" }, index.h("swc-svg-icon", { key: 'fb9b98dfa885c696fb432425eba82f7a0165da94', name: this.alertIcon?.name, variant: 'filled', size: "16", color: this.alertIcon?.color }), index.h("p", { key: '5228494894b3ad36e85870f4f80014f71a7d8672', class: "sfe-alert__display-text", id: "sfe-alert__display-text-id" }, this.message)), index.h("div", { key: '2bcf4c71fb105827ddc57a58923c20fe435dda88', class: "sfe-alert__icon-group", onClick: this.dismissAlert }, index.h("swc-button", { key: '75173cd5874cbd08eb805f53b226886a4c582266', intent: "neutral", variant: "bare", "aria-label": this.iconButtonAriaLabel }, index.h("swc-svg-icon", { key: 'e0ca75873e8911c80eb54894920b1df22015cd90', name: "Dismiss", variant: "filled", size: "16", color: this.dismissIconColor })))))));
    }
};
SwcAlert.style = swcAlertCss;

exports.swc_alert = SwcAlert;
//# sourceMappingURL=swc-alert.entry.cjs.js.map

//# sourceMappingURL=swc-alert.cjs.entry.js.map