'use strict';

var index = require('./index-CVtxT0q5.js');
var utils = require('./utils-B_y0COLv.js');

const fileColorVariants = {
    jpg: 'var(--sfe-color-non-semantic-content-violet-subtle, #4E38BC)'};
// Method: Format file details
const fileDetailsFormat = (_files) => {
    if (_files && _files.length > 0) {
        return _files.map((file, index) => {
            const fileName = file.name;
            const nameWithoutExt = fileName.substring(0, fileName.lastIndexOf('.')) || fileName;
            const sizeInMb = (file.size / 1024 / 1024).toFixed(2); // Size in MB
            return {
                id: index,
                name: nameWithoutExt,
                size: `${sizeInMb} MB`,
            };
        });
    }
    return [];
};
// Method: Check if an object is empty
const isEmptyObject = (obj) => {
    return Object.keys(obj).length === 0 && obj.constructor === Object;
};

const swcMultipleFileCss = ".sc-swc-multiple-file-h .me-2.sc-swc-multiple-file{margin-right:8px}.sc-swc-multiple-file-h .me-1.sc-swc-multiple-file{margin-right:4px}.sc-swc-multiple-file-h .mt-2.sc-swc-multiple-file{margin-top:8px}.sc-swc-multiple-file-h .d-flex.sc-swc-multiple-file{display:flex}.sc-swc-multiple-file-h .align-items-center.sc-swc-multiple-file{align-items:center}.sc-swc-multiple-file-h .justify-content-end.sc-swc-multiple-file{justify-content:flex-end}.sc-swc-multiple-file-h .justify-content-between.sc-swc-multiple-file{justify-content:space-between}.sc-swc-multiple-file-h .multiple-file-choosen.sc-swc-multiple-file{border-radius:var(--sfe-sizing-radius-default, 8px);background:var(--sfe-color-fill-neutral-lightest, #f5f7f9);padding:var(--sfe-sizing-gap-small, 8px) var(--sfe-sizing-gap-large, 16px) !important;margin-top:8px}.sc-swc-multiple-file-h .multiple-file-choosen.uploaded.sc-swc-multiple-file{background:var(--sfe-color-fill-brand-light, #e4edfc) !important}.sc-swc-multiple-file-h .multiple-file-choosen.inverted.sc-swc-multiple-file{border:1px solid var(--sfe-color-border-neutral-subtle, #dee3e7);background:var(--sfe-color-fill-backround, #fafbff)}.sc-swc-multiple-file-h .multiple-file-choosen.has-error.sc-swc-multiple-file{background:var(--sfe-color-fill-critical-light, #f8e0e0)}.sc-swc-multiple-file-h .multiple-file-choosen.has-error.inverted.sc-swc-multiple-file{border:1px solid var(--sfe-color-border-critical-solid, #a22827);background:var(--sfe-color-fill-backround, #fafbff)}.sc-swc-multiple-file-h .multiple-file-choosen__wrapper.sc-swc-multiple-file{display:grid;align-items:center;grid-template-columns:2fr 1fr 3fr;gap:22px}.sc-swc-multiple-file-h .multiple-file-choosen__name.sc-swc-multiple-file{color:var(--sfe-color-text-default-primary, rgba(0, 0, 0, 0.95));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;min-width:3rem}.sc-swc-multiple-file-h .multiple-file-choosen__size.sc-swc-multiple-file{color:var(--sfe-color-text-default-secondary, rgba(0, 0, 0, 0.8));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;white-space:nowrap}.sc-swc-multiple-file-h .multiple-file-choosen.sc-swc-multiple-file div.sc-swc-multiple-file div.completed.sc-swc-multiple-file{color:var(--sfe-color-text-default-secondary, rgba(0, 0, 0, 0.8));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-small, 0.75rem);font-style:normal;font-weight:400;line-height:14px}.sc-swc-multiple-file-h .multiple-file-choosen.sc-swc-multiple-file button.sc-swc-multiple-file span.sc-swc-multiple-file{color:var(--sfe-btn-color-content-bare-brand, #004ca6);font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-default, 0.875rem);font-style:normal;font-weight:400;line-height:16px}.sc-swc-multiple-file-h .multiple-file-choosen.sc-swc-multiple-file button.has-error.sc-swc-multiple-file span.sc-swc-multiple-file{color:var(--sfe-btn-color-content-bare-critical, #a22827)}";

const SwcMultipleFile = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.updateRemove = index.createEvent(this, "updateRemove");
        this.updateReplace = index.createEvent(this, "updateReplace");
        this.uploadRetry = index.createEvent(this, "uploadRetry");
    }
    /**
     * fileInfo prop for the component
     */
    fileInfo = [];
    /**
     * inverted prop for the single file component
     */
    inverted = false;
    /**
     * hasError prop for the single file component
     */
    hasError = false;
    /**
     * progress prop for the single file component
     */
    progress = 0;
    /**
     * uniqueId prop for the single file component
     */
    uniqueId = `multiple-file-${utils.useId().generate()}`;
    //event emitted from the multiple file component
    updateRemove;
    updateReplace;
    uploadRetry;
    //computed properties in the component
    get fileDetails() {
        return fileDetailsFormat(this.fileInfo);
    }
    //methods
    handleUpdateReplace = (event, fileId) => {
        event.preventDefault();
        this.updateReplace.emit(fileId);
    };
    handleUpdateRemove = (event, fileId) => {
        event.preventDefault();
        this.updateRemove.emit(fileId);
    };
    handleUploadRetry = (event) => {
        event.preventDefault();
        this.uploadRetry.emit(null);
    };
    render() {
        return (index.h(index.Host, { key: 'c786468dc96422a5aed52231cca83e2c4179a418' }, index.h("section", { key: '665792a30aa7ed31ed35fd456ddaeea57cd27c88', class: {
                'multiple-file-choosen': true,
                inverted: this.inverted,
                uploaded: this.progress === 100,
                'has-error': this.hasError,
            } }, this.fileDetails.map((fileDetail, index$1) => (index.h("div", { class: "multiple-file-choosen__wrapper", key: index$1 }, index.h("div", { class: "multiple-file-choosen__name" }, fileDetail.name), index.h("div", { class: "multiple-file-choosen__size" }, fileDetail.size), index.h("div", { class: "d-flex align-items-center justify-content-end" }, index.h("swc-button", { size: "lg", intent: "brand", variant: "bare", "aria-label": "replace", class: "mr-1", onClick: (ev) => this.handleUpdateReplace(ev, fileDetail.id) }, index.h("span", null, "Replace")), index.h("swc-icon-button", { intent: "neutral", variant: "bare", size: "lg", "aria-label": "dismiss", onClick: (ev) => this.handleUpdateRemove(ev, fileDetail.id) }, index.h("swc-svg-icon", { name: "Dismiss", size: "16" })))))), this.progress > 0 &&
            this.progress !== 100 &&
            this.fileDetails.length > 0 &&
            !this.hasError && (index.h("swc-progress", { key: 'fd7a05c065fcbe5c749f0f8d6a31cb4e29acf4ea', value: this.progress, max: 100, class: "mt-2" })), !this.hasError && this.fileDetails.length > 0 && this.progress === 100 && (index.h("div", { key: 'a55952877da64f4ea54e7bce4b9edf0c5d4a3043', class: "d-flex align-items-center mt-2" }, index.h("div", { key: '1cb415588b04076f9e76d00cc9cd178a75201843', class: "completed" }, "Upload completed"))), this.hasError && (index.h("div", { key: 'f34eda49bb3b0a5758bf4369beacbc9c958e458d', class: "d-flex justify-content-between align-items-center mt-2" }, index.h("div", { key: 'ecf6674fb20fa33466a5236df7c961b9cc5d69aa', class: "has-error" }, index.h("swc-svg-icon", { key: '9e89202234020eba1e283edd7b8eb4ac714db0ba', name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" })), index.h("swc-button", { key: 'df19d477cac10de027adb8bc73d1875a6ffe7deb', size: "lg", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.handleUploadRetry }, index.h("span", { key: '3c23eb07724637a09f50d0e142a683e6aa1a7a33' }, "Retry")))))));
    }
};
SwcMultipleFile.style = swcMultipleFileCss;

const swcSingleFileCss = ".sc-swc-single-file-h .single-file-choosen.sc-swc-single-file{border-radius:var(--sfe-sizing-radius-default, 8px);background:var(--sfe-color-fill-neutral-lightest, #f5f7f9);padding:0 var(--sfe-sizing-gap-large, 16px)}.sc-swc-single-file-h .single-file-choosen.uploaded.sc-swc-single-file{background:var(--sfe-color-fill-brand-light, #e4edfc) !important}.sc-swc-single-file-h .single-file-choosen.inverted.sc-swc-single-file{border:1px solid var(--sfe-color-border-neutral-subtle, #dee3e7);background:var(--sfe-color-fill-backround, #fafbff)}.sc-swc-single-file-h .single-file-choosen.has-error.sc-swc-single-file{background:var(--sfe-color-fill-critical-light, #f8e0e0)}.sc-swc-single-file-h .single-file-choosen.has-error.inverted.sc-swc-single-file{border:1px solid var(--sfe-color-border-critical-solid, #a22827);background:var(--sfe-color-fill-backround, #fafbff)}.sc-swc-single-file-h .single-file-choosen.extended.sc-swc-single-file{padding:var(--sfe-sizing-gap-large, 16px) !important}.sc-swc-single-file-h .single-file-choosen.sc-swc-single-file .btn-span.sc-swc-single-file{color:var(--sfe-btn-color-content-bare-brand, #004ca6);font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-default, 0.875rem);font-style:normal;font-weight:400;line-height:16px}.sc-swc-single-file-h .single-file-choosen__wrapper.sc-swc-single-file{display:grid;align-items:center;grid-template-columns:2fr 1fr 3fr 1fr;gap:10px}.sc-swc-single-file-h .single-file-choosen__wrapper__name.sc-swc-single-file{color:var(--sfe-color-text-default-primary, rgba(0, 0, 0, 0.95));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;min-width:4.5rem}.sc-swc-single-file-h .single-file-choosen__wrapper__size.sc-swc-single-file{color:var(--sfe-color-text-default-secondary, rgba(0, 0, 0, 0.8));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;white-space:nowrap}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file{display:grid;align-items:center;grid-template-columns:1fr 24fr}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.no-thumbnail.sc-swc-single-file{grid-template-columns:1fr}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__extension.sc-swc-single-file{position:relative;width:32px;height:40px}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__extension.sc-swc-single-file .file-type.sc-swc-single-file{position:absolute;transform:translate(-50%, -50%);top:65%;left:50%}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__extension.sc-swc-single-file .file-img.sc-swc-single-file img.sc-swc-single-file{width:32px;height:32px;border-radius:4px}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__extension.sc-swc-single-file:empty{display:none}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__identifier.sc-swc-single-file{display:grid;grid-template-columns:3fr 1fr;align-items:center}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__identifier__name.sc-swc-single-file{color:var(--sfe-color-text-default-primary, rgba(0, 0, 0, 0.95));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;min-width:3.4rem;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.sc-swc-single-file-h .single-file-choosen__extended-wrapper.sc-swc-single-file .file__identifier__size.sc-swc-single-file span.sc-swc-single-file{color:var(--sfe-color-text-default-secondary, rgba(0, 0, 0, 0.8));font-family:var(--sfe-typography-font-serif-font, Sora);font-size:var(--sfe-typography-font-size-label-large, 1rem);font-style:normal;font-weight:400;line-height:20px;white-space:nowrap}.sc-swc-single-file-h .single-file-choosen.sc-swc-single-file button.has-error.sc-swc-single-file span.sc-swc-single-file{color:var(--sfe-btn-color-content-bare-critical, #a22827)}.sc-swc-single-file-h .me-2.sc-swc-single-file{margin-right:8px}.sc-swc-single-file-h .me-1.sc-swc-single-file{margin-right:4px}.sc-swc-single-file-h .mt-2.sc-swc-single-file{margin-top:8px}.sc-swc-single-file-h .ms-3.sc-swc-single-file{margin-left:16px}.sc-swc-single-file-h .d-flex.sc-swc-single-file{display:flex}.sc-swc-single-file-h .align-items-center.sc-swc-single-file{align-items:center}.sc-swc-single-file-h .justify-content-end.sc-swc-single-file{justify-content:flex-end}.sc-swc-single-file-h .justify-content-between.sc-swc-single-file{justify-content:space-between}";

const SwcSingleFile = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.updateRemove = index.createEvent(this, "updateRemove");
        this.updateReplace = index.createEvent(this, "updateReplace");
        this.uploadRetry = index.createEvent(this, "uploadRetry");
    }
    /**
     * file prop for the component
     */
    fileInfo = [];
    /**
     * extended prop for the single file component
     */
    extended = false;
    /**
     * thumbnail prop for the single file component
     */
    thumbnail = 'file';
    /**
     * inverted prop for the single file component
     */
    inverted = false;
    /**
     * hasError prop for the single file component
     */
    hasError = false;
    /**
     * progress prop for the single file component
     */
    progress = 0;
    /**
     * uniqueId prop for the single file component
     */
    uniqueId = `single-file-${utils.useId().generate()}`;
    updateRemove;
    updateReplace;
    uploadRetry;
    //computed getter properties of the component
    get getFileExtension() {
        if (this.fileInfo.length > 0) {
            const fileName = this.fileInfo[0].name;
            return fileName.split('.').pop()?.toUpperCase() || '';
        }
        return '';
    }
    get fileExtensionColour() {
        return fileColorVariants['jpg'];
    }
    get fileFontSize() {
        return this.getFileExtension.length <= 3 ? '13px' : '10px';
    }
    get shouldShowFile() {
        if (this.thumbnail === 'file') {
            return true;
        }
        if (this.thumbnail === 'photo' && this.fileInfo.length > 0) {
            const extension = this.getFileExtension;
            return !['PNG', 'JPEG', 'JPG'].includes(extension);
        }
        return false;
    }
    get createImageUrl() {
        if (this.fileInfo.length > 0) {
            return URL.createObjectURL(this.fileInfo[0]);
        }
        return '';
    }
    get fileDetails() {
        return fileDetailsFormat(this.fileInfo)[0];
    }
    retryUpload = (event) => {
        event.preventDefault();
        this.uploadRetry.emit(null);
    };
    replaceFile = (event) => {
        event.preventDefault();
        this.updateReplace.emit(null);
    };
    removeFile = (id) => {
        this.updateRemove.emit(id);
    };
    render() {
        return (index.h(index.Host, { key: '535405f0330748d6a00c45afe64a9f9efbe7f602' }, index.h("section", { key: 'ae65a1d4f5f24a2ca17da8569c7317effc622e56', class: {
                'single-file-choosen': true,
                inverted: this.inverted,
                uploaded: this.progress === 100,
                'has-error': this.hasError,
                extended: this.extended,
            } }, !this.extended && (index.h("div", { key: 'ff8410d61fd8b599f979e2d95f6c7d42b7903209', class: "single-file-choosen__wrapper" }, index.h("div", { key: '4734671a9baedc1d43545477d595da3547207fb1', class: "single-file-choosen__wrapper__name" }, this.hasError && (index.h("swc-svg-icon", { key: '1afa30ecae1419df6cc1f54d746ad93905a36e31', class: "me-2", name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" })), this.fileDetails.name), index.h("div", { key: 'cdd8adb2846f16e11c5eaec8d463ce3bde693d6a', class: "single-file-choosen__wrapper__size" }, this.fileDetails.size), index.h("div", { key: '88e1d909f623510e81d8245d257998e7294a63b7' }, this.progress > 0 &&
            this.progress !== 100 &&
            !isEmptyObject(this.fileDetails) &&
            !this.extended &&
            !this.hasError && index.h("swc-progress", { key: 'da13bd3e8e7d2ef57b4d836b634c92d0291d80f8', value: this.progress, max: 100 })), index.h("div", { key: '36f83f6316533334d090d17865e9396f113a6a16', class: "d-flex align-items-center justify-content-end" }, this.hasError && !isEmptyObject(this.fileDetails) && (index.h("swc-button", { key: '43539fee6ae3fff53a605ccb09827cd7f2612645', size: "lg", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.retryUpload }, index.h("span", { key: '65afc5ceb7111414b1dff2c0af3c29f06ec9a27c', class: "btn-span" }, "Retry"))), !this.hasError &&
            !isEmptyObject(this.fileDetails) &&
            (this.progress === 0 || this.progress === 100) && (index.h("swc-button", { key: '7a855077cf8cb90c65fed898ac6006dd1b258fac', size: "lg", intent: "brand", variant: "bare", "aria-label": "replace", class: "me-1", onClick: this.replaceFile }, index.h("span", { key: 'e65f1f929943a8c665c48adf018daae6583110f8', class: "btn-span" }, "Replace"))), index.h("swc-icon-button", { key: '8bf888609ac72e54960793213a4a64408ba3cd76', intent: "neutral", variant: "bare", size: "lg", "aria-label": "dismiss", onClick: () => this.removeFile(this.fileDetails.id) }, index.h("swc-svg-icon", { key: 'ec94a8c100960234bed34eb439588a72ecdc3c2a', name: "Dismiss", size: "16" }))))), this.extended && (index.h("div", { key: 'd7a30aa3cda5dde3992d0e178bde54bc8b38391a', class: {
                'single-file-choosen__extended-wrapper': true,
                'no-thumbnail': this.thumbnail === 'none',
            } }, this.thumbnail !== 'none' && (index.h("div", { key: '66f4e91606bcf3efc15ac5a40bd6c93072e6eec4', class: "file__extension" }, this.shouldShowFile && (index.h("div", { key: 'eab56591f55fe973169e4d3d36e85e5a9699a5ee' }, index.h("svg", { key: 'e438da985d81478ea04f5d957ea1de240fd3e2c4', width: "32", height: "40", viewBox: "0 0 32 40", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, index.h("path", { key: '8e6e65b3f7720a8add6adda8f02d98244e02ea07', d: "M1 6C1 3.5 3.5 1 6 1H21.1071C21.9328 1 22.1149 1.10983 22.6954 1.70367C25.2864 4.35425 28.1524 7.58204 30.3895 9.88063C30.9814 10.4888 31 10.6512 31 11.5V33.5C31 36.5 29.5 39 26 39H6C2.5 39 1 36 1 33.5V6Z", fill: "white", stroke: this.fileExtensionColour, "stroke-width": "1.5" })), index.h("div", { key: '3e79151c2aab8a6d9e68d342424078a00fbc84bc', class: "file-type", style: { color: this.fileExtensionColour, fontSize: this.fileFontSize } }, this.getFileExtension))), this.thumbnail === 'photo' &&
            ['PNG', 'JPEG', 'JPG'].includes(this.getFileExtension) &&
            !isEmptyObject(this.fileDetails) && (index.h("div", { key: 'bd583ea6b51d8f0a13fdd0a25e56dc98624db978', class: "file-img" }, index.h("img", { key: '6488630fab8f14eb84e7ef11c342adfd78cb1994', src: this.createImageUrl, alt: this.fileDetails.name }))))), index.h("div", { key: '312352ca224b9f839fe741187709b124bb089941', class: { file: true, 'ms-3': this.thumbnail !== 'none' } }, index.h("div", { key: '9a9822d47173fb95f9dc5213dca298e6accd7798', class: "file__identifier" }, index.h("div", { key: '1087f2e98f75fcbbc8c2c7fe8b2db8dbe08edffd', class: "file__identifier__name" }, this.fileDetails.name), index.h("div", { key: 'f5a7d45396342ea5bfe55dd508192f93f3a05cba', class: "d-flex align-items-center justify-content-end" }, this.hasError && !isEmptyObject(this.fileDetails) && (index.h("swc-button", { key: '994afaf621d93daf63b8dc505f61eebf7234e6bd', size: "md", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.retryUpload }, index.h("span", { key: '017ac7d37efcad7563c89b12ddebd05fd9c18802', class: "btn-span" }, "Retry"))), !this.hasError &&
            !isEmptyObject(this.fileDetails) &&
            (this.progress === 0 || this.progress === 100) && (index.h("swc-button", { key: 'bfd0253496b65c07a0ec3dd303938666754ce781', size: "md", intent: "brand", variant: "bare", "aria-label": "replace", class: "me-1", onClick: this.replaceFile }, index.h("span", { key: 'aef9f90b5a38bf598f969c040be170cf827c97e3', class: "btn-span" }, "Replace"))), index.h("swc-icon-button", { key: '85719f8ecc9d74aba8551a7c4a5196f35cd04bfd', intent: "neutral", variant: "bare", size: "md", "aria-label": "dismiss", onClick: () => this.removeFile(this.fileDetails.id) }, index.h("swc-svg-icon", { key: '77db9c16e6a18bf0a51c0dbe3e7917e86e01657c', name: "Dismiss", size: "16" })))), index.h("div", { key: '195fc61432d1141142d676f909c65517d2fa829d', class: "file__identifier__size mt-3 d-flex align-items-center" }, this.hasError && (index.h("div", { key: 'f6b66e76e4e788e9d9196a7831e3fc404f15b78f' }, index.h("swc-svg-icon", { key: 'c5b9f735e9750021b1448e097ba7ed7d9117da6d', "v-if": "hasError", class: "me-2", name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" }))), index.h("span", { key: 'd1b949999f1edc29542419a85fddf5768488e8c6' }, this.fileDetails.size))))), this.progress > 0 &&
            this.progress !== 100 &&
            this.extended &&
            !isEmptyObject(this.fileDetails) &&
            !this.hasError && index.h("swc-progress", { key: '95edd1a443fe770b4a133c0ef331076072c6ef88', value: this.progress, max: 100 }))));
    }
};
SwcSingleFile.style = swcSingleFileCss;

exports.swc_multiple_file = SwcMultipleFile;
exports.swc_single_file = SwcSingleFile;
//# sourceMappingURL=swc-multiple-file.swc-single-file.entry.cjs.js.map

//# sourceMappingURL=swc-multiple-file_2.cjs.entry.js.map