import { h, Host } from "@stencil/core";
import { useId, hasNamedSlot } from "../../../utils/utils";
export class SwcAccordionItem {
    /**
     * Is used to provide a unique value for the item. If this value is equal to
     * the defaultValue prop on SfeAccordion, then this item
     * will be open by default on page load
     */
    value;
    /**
     * Is used to specify which item should be open by default on page load
     *
     * @internal
     */
    defaultValue = '';
    /**
     * headerClass of the component
     * @internal
     */
    AccordionHeaderClass;
    /**
     * allowMultiple internal prop of the component
     * @internal
     */
    AllowMultiple;
    /**
     * accrodionVariant prop of the component
     * @internal
     */
    variant;
    /**
     * accrodionVariant prop of the component
     * @internal
     */
    ActiveIdsProp;
    /**
     * determines if a radio button should be displayed on the accordion header
     * @internal
     */
    hasRadioButton = true;
    /**
     * determines if a left border should be rendered when the accordion is open
     * @internal
     */
    hasLeftBorder = false;
    contentId = useId().generate(`sfeAccordion`);
    headerId = useId().generate(`sfeAccordion`);
    componentId = useId().generate(`sfeAccordion`);
    reloadComp = false;
    accordionItemRef;
    accordionItemsHost;
    get isContentVisible() {
        return this.ActiveIdsProp.activeIds.includes(this.componentId);
    }
    toggleContentVisibility = () => {
        this.ActiveIdsProp.toggleActiveId(this.componentId);
    };
    componentWillLoad() {
        if (this.value && this.value === this.defaultValue) {
            this.toggleContentVisibility();
        }
    }
    render() {
        const hasHeadingSlot = hasNamedSlot(this.accordionItemsHost, 'heading');
        const hasSubHeadingSlot = hasNamedSlot(this.accordionItemsHost, 'subheading');
        return (h(Host, { key: '94c3d8a9bbc5f0cc25714e425c9aecc9a3d5c860' }, h("div", { key: 'dfcf221c55728f99e653166aefa26e3833fb5c07', id: this.componentId, ref: (el) => (this.accordionItemRef = el), class: {
                accordion__item: true,
                'show-content': this.isContentVisible,
                'accordion--left-border': this.hasLeftBorder,
                [`accordion__${this.variant}`]: true,
            }, "data-testid": "sfe-accordion-item", "data-open": this.isContentVisible ? 'true' : 'false' }, h("button", { key: '22799628c7d9d71fc479e5995ef58630d71993bf', id: this.headerId, "aria-expanded": this.isContentVisible, "aria-controls": this.contentId, class: {
                accordion__header: true,
                [this.AccordionHeaderClass]: true,
            }, "data-testid": "sfe-accordion-header", onClick: this.toggleContentVisibility }, h("div", { key: '1626298009dac58013ec48b31f76d8eb7863441a', class: "accordion__header-content flex-between w-100" }, h("div", { key: '32ab0e3923310d2c42a0d72ecfbfd0229083c2b1', class: "me-5" }, this.hasRadioButton && (h("div", { key: '84793c726b7e8f970ee9ccad90e789ccb5d7a1c2', class: "accordion__icon" }, h("div", { key: '15ddf520604a6a1c4a318ee15e44901f605c74d7', class: {
                accordion__inner__icon: true,
                'accordion__inner__icon--active': this.isContentVisible,
            } }))), h("span", { key: '405134dc7df15729e3b1595cf5b7f48f14297f4f', class: "accordion__headings" }, hasHeadingSlot && (h("span", { key: '1042c613ffc305a53b38cc8ae740336d47c7bed4', class: "accordion__header__text" }, h("slot", { key: '86dbbf35fc6d57703c20711657612c78e48281b8', name: "heading" }))), hasSubHeadingSlot && (h("span", { key: '6acda21e333234ad8ad589fa619254ecab2f3288', class: "accordion__subheader__text" }, h("slot", { key: '7c1a3e53873dc1ec273c10c9f27b312eaaa53db8', name: "subheading" }))))), h("div", { key: '759a5f928ae0fc8ad2de51380e224d68d151832b', class: "d-flex align-items-center" }, h("div", { key: 'f75c190d6159e2e1edb87b9575d3df86c335f47b', class: "mr-2" }, h("slot", { key: '4c76a13ed696d42ba741713bd931ef86576d63ca', name: "extraContent" })), h("slot", { key: 'b2bf8cb2b6a5a137ecc87027cfe287ca16ebc10a', name: "icon" }, h("span", { key: 'f78ff6ecb3e93969b443615bd2b4f7dd41bcbe5f', class: "accordion__header__chevron", "data-open": this.isContentVisible ? 'true' : 'false' }, h("swc-svg-icon", { key: '8b73c8e107813eeac36dd7563357c701946dcd14', name: "Chevron Down", size: "16" })))))), h("div", { key: 'e4d1c37cb47fe5db926c75aa1cac287b3bb10ed4', id: this.contentId, "aria-labelledby": this.headerId, "data-open": this.isContentVisible ? 'true' : 'false', "data-testid": "sfe-accordion-content", class: "accordion__content" }, h("div", { key: '4f59dc24bf1f70dc1426be8b2df81f933cc2d37a', style: { overflow: 'hidden' } }, h("slot", { key: '2384154ac3e9bc73aa8d2adb8b44b92536d917e7', name: "content" }))))));
    }
    static get is() { return "swc-accordion-item"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-accordion-item.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-accordion-item.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is used to provide a unique value for the item. If this value is equal to\nthe defaultValue prop on SfeAccordion, then this item\nwill be open by default on page load"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "defaultValue": {
                "type": "string",
                "attribute": "default-value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "Is used to specify which item should be open by default on page load"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "AccordionHeaderClass": {
                "type": "string",
                "attribute": "accordion-header-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "headerClass of the component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "AllowMultiple": {
                "type": "boolean",
                "attribute": "allow-multiple",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "allowMultiple internal prop of the component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "accrodionVariant prop of the component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "ActiveIdsProp": {
                "type": "unknown",
                "attribute": "active-ids-prop",
                "mutable": false,
                "complexType": {
                    "original": "{ activeIds: string[]; toggleActiveId: (id: string) => void }",
                    "resolved": "{ activeIds: string[]; toggleActiveId: (id: string) => void; }",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "accrodionVariant prop of the component"
                },
                "getter": false,
                "setter": false
            },
            "hasRadioButton": {
                "type": "boolean",
                "attribute": "has-radio-button",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "determines if a radio button should be displayed on the accordion header"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "hasLeftBorder": {
                "type": "boolean",
                "attribute": "has-left-border",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "determines if a left border should be rendered when the accordion is open"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "reloadComp": {}
        };
    }
    static get elementRef() { return "accordionItemsHost"; }
}
//# sourceMappingURL=swc-accordion-item.js.map
