import { h, Host } from "@stencil/core";
import { useId } from "../../../utils/utils";
export class SwcAccordion {
    /**
     * variant for the accordion
     */
    variant = 'default';
    /**
     * allowMultiple prop
     */
    allowMultiple = false;
    /**
     * Is used to specify which item should be open by default on page load
     */
    defaultValue = '';
    /**
     * determines if a radio button should be displayed on the accordion header
     */
    hasRadioButton = true;
    /**
     * determines if a left border should be rendered when the accordion is open
     */
    hasLeftBorder = false;
    activeIds = [];
    accordionHostElement;
    headerClass = useId().generate(`accordion-item-header`);
    // keyboard(arrow up and down) navigation for accessibility
    handleArrowNavigation = (event) => {
        if (['ArrowUp', 'ArrowDown'].includes(event.key)) {
            event.stopPropagation();
            event.preventDefault();
        }
        const direction = event.key;
        const currentFocusedHeader = document.activeElement;
        const accordionHeaderList = Array.from(document.querySelectorAll(`.${this.headerClass}`));
        const length = accordionHeaderList.length;
        const indexOfCurrentFocusedHeader = Array.from(accordionHeaderList).findIndex((el) => el.id == currentFocusedHeader.id);
        if (length <= 1)
            return;
        if (direction === 'ArrowDown') {
            const nextIndex = (indexOfCurrentFocusedHeader + 1) % length;
            accordionHeaderList[nextIndex].focus();
        }
        else if (direction === 'ArrowUp') {
            const nextIndex = (indexOfCurrentFocusedHeader - 1 + length) % length;
            accordionHeaderList[nextIndex].focus();
        }
    };
    toggleActiveId = (id) => {
        if (this.allowMultiple) {
            if (this.activeIds.includes(id)) {
                this.activeIds = this.activeIds.filter((activeId) => activeId !== id);
            }
            else {
                this.activeIds = [...this.activeIds, id];
            }
        }
        else {
            this.activeIds = this.activeIds[0] === id ? [] : [id];
        }
    };
    provideAccordionContext = () => {
        const accordionItems = this.accordionHostElement.querySelectorAll('swc-accordion-item');
        accordionItems.forEach((accordionItem) => {
            accordionItem.AccordionHeaderClass = this.headerClass;
            accordionItem.variant = this.variant;
            accordionItem.AllowMultiple = this.allowMultiple;
            accordionItem.defaultValue = this.defaultValue;
            accordionItem.hasLeftBorder = this.hasLeftBorder;
            accordionItem.hasRadioButton = this.hasRadioButton;
            accordionItem.ActiveIdsProp = {
                activeIds: this.activeIds,
                toggleActiveId: this.toggleActiveId,
            };
        });
    };
    render() {
        this.provideAccordionContext();
        return (h(Host, { key: '60d3da64daa5ad291e69133951670e3fb34a3629' }, h("div", { key: 'c848d5c686e766123c68ccd3c6de2cc84769f7a8', class: `accordion accordion__${this.variant}`, "data-testid": "sfe-accordion", onKeyDown: this.handleArrowNavigation }, h("slot", { key: '87d5bf561af3e7591976df5d57d74b0a3f8de5ff' }))));
    }
    static get is() { return "swc-accordion"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-accordion.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-accordion.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "variant",
                    "resolved": "\"contained\" | \"default\" | \"separated\" | undefined",
                    "references": {
                        "variant": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Accordion/types.ts::variant"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "variant for the accordion"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'default'"
            },
            "allowMultiple": {
                "type": "boolean",
                "attribute": "allow-multiple",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "allowMultiple prop"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "defaultValue": {
                "type": "string",
                "attribute": "default-value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is used to specify which item should be open by default on page load"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "hasRadioButton": {
                "type": "boolean",
                "attribute": "has-radio-button",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines if a radio button should be displayed on the accordion header"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "hasLeftBorder": {
                "type": "boolean",
                "attribute": "has-left-border",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines if a left border should be rendered when the accordion is open"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "activeIds": {}
        };
    }
    static get elementRef() { return "accordionHostElement"; }
}
//# sourceMappingURL=swc-accordion.js.map
