import { h, Host } from "@stencil/core";
const leftMargins = {
    xs: -6,
    sm: -8,
    md: -12,
    lg: -16,
    xl: -19,
};
export class SwcAvatarGroup {
    /**
     * size of each avatar
     */
    size = 'lg';
    /**
     * shape of each avatar
     */
    shape = 'circle';
    /**
     *  an array of objects containing metadata about each avatar
     */
    avatarGroupItems = [];
    get length() {
        return this.avatarGroupItems.length;
    }
    get avatarGroups() {
        if (this.length === 0)
            return [];
        if (this.length <= 5)
            return this.avatarGroupItems;
        const firstFive = this.avatarGroupItems.slice(0, 5);
        const remainderCount = this.length - 5;
        firstFive.push({
            src: '',
            initials: `+${remainderCount}`,
            alt: `+${remainderCount} persons`,
            status: 'none',
        });
        return firstFive;
    }
    calculateZIndex(index) {
        const zIndex = this.length - index;
        return `${zIndex}`;
    }
    calculateLeftMargin(index) {
        if (index === 0)
            return '0px';
        const margin = leftMargins[this.size];
        return `${margin}px`;
    }
    render() {
        return (h(Host, { key: '8bd4e4dc38e5c65be850d6533c81519b4c034d87' }, h("div", { key: 'ed18ded44b540c02a67c2c5064935ca57fe18cb9', class: "swc-avatar-group", "data-testid": "sfe-avatar-group" }, this.avatarGroups.map((avatar, index) => (h("swc-avatar", { key: index, size: this.size, shape: this.shape, src: avatar.src, status: avatar.status, initials: avatar.initials, alt: avatar.alt, class: "swc-avatar", style: {
                zIndex: this.calculateZIndex(index),
                marginLeft: this.calculateLeftMargin(index),
            } }))))));
    }
    static get is() { return "swc-avatar-group"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-avatar-group.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-avatar-group.css"]
        };
    }
    static get properties() {
        return {
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "size",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\" | \"xs\"",
                    "references": {
                        "size": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::size"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of each avatar"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'lg'"
            },
            "shape": {
                "type": "string",
                "attribute": "shape",
                "mutable": false,
                "complexType": {
                    "original": "shape",
                    "resolved": "\"circle\" | \"square\"",
                    "references": {
                        "shape": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::shape"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "shape of each avatar"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'circle'"
            },
            "avatarGroupItems": {
                "type": "unknown",
                "attribute": "avatar-group-items",
                "mutable": false,
                "complexType": {
                    "original": "group",
                    "resolved": "{ src?: string | undefined; initials?: string | undefined; alt?: string | undefined; status?: status | undefined; }[]",
                    "references": {
                        "group": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::group"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "an array of objects containing metadata about each avatar"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            }
        };
    }
}
//# sourceMappingURL=swc-avatar-group.js.map
