import { h } from "@stencil/core";
import { sizes, randomBgInitialsColors, randomBgIconColors } from "./constants";
export class SwcAvatar {
    /**
     * The image src attribute
     */
    src;
    /**
     * The image alt attribute
     */
    alt = '';
    /**
     * The avatar size
     */
    size = 'lg';
    /**
     * The status of the avatar
     */
    status = 'none';
    /**
     * The initials to be displayed on the avatar
     */
    initials;
    /**
     * The shape of the avatar
     */
    shape = 'circle';
    hasImageLoaded = false;
    get itemToRender() {
        if (this.src && this.hasImageLoaded)
            return 'image';
        else if (this.initials)
            return 'initials';
        return 'icon';
    }
    get statusPosition() {
        if (['xs', 'sm'].includes(this.size))
            return { bottom: '-2px', right: '-3px' };
        return { bottom: '0px', right: '-2px' };
    }
    randomBgInitialsColorsCount = randomBgInitialsColors.length;
    randomBgIconColorsCount = randomBgIconColors.length;
    initialsBgColor = randomBgInitialsColors[Math.floor(Math.random() * this.randomBgInitialsColorsCount)];
    iconBgColor = randomBgIconColors[Math.floor(Math.random() * this.randomBgIconColorsCount)];
    handleError = () => (this.hasImageLoaded = false);
    handleLoad = () => (this.hasImageLoaded = true);
    render() {
        return (h("div", { key: 'a1ff6b5140a11bda02f57c5ca3e400248526a0a3', class: "swc-avatar-wrapper", style: { '--right': this.statusPosition.right, '--bottom': this.statusPosition.bottom } }, h("img", { key: '90bb5c942596f93b84a3fc0723fda5f0b67a7ea3', src: this.src, alt: this.alt, onError: this.handleError, onLoad: this.handleLoad, class: `swc-avatar swc-avatar--${this.size} swc-avatar--${this.shape} swc-avatar--${this.status}`, style: { display: this.itemToRender === 'image' ? 'block' : 'none' } }), this.itemToRender === 'initials' && (h("div", { key: '7d0f5a9377982cbbbccf7e649901abe5127b9952', class: `swc-avatar-initials swc-avatar swc-avatar--${this.size} swc-avatar--${this.shape} swc-avatar--${this.status}`, style: { backgroundColor: this.initialsBgColor } }, this.initials)), this.itemToRender === 'icon' && (h("div", { key: 'af269c79bdacaaabe863867953711e7fc9ed1e2a', class: `swc-avatar-icon swc-avatar swc-avatar--${this.size} swc-avatar--${this.shape} swc-avatar--${this.status}`, style: { backgroundColor: this.iconBgColor.bgColor } }, h("svg", { key: '156e2d8018f2abdc1e6b92d66e80dd4b97b26e00', xmlns: "http://www.w3.org/2000/svg", width: sizes[this.size], height: sizes[this.size], viewBox: "0 0 25 24", fill: "none" }, h("path", { key: '1ecb84b042861b44da7f7150ca6cd9a56504d2cb', d: "M18.2541 13.9999C19.4961 13.9999 20.503 15.0068 20.503 16.2488V16.8242C20.503 17.7185 20.1834 18.5833 19.6019 19.2627C18.0325 21.0962 15.6453 22.0011 12.4999 22.0011C9.35407 22.0011 6.96806 21.0959 5.40176 19.2617C4.822 18.5828 4.50348 17.7193 4.50348 16.8265V16.2488C4.50348 15.0068 5.51034 13.9999 6.75236 13.9999H18.2541ZM18.2541 15.4999H6.75236C6.33876 15.4999 6.00348 15.8352 6.00348 16.2488V16.8265C6.00348 17.3622 6.19459 17.8802 6.54245 18.2876C7.79576 19.7553 9.76163 20.5011 12.4999 20.5011C15.2382 20.5011 17.2058 19.7553 18.4623 18.2873C18.8112 17.8797 19.003 17.3608 19.003 16.8242V16.2488C19.003 15.8352 18.6677 15.4999 18.2541 15.4999ZM12.4999 2.00464C15.2614 2.00464 17.4999 4.24321 17.4999 7.00464C17.4999 9.76606 15.2614 12.0046 12.4999 12.0046C9.73851 12.0046 7.49994 9.76606 7.49994 7.00464C7.49994 4.24321 9.73851 2.00464 12.4999 2.00464ZM12.4999 3.50464C10.5669 3.50464 8.99994 5.07164 8.99994 7.00464C8.99994 8.93764 10.5669 10.5046 12.4999 10.5046C14.4329 10.5046 15.9999 8.93764 15.9999 7.00464C15.9999 5.07164 14.4329 3.50464 12.4999 3.50464Z", fill: this.iconBgColor.textColor }))))));
    }
    static get is() { return "swc-avatar"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-avatar.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-avatar.css"]
        };
    }
    static get properties() {
        return {
            "src": {
                "type": "string",
                "attribute": "src",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The image src attribute"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "alt": {
                "type": "string",
                "attribute": "alt",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The image alt attribute"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "''"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "size",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\" | \"xs\"",
                    "references": {
                        "size": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::size"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The avatar size"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'lg'"
            },
            "status": {
                "type": "string",
                "attribute": "status",
                "mutable": false,
                "complexType": {
                    "original": "status",
                    "resolved": "\"error\" | \"none\" | \"success\" | \"warning\"",
                    "references": {
                        "status": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::status"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The status of the avatar"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'none'"
            },
            "initials": {
                "type": "string",
                "attribute": "initials",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The initials to be displayed on the avatar"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "shape": {
                "type": "string",
                "attribute": "shape",
                "mutable": false,
                "complexType": {
                    "original": "shape",
                    "resolved": "\"circle\" | \"square\"",
                    "references": {
                        "shape": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Avatar/types.ts::shape"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The shape of the avatar"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'circle'"
            }
        };
    }
    static get states() {
        return {
            "hasImageLoaded": {}
        };
    }
}
//# sourceMappingURL=swc-avatar.js.map
