import { Host, h } from "@stencil/core";
import { hasNamedSlot } from "../../../utils/utils";
export class SwcBreadcrumb {
    /**
     * separator for the component
     */
    separator;
    el;
    get getSeparatorContent() {
        if (hasNamedSlot(this.el, 'separator')) {
            return Array.from(this.el.children).find((child) => child.slot === 'separator')?.innerHTML;
        }
        if (this.separator) {
            return this.separator;
        }
        return `
        <svg width="12" height="12" viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path d="M4.46967 2.21967C4.17678 2.51256 4.17678 2.98744 4.46967 3.28033L7.18934 6L4.46967 8.71967C4.17678 9.01256 4.17678 9.48744 4.46967 9.78033C4.76256 10.0732 5.23744 10.0732 5.53033 9.78033L8.78033 6.53033C9.07322 6.23744 9.07322 5.76256 8.78033 5.46967L5.53033 2.21967C5.23744 1.92678 4.76256 1.92678 4.46967 2.21967Z" fill="black" fill-opacity="0.5"/>
        </svg>`;
    }
    provideComponentContext = () => {
        const breadCrumbItems = this.el.querySelectorAll('swc-breadcrumb-item');
        breadCrumbItems.forEach((itemElement) => {
            itemElement.separator = this.getSeparatorContent;
        });
    };
    componentDidLoad() {
        this.provideComponentContext();
    }
    render() {
        // provide the necessary content to the relevant component
        this.provideComponentContext();
        return (h(Host, { key: '3c7b2ccbeea48cb6d427872eb196625d280ea89b' }, h("nav", { key: '8f3cd9c500ddb5ae94152572a2ed1e6a25e13b25', "aria-label": "breadcrumb", class: "sfe-breadcrumb sfe-breadcrumb-wrapper", "data-testid": "sfe-breadcrumb" }, h("slot", { key: 'af084f042e726d94dc63dc85648ee31ac80a04cc' }))));
    }
    static get is() { return "swc-breadcrumb"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-breadcrumb.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-breadcrumb.css"]
        };
    }
    static get properties() {
        return {
            "separator": {
                "type": "string",
                "attribute": "separator",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "separator for the component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=swc-breadcrumb.js.map
