import { Host, h } from "@stencil/core";
import tippy from "tippy.js";
import { useId } from "../../../utils/utils";
import { hideOnEsc } from "../../plugin";
import { tabbable } from "tabbable";
export class SwcDropdown {
    /**
     * this is a menu prop
     */
    isSubMenu = false;
    /**
     * position prop
     */
    position = 'bottom';
    /**
     * flip prop of the dropdown
     */
    flip = true;
    dropdownRef;
    contentRef;
    triggerRef;
    observer = null;
    isExpanded = false;
    isExpandedHandler(newValue) {
        if (!newValue && !this.isSubMenu) {
            setTimeout(() => {
                const focusableElements = tabbable(this.triggerRef || []);
                focusableElements[0] && focusableElements[0].focus();
            }, 0);
        }
    }
    hostElement;
    triggerId = useId().generate('dropdown-trigger');
    handleKeydown = (event) => {
        if (event.key === 'Tab' && this.isExpanded) {
            event.preventDefault();
        }
        if (event.key === 'ArrowUp' || event.key === 'ArrowDown') {
            event.preventDefault();
            const items = Array.from(this.dropdownRef.querySelectorAll('.sfe-list-item__trigger:not([disabled])'));
            if (items.length > 0 &&
                !event.target.classList.contains('sfe-list-item__trigger')) {
                items[0].focus();
            }
        }
    };
    handleKeydownOnTrigger = (event) => {
        /**
         * Move focus to the first list item if Enter or Space key
         * is pressed while the trigger was focused on
         */
        if (event.key === 'Enter' || event.key === ' ') {
            setTimeout(() => {
                const items = Array.from(this.dropdownRef.querySelectorAll('.sfe-list-item__trigger:not([disabled])'));
                if (items.length === 0)
                    return;
                items[0].focus();
            }, 100);
        }
    };
    initDropdown = () => {
        tippy(this.hostElement.querySelector(`#${this.triggerId}`), {
            theme: 'dropdown',
            content: this.contentRef,
            placement: this.position,
            allowHTML: true,
            trigger: this.isSubMenu ? 'mouseenter focusin' : 'click',
            arrow: false,
            interactive: true,
            role: 'menu',
            maxWidth: 'none',
            offset: [0, -5],
            hideOnClick: true,
            plugins: [hideOnEsc],
            popperOptions: {
                // Ensures that the menu is not constrained within its container
                strategy: 'fixed',
                modifiers: [
                    {
                        name: 'flip',
                        enabled: this.flip,
                    },
                ],
            },
        });
        // if (Array.isArray(instances) && instances.length > 0) {
        //   this.dropdownId = `tippy-${instances[0].id}`
        // }
    };
    createObserver = () => {
        const options = {
            attributes: true, // Observe attribute changes
            attributeFilter: ['aria-expanded'], // Observe only the aria-expanded attribute
        };
        this.observer = new MutationObserver((mutationsList) => {
            mutationsList.forEach((mutation) => {
                if (mutation.type === 'attributes' && mutation.attributeName === 'aria-expanded') {
                    const target = mutation.target;
                    this.isExpanded = target.getAttribute('aria-expanded') === 'true';
                }
            });
        });
        if (this.triggerId)
            this.observer.observe(this.triggerRef, options);
    };
    componentDidLoad() {
        this.initDropdown();
        this.createObserver();
    }
    disconnectedCallback() {
        if (this.observer) {
            this.observer.disconnect();
            this.observer = null; // Clean up the reference
        }
    }
    render() {
        return (h(Host, { key: 'd3d1ee249862b1ae08666358e89300d6c201fe09' }, h("div", { key: '5944bdf34e96f254624adb14440a0e1618383667', ref: (elm) => (this.dropdownRef = elm), class: "sfe-dropdown", "data-testid": "sfe-dropdown", onKeyDown: this.handleKeydown }, h("div", { key: '0c6a24123bd7c93678bd60bfe7eb05ec7a9c33b6' }, h("div", { key: '2dbe5c7235de3319094002f8669f3fec24a59a58', id: this.triggerId, ref: (elm) => (this.triggerRef = elm), "aria-haspopup": "menu", "aria-controls": this.triggerId, class: "fit-content", onKeyDown: this.handleKeydownOnTrigger }, h("slot", { key: '8eae21470f11a9ea1010d2321281b6e9915e5468', name: "trigger" }))), h("div", { key: '8e44dc44281c7e6d703fa09dc9f99fc5020426ba', ref: (el) => (this.contentRef = el) }, h("slot", { key: 'b82823176f313263c447bd0d4529f4cf9c27ea5d', name: "list" })))));
    }
    static get is() { return "swc-dropdown"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-dropdown.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-dropdown.css"]
        };
    }
    static get properties() {
        return {
            "isSubMenu": {
                "type": "boolean",
                "attribute": "is-sub-menu",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "this is a menu prop"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "Placement",
                    "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
                    "references": {
                        "Placement": {
                            "location": "import",
                            "path": "tippy.js",
                            "id": "../../node_modules/tippy.js/index.d.ts::Placement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "position prop"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'bottom'"
            },
            "flip": {
                "type": "boolean",
                "attribute": "flip",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "flip prop of the dropdown"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "isExpanded": {}
        };
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "isExpanded",
                "methodName": "isExpandedHandler"
            }];
    }
}
//# sourceMappingURL=swc-dropdown.js.map
