import { Host, h } from "@stencil/core";
import { useId } from "../../../utils/utils";
import { fileDetailsFormat } from "../file-utils";
export class SwcMultipleFile {
    /**
     * fileInfo prop for the component
     */
    fileInfo = [];
    /**
     * inverted prop for the single file component
     */
    inverted = false;
    /**
     * hasError prop for the single file component
     */
    hasError = false;
    /**
     * progress prop for the single file component
     */
    progress = 0;
    /**
     * uniqueId prop for the single file component
     */
    uniqueId = `multiple-file-${useId().generate()}`;
    //event emitted from the multiple file component
    updateRemove;
    updateReplace;
    uploadRetry;
    //computed properties in the component
    get fileDetails() {
        return fileDetailsFormat(this.fileInfo);
    }
    //methods
    handleUpdateReplace = (event, fileId) => {
        event.preventDefault();
        this.updateReplace.emit(fileId);
    };
    handleUpdateRemove = (event, fileId) => {
        event.preventDefault();
        this.updateRemove.emit(fileId);
    };
    handleUploadRetry = (event) => {
        event.preventDefault();
        this.uploadRetry.emit(null);
    };
    render() {
        return (h(Host, { key: 'c786468dc96422a5aed52231cca83e2c4179a418' }, h("section", { key: '665792a30aa7ed31ed35fd456ddaeea57cd27c88', class: {
                'multiple-file-choosen': true,
                inverted: this.inverted,
                uploaded: this.progress === 100,
                'has-error': this.hasError,
            } }, this.fileDetails.map((fileDetail, index) => (h("div", { class: "multiple-file-choosen__wrapper", key: index }, h("div", { class: "multiple-file-choosen__name" }, fileDetail.name), h("div", { class: "multiple-file-choosen__size" }, fileDetail.size), h("div", { class: "d-flex align-items-center justify-content-end" }, h("swc-button", { size: "lg", intent: "brand", variant: "bare", "aria-label": "replace", class: "mr-1", onClick: (ev) => this.handleUpdateReplace(ev, fileDetail.id) }, h("span", null, "Replace")), h("swc-icon-button", { intent: "neutral", variant: "bare", size: "lg", "aria-label": "dismiss", onClick: (ev) => this.handleUpdateRemove(ev, fileDetail.id) }, h("swc-svg-icon", { name: "Dismiss", size: "16" })))))), this.progress > 0 &&
            this.progress !== 100 &&
            this.fileDetails.length > 0 &&
            !this.hasError && (h("swc-progress", { key: 'fd7a05c065fcbe5c749f0f8d6a31cb4e29acf4ea', value: this.progress, max: 100, class: "mt-2" })), !this.hasError && this.fileDetails.length > 0 && this.progress === 100 && (h("div", { key: 'a55952877da64f4ea54e7bce4b9edf0c5d4a3043', class: "d-flex align-items-center mt-2" }, h("div", { key: '1cb415588b04076f9e76d00cc9cd178a75201843', class: "completed" }, "Upload completed"))), this.hasError && (h("div", { key: 'f34eda49bb3b0a5758bf4369beacbc9c958e458d', class: "d-flex justify-content-between align-items-center mt-2" }, h("div", { key: 'ecf6674fb20fa33466a5236df7c961b9cc5d69aa', class: "has-error" }, h("swc-svg-icon", { key: '9e89202234020eba1e283edd7b8eb4ac714db0ba', name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" })), h("swc-button", { key: 'df19d477cac10de027adb8bc73d1875a6ffe7deb', size: "lg", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.handleUploadRetry }, h("span", { key: '3c23eb07724637a09f50d0e142a683e6aa1a7a33' }, "Retry")))))));
    }
    static get is() { return "swc-multiple-file"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-multiple-file.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-multiple-file.css"]
        };
    }
    static get properties() {
        return {
            "fileInfo": {
                "type": "unknown",
                "attribute": "file-info",
                "mutable": false,
                "complexType": {
                    "original": "File[]",
                    "resolved": "File[]",
                    "references": {
                        "File": {
                            "location": "global",
                            "id": "global::File"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "fileInfo prop for the component"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "inverted": {
                "type": "boolean",
                "attribute": "inverted",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "inverted prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "hasError": {
                "type": "boolean",
                "attribute": "has-error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "hasError prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "progress": {
                "type": "number",
                "attribute": "progress",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "progress prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "0"
            },
            "uniqueId": {
                "type": "string",
                "attribute": "unique-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "uniqueId prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "`multiple-file-${useId().generate()}`"
            }
        };
    }
    static get events() {
        return [{
                "method": "updateRemove",
                "name": "updateRemove",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }, {
                "method": "updateReplace",
                "name": "updateReplace",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }, {
                "method": "uploadRetry",
                "name": "uploadRetry",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-multiple-file.js.map
