import { Host, h } from "@stencil/core";
import { useId } from "../../../utils/utils";
import { fileColorVariants, fileDetailsFormat, isEmptyObject } from "../file-utils";
export class SwcSingleFile {
    /**
     * file prop for the component
     */
    fileInfo = [];
    /**
     * extended prop for the single file component
     */
    extended = false;
    /**
     * thumbnail prop for the single file component
     */
    thumbnail = 'file';
    /**
     * inverted prop for the single file component
     */
    inverted = false;
    /**
     * hasError prop for the single file component
     */
    hasError = false;
    /**
     * progress prop for the single file component
     */
    progress = 0;
    /**
     * uniqueId prop for the single file component
     */
    uniqueId = `single-file-${useId().generate()}`;
    updateRemove;
    updateReplace;
    uploadRetry;
    //computed getter properties of the component
    get getFileExtension() {
        if (this.fileInfo.length > 0) {
            const fileName = this.fileInfo[0].name;
            return fileName.split('.').pop()?.toUpperCase() || '';
        }
        return '';
    }
    get fileExtensionColour() {
        return fileColorVariants['jpg'] || '#C53434';
    }
    get fileFontSize() {
        return this.getFileExtension.length <= 3 ? '13px' : '10px';
    }
    get shouldShowFile() {
        if (this.thumbnail === 'file') {
            return true;
        }
        if (this.thumbnail === 'photo' && this.fileInfo.length > 0) {
            const extension = this.getFileExtension;
            return !['PNG', 'JPEG', 'JPG'].includes(extension);
        }
        return false;
    }
    get createImageUrl() {
        if (this.fileInfo.length > 0) {
            return URL.createObjectURL(this.fileInfo[0]);
        }
        return '';
    }
    get fileDetails() {
        return fileDetailsFormat(this.fileInfo)[0];
    }
    retryUpload = (event) => {
        event.preventDefault();
        this.uploadRetry.emit(null);
    };
    replaceFile = (event) => {
        event.preventDefault();
        this.updateReplace.emit(null);
    };
    removeFile = (id) => {
        this.updateRemove.emit(id);
    };
    render() {
        return (h(Host, { key: '535405f0330748d6a00c45afe64a9f9efbe7f602' }, h("section", { key: 'ae65a1d4f5f24a2ca17da8569c7317effc622e56', class: {
                'single-file-choosen': true,
                inverted: this.inverted,
                uploaded: this.progress === 100,
                'has-error': this.hasError,
                extended: this.extended,
            } }, !this.extended && (h("div", { key: 'ff8410d61fd8b599f979e2d95f6c7d42b7903209', class: "single-file-choosen__wrapper" }, h("div", { key: '4734671a9baedc1d43545477d595da3547207fb1', class: "single-file-choosen__wrapper__name" }, this.hasError && (h("swc-svg-icon", { key: '1afa30ecae1419df6cc1f54d746ad93905a36e31', class: "me-2", name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" })), this.fileDetails.name), h("div", { key: 'cdd8adb2846f16e11c5eaec8d463ce3bde693d6a', class: "single-file-choosen__wrapper__size" }, this.fileDetails.size), h("div", { key: '88e1d909f623510e81d8245d257998e7294a63b7' }, this.progress > 0 &&
            this.progress !== 100 &&
            !isEmptyObject(this.fileDetails) &&
            !this.extended &&
            !this.hasError && h("swc-progress", { key: 'da13bd3e8e7d2ef57b4d836b634c92d0291d80f8', value: this.progress, max: 100 })), h("div", { key: '36f83f6316533334d090d17865e9396f113a6a16', class: "d-flex align-items-center justify-content-end" }, this.hasError && !isEmptyObject(this.fileDetails) && (h("swc-button", { key: '43539fee6ae3fff53a605ccb09827cd7f2612645', size: "lg", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.retryUpload }, h("span", { key: '65afc5ceb7111414b1dff2c0af3c29f06ec9a27c', class: "btn-span" }, "Retry"))), !this.hasError &&
            !isEmptyObject(this.fileDetails) &&
            (this.progress === 0 || this.progress === 100) && (h("swc-button", { key: '7a855077cf8cb90c65fed898ac6006dd1b258fac', size: "lg", intent: "brand", variant: "bare", "aria-label": "replace", class: "me-1", onClick: this.replaceFile }, h("span", { key: 'e65f1f929943a8c665c48adf018daae6583110f8', class: "btn-span" }, "Replace"))), h("swc-icon-button", { key: '8bf888609ac72e54960793213a4a64408ba3cd76', intent: "neutral", variant: "bare", size: "lg", "aria-label": "dismiss", onClick: () => this.removeFile(this.fileDetails.id) }, h("swc-svg-icon", { key: 'ec94a8c100960234bed34eb439588a72ecdc3c2a', name: "Dismiss", size: "16" }))))), this.extended && (h("div", { key: 'd7a30aa3cda5dde3992d0e178bde54bc8b38391a', class: {
                'single-file-choosen__extended-wrapper': true,
                'no-thumbnail': this.thumbnail === 'none',
            } }, this.thumbnail !== 'none' && (h("div", { key: '66f4e91606bcf3efc15ac5a40bd6c93072e6eec4', class: "file__extension" }, this.shouldShowFile && (h("div", { key: 'eab56591f55fe973169e4d3d36e85e5a9699a5ee' }, h("svg", { key: 'e438da985d81478ea04f5d957ea1de240fd3e2c4', width: "32", height: "40", viewBox: "0 0 32 40", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("path", { key: '8e6e65b3f7720a8add6adda8f02d98244e02ea07', d: "M1 6C1 3.5 3.5 1 6 1H21.1071C21.9328 1 22.1149 1.10983 22.6954 1.70367C25.2864 4.35425 28.1524 7.58204 30.3895 9.88063C30.9814 10.4888 31 10.6512 31 11.5V33.5C31 36.5 29.5 39 26 39H6C2.5 39 1 36 1 33.5V6Z", fill: "white", stroke: this.fileExtensionColour, "stroke-width": "1.5" })), h("div", { key: '3e79151c2aab8a6d9e68d342424078a00fbc84bc', class: "file-type", style: { color: this.fileExtensionColour, fontSize: this.fileFontSize } }, this.getFileExtension))), this.thumbnail === 'photo' &&
            ['PNG', 'JPEG', 'JPG'].includes(this.getFileExtension) &&
            !isEmptyObject(this.fileDetails) && (h("div", { key: 'bd583ea6b51d8f0a13fdd0a25e56dc98624db978', class: "file-img" }, h("img", { key: '6488630fab8f14eb84e7ef11c342adfd78cb1994', src: this.createImageUrl, alt: this.fileDetails.name }))))), h("div", { key: '312352ca224b9f839fe741187709b124bb089941', class: { file: true, 'ms-3': this.thumbnail !== 'none' } }, h("div", { key: '9a9822d47173fb95f9dc5213dca298e6accd7798', class: "file__identifier" }, h("div", { key: '1087f2e98f75fcbbc8c2c7fe8b2db8dbe08edffd', class: "file__identifier__name" }, this.fileDetails.name), h("div", { key: 'f5a7d45396342ea5bfe55dd508192f93f3a05cba', class: "d-flex align-items-center justify-content-end" }, this.hasError && !isEmptyObject(this.fileDetails) && (h("swc-button", { key: '994afaf621d93daf63b8dc505f61eebf7234e6bd', size: "md", intent: "neutral", variant: "bare", "aria-label": "dismiss", class: "has-error", onClick: this.retryUpload }, h("span", { key: '017ac7d37efcad7563c89b12ddebd05fd9c18802', class: "btn-span" }, "Retry"))), !this.hasError &&
            !isEmptyObject(this.fileDetails) &&
            (this.progress === 0 || this.progress === 100) && (h("swc-button", { key: 'bfd0253496b65c07a0ec3dd303938666754ce781', size: "md", intent: "brand", variant: "bare", "aria-label": "replace", class: "me-1", onClick: this.replaceFile }, h("span", { key: 'aef9f90b5a38bf598f969c040be170cf827c97e3', class: "btn-span" }, "Replace"))), h("swc-icon-button", { key: '85719f8ecc9d74aba8551a7c4a5196f35cd04bfd', intent: "neutral", variant: "bare", size: "md", "aria-label": "dismiss", onClick: () => this.removeFile(this.fileDetails.id) }, h("swc-svg-icon", { key: '77db9c16e6a18bf0a51c0dbe3e7917e86e01657c', name: "Dismiss", size: "16" })))), h("div", { key: '195fc61432d1141142d676f909c65517d2fa829d', class: "file__identifier__size mt-3 d-flex align-items-center" }, this.hasError && (h("div", { key: 'f6b66e76e4e788e9d9196a7831e3fc404f15b78f' }, h("swc-svg-icon", { key: 'c5b9f735e9750021b1448e097ba7ed7d9117da6d', "v-if": "hasError", class: "me-2", name: "Warning", size: "20", variant: "filled", color: "#bf3835", opacity: "1" }))), h("span", { key: 'd1b949999f1edc29542419a85fddf5768488e8c6' }, this.fileDetails.size))))), this.progress > 0 &&
            this.progress !== 100 &&
            this.extended &&
            !isEmptyObject(this.fileDetails) &&
            !this.hasError && h("swc-progress", { key: '95edd1a443fe770b4a133c0ef331076072c6ef88', value: this.progress, max: 100 }))));
    }
    static get is() { return "swc-single-file"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-single-file.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-single-file.css"]
        };
    }
    static get properties() {
        return {
            "fileInfo": {
                "type": "unknown",
                "attribute": "file-info",
                "mutable": false,
                "complexType": {
                    "original": "File[]",
                    "resolved": "File[]",
                    "references": {
                        "File": {
                            "location": "global",
                            "id": "global::File"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "file prop for the component"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "extended": {
                "type": "boolean",
                "attribute": "extended",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "extended prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "thumbnail": {
                "type": "string",
                "attribute": "thumbnail",
                "mutable": false,
                "complexType": {
                    "original": "'none' | 'file' | 'photo'",
                    "resolved": "\"file\" | \"none\" | \"photo\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "thumbnail prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'file'"
            },
            "inverted": {
                "type": "boolean",
                "attribute": "inverted",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "inverted prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "hasError": {
                "type": "boolean",
                "attribute": "has-error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "hasError prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "progress": {
                "type": "number",
                "attribute": "progress",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "progress prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "0"
            },
            "uniqueId": {
                "type": "string",
                "attribute": "unique-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "uniqueId prop for the single file component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "`single-file-${useId().generate()}`"
            }
        };
    }
    static get events() {
        return [{
                "method": "updateRemove",
                "name": "updateRemove",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }, {
                "method": "updateReplace",
                "name": "updateReplace",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }, {
                "method": "uploadRetry",
                "name": "uploadRetry",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-single-file.js.map
