import { h, Host } from "@stencil/core";
import { sidebarState, updateCollapsed } from "../sidebar-store";
export class SwcSidebarHeader {
    /**
     * Current module name
     */
    module = '';
    /**
     * List of available modules
     */
    modulesList = [{ title: '', description: '' }];
    /**
     * Whether modules can be switched
     */
    canSwitchModules = false;
    /**
     * Event emitted when a module is switched
     */
    switchModule;
    /**
     * Event emitted when the sidebar is collapsed
     */
    async isCurrentModule(index) {
        return Promise.resolve(this.module.toLowerCase() === this.modulesList[index].title.toLowerCase());
    }
    handleModuleSwitch = (moduleTitle) => {
        this.switchModule.emit(moduleTitle);
    };
    toggleCollapsed = () => {
        updateCollapsed(!sidebarState.collapsed);
    };
    render() {
        return (h(Host, { key: 'e963335913a49d0a8a3d74b179b1d3c3fbcda3c5', "data-testid": "sfe-sidebar-header" }, h("div", { key: '821b502f21f727f0af001c3b77a9e849fd084e26', class: "sfe-sidebar-header" }, h("div", { key: '6ec8fc8de754233c73313543920da51a5f7958e6', class: `d-flex align-items-center w-100 ${sidebarState.collapsed ? 'justify-content-center' : 'justify-content-between'}` }, !sidebarState.collapsed && (h("div", { key: '21efca55733a7a44603cffe230138203a50a8fb0', class: "d-flex align-items-center" }, this.canSwitchModules ? (h("swc-dropdown", null, h("swc-button", { slot: "trigger", variant: "bare", intent: "neutral", class: "border-0 bg-transparent d-flex align-items-center", customClass: "cursor-pointer" }, h("span", { class: "sfe-sidebar-header__module" }, this.module), h("swc-svg-icon", { name: "Chevron Down", size: "16", color: "currentColor", class: "ml-1" })), h("swc-list", { slot: "list", class: "modules-list ml-3" }, this.modulesList.map((moduleDetails, index) => (h("swc-list-item", { key: index, onClick: () => this.handleModuleSwitch(moduleDetails.title), class: "modules-list-item" }, h("p", { class: "modules-list-item__title" }, moduleDetails.title), h("p", { class: "modules-list-item__description" }, moduleDetails.description))))))) : (h("p", { class: "sfe-sidebar-header__module" }, this.module)))), h("swc-button", { key: 'ca4723f1a6096dffdd7902db2d08f63959ea90f3', intent: "neutral", variant: "bare", title: sidebarState.collapsed ? 'Expand sidebar' : 'Collapse sidebar', "aria-label": sidebarState.collapsed ? 'Expand sidebar' : 'Collapse sidebar', class: !sidebarState.collapsed ? 'ml-auto' : '', onClick: this.toggleCollapsed, customClass: "cursor-pointer" }, h("svg", { key: 'ac222d57378e00d71cffd7cfa4e182716d051b4b', xmlns: "http://www.w3.org/2000/svg", width: "18", height: "18", viewBox: "0 0 18 18", fill: "none" }, h("path", { key: '7f5f43a9993396d6202ee872b7735e1a585b5c26', d: "M3.25 0C1.45507 0 0 1.45507 0 3.25V14.75C0 16.5449 1.45507 18 3.25 18H14.75C16.5449 18 18 16.5449 18 14.75V3.25C18 1.45507 16.5449 0 14.75 0H3.25ZM9 16.5V1.5H14.75C15.7165 1.5 16.5 2.2835 16.5 3.25V14.75C16.5 15.7165 15.7165 16.5 14.75 16.5H9Z", fill: "black", "fill-opacity": "0.7" })))))));
    }
    static get is() { return "swc-sidebar-header"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-sidebar-header.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-sidebar-header.css"]
        };
    }
    static get properties() {
        return {
            "module": {
                "type": "string",
                "attribute": "module",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Current module name"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "modulesList": {
                "type": "unknown",
                "attribute": "modules-list",
                "mutable": false,
                "complexType": {
                    "original": "ModuleDetails[]",
                    "resolved": "ModuleDetails[]",
                    "references": {
                        "ModuleDetails": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Layout/swc-sidebar/swc-sidebar-header/swc-sidebar-header.tsx",
                            "id": "src/components/Layout/swc-sidebar/swc-sidebar-header/swc-sidebar-header.tsx::ModuleDetails"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "List of available modules"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[{ title: '', description: '' }]"
            },
            "canSwitchModules": {
                "type": "boolean",
                "attribute": "can-switch-modules",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether modules can be switched"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "switchModule",
                "name": "switch:module",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when a module is switched"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "isCurrentModule": {
                "complexType": {
                    "signature": "(index: number) => Promise<boolean>",
                    "parameters": [{
                            "name": "index",
                            "type": "number",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<boolean>"
                },
                "docs": {
                    "text": "Event emitted when the sidebar is collapsed",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=swc-sidebar-header.js.map
