import { h, Host, } from "@stencil/core";
import { sidebarState, updateCollapsed, toggleNestedItem, isNestedItemOpen } from "../sidebar-store";
import { useId } from "../../../../utils/utils";
export class SwcSidebarOption {
    el;
    /**
     * Whether this option has nested sections
     */
    hasSections = false;
    /**
     * Whether this is a subsection
     */
    isSubsection = false;
    /**
     * Title of the option
     */
    sidebarTitle = '';
    /**
     * Whether this option is active
     */
    isActive = false;
    /**
     * Nesting level
     */
    level;
    /**
     * Icon name
     */
    iconName = 'Add Circle';
    /**
     * Icon variant
     */
    iconVariant = 'outline';
    /**
     * Unique identifier for this option
     */
    optionId = '';
    /**
     * Event emitted when option is selected
     */
    selectOption;
    showDropdown = false;
    childHeight = 'auto';
    childRef;
    uniqueId = '';
    handleStoreChange() {
        this.showDropdown = false;
    }
    handleSidebarCollapsed() {
        this.showDropdown = false;
    }
    connectedCallback() {
        this.uniqueId = this.optionId || `sidebar-option-${this.sidebarTitle}-${useId().generate()}`;
        this.showDropdown = isNestedItemOpen(this.uniqueId);
    }
    componentDidLoad() {
        this.childRef = this.el.querySelector('.sidebar-option__subsection');
    }
    toggleDropdown = () => {
        if (this.hasSections) {
            this.showDropdown = !this.showDropdown;
            toggleNestedItem(this.uniqueId, this.showDropdown);
            if (this.level === 1) {
                setTimeout(() => {
                    const lastSubsectionItem = this.getLastSubsectionItem();
                    if (lastSubsectionItem) {
                        this.addClickListenerToLastSubsection(lastSubsectionItem);
                    }
                }, 0);
            }
        }
    };
    getLastSubsectionItem() {
        if (!this.childRef)
            return null;
        const subsections = this.childRef.querySelectorAll(':scope > .sidebar-option');
        if (!subsections || subsections.length === 0)
            return null;
        return subsections[subsections.length - 1];
    }
    getSidebarOptionHeight(element) {
        const sidebarOption = element.getElementsByClassName('sidebar-option-wrapper');
        return sidebarOption.length ? sidebarOption[0].getBoundingClientRect().height / 2 || 0 : 0;
    }
    addClickListenerToLastSubsection(lastSubsectionItem) {
        if (!(lastSubsectionItem && this.childRef))
            return;
        lastSubsectionItem.addEventListener('click', () => {
            const childWrapperHeight = lastSubsectionItem.getBoundingClientRect().height || 0;
            const sidebarOptionHeight = this.getSidebarOptionHeight(lastSubsectionItem);
            if (sidebarOptionHeight) {
                this.childHeight = `${childWrapperHeight - sidebarOptionHeight - 1}px`;
            }
            if (this.childRef) {
                this.childRef.classList.add('excess');
            }
        });
    }
    handleSelection = async () => {
        this.selectOption.emit();
        if (sidebarState.collapsed) {
            updateCollapsed(false);
            setTimeout(() => {
                this.toggleDropdown();
            }, 0);
        }
    };
    render() {
        return (h(Host, { key: '4badb5c92e1e68fe9394b5f6d1f5892b440631ca' }, h("div", { key: 'f8822d1a48a2dfc1351a6829b6c0bd15b6252ba6', class: {
                'sidebar-option': true,
                'has-sections': this.hasSections && this.showDropdown,
            }, style: { '--child-height': this.childHeight }, "data-testid": "sfe-sidebar-option" }, h("div", { key: '006b0391893c4438c6007c0a6bc681e3c08d2d47', class: {
                'sidebar-option-wrapper': true,
                'sidebar-option-content': this.isSubsection,
            }, onClick: this.handleSelection }, h("swc-button", { key: '075643c968a8fad9923f05e98dd006b7838289c3', customClass: `
              sidebar-option__item w-100 border-0 cursor-pointer ${this.hasSections && this.showDropdown && 'lighter-blue'} ${this.isActive && 'sidebar-option--active'}
            `, onClick: this.toggleDropdown, variant: this.isActive ? 'faded' : 'bare', intent: this.isActive ? 'brand' : 'neutral', size: "md" }, h("div", { key: '13be8413d89d02cc920d49ecce63f014e1b548ef', class: "d-flex sidebar-option-content-group" }, !this.isSubsection && (h("div", { key: 'b84c2ff8c05f90cfe25a7b5ca81c58cc06b81d2d', class: "icon" }, h("slot", { key: '5fa4aa3702f33ff95aeca23dd898fae4705e0e70', name: "optionIcon" }, h("swc-svg-icon", { key: '9bba5d19d6b0671625aee848699fd5c00a8d4aad', name: this.iconName, variant: 'outline', color: "currentColor", size: "20", class: `${sidebarState.collapsed && 'icon-nudge'}` })))), !sidebarState.collapsed && (h("div", { key: '1467485bd38022f17b7b3400634871ace443f6d1', class: "sidebar-option--group" }, h("span", { key: '619ddbfa54c4b1dc2a26de32b7e8c79b5e381428' }, this.sidebarTitle), h("div", { key: '4661c586dd8c9cbc5baa8667f126bdbc99449e0a', class: "ml-auto d-flex align-items-center" }, h("span", { key: '92550819ecc445838dcd2456c4757e3656449806', class: "ml-auto mr-1" }, h("slot", { key: 'ccce09e780cf198187dc1379fc6260e68f1d55c8', name: "optionBadge" })), this.hasSections && (h("i", { key: 'cecceb354204cf50d46f88ec406da76a7e5d3f23', class: "chevron material-icons" }, this.showDropdown ? 'expand_less' : 'expand_more')))))))), h("div", { key: 'a58caaa04566c2cb58e8b1aa0583166c0acae38a', ref: (el) => (this.childRef = el), class: {
                'vertical-line-nudge': sidebarState.collapsed,
                'd-none': !this.hasSections || !this.showDropdown,
                'sidebar-option__subsection': true,
                'sidebar-option__subsection-content': this.isSubsection || this.hasSections,
            } }, h("slot", { key: '92c1b5255545da2dfd79e2d347d2b1129bc8f2b5' })))));
    }
    static get is() { return "swc-sidebar-option"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-sidebar-option.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-sidebar-option.css"]
        };
    }
    static get properties() {
        return {
            "hasSections": {
                "type": "boolean",
                "attribute": "has-sections",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether this option has nested sections"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "isSubsection": {
                "type": "boolean",
                "attribute": "is-subsection",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether this is a subsection"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "sidebarTitle": {
                "type": "string",
                "attribute": "sidebar-title",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Title of the option"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "isActive": {
                "type": "boolean",
                "attribute": "is-active",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether this option is active"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "level": {
                "type": "number",
                "attribute": "level",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Nesting level"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "iconName": {
                "type": "string",
                "attribute": "icon-name",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Icon name"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Add Circle'"
            },
            "iconVariant": {
                "type": "string",
                "attribute": "icon-variant",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Icon variant"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'outline'"
            },
            "optionId": {
                "type": "string",
                "attribute": "option-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Unique identifier for this option"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get states() {
        return {
            "showDropdown": {},
            "childHeight": {}
        };
    }
    static get events() {
        return [{
                "method": "selectOption",
                "name": "select:option",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when option is selected"
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get listeners() {
        return [{
                "name": "storeChange",
                "method": "handleStoreChange",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "sidebar-collapsed",
                "method": "handleSidebarCollapsed",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=swc-sidebar-option.js.map
