/* eslint-disable @stencil-community/strict-boolean-conditions */
import { Host, h, } from "@stencil/core";
import { hasDefaultSlot, hasNamedSlot } from "../../../utils/utils";
export class SwcList {
    /**
     * width of the list
     */
    width = 'fit-content';
    /**
     * selection for the component
     */
    selection;
    /**
     * options
     */
    options;
    /**
     * searchable prop to allow searching the list or not
     */
    searchable = false;
    /**
     * placeholder text for the search field
     */
    placeholder = 'Search';
    /**
     * loading prop on the component rendering
     */
    loading = false;
    /**
     * maxheight for the component
     */
    maxHeight = 'auto';
    customClass;
    /**
     * registering the search:query event for the component
     */
    searchQuery;
    /**
     * registering update:selection event for updating the selected option
     */
    updateSelection;
    hoveredItem = null;
    searchQueryValue = '';
    el;
    //private listRef?: HTMLUListElement
    /**
    * if (!props.options || (Array.isArray(props.options) && props.options.length === 0)) return []
  
    return props.options.filter((option) => {
      return option.label.toLowerCase().includes(searchQuery.value.toLowerCase())
    })
    */
    get showEmptyState() {
        return (this.searchQueryValue &&
            Array.isArray(this.options) &&
            this.options.length > 0 &&
            this.searchResult.length === 0);
    }
    get searchResult() {
        if (!this.options || (Array.isArray(this.options) && this.options.length === 0))
            return [];
        return this.options.filter((option) => {
            return option.label.toLowerCase().includes(this.searchQueryValue.toLowerCase());
        });
        /*
        if (this.options === undefined || (Array.isArray(this.options) && this.options.length === 0))
          return []
        return this.options.filter((option) =>
          option.label.toLowerCase().includes(this.searchQueryValue.toLowerCase()),
        )*/
    }
    get listedItem() {
        const ulElement = this.el.querySelector('ul');
        if (ulElement) {
            // Select all matching items within the <ul>
            const triggers = ulElement.querySelectorAll('.sfe-list-item__trigger:not([disabled])');
            return Array.from(triggers); // Convert NodeList to Array if needed
        }
        return [];
    }
    //METHODS
    handleSelection = (option) => {
        this.updateSelection.emit(option);
    };
    handleMouseLeave = () => {
        if (this.hoveredItem) {
            this.hoveredItem.blur();
            this.hoveredItem = null;
        }
    };
    handleMouseover = (event) => {
        const hoveredElement = event.target?.closest('.sfe-list-item__trigger:not([disabled])');
        if (hoveredElement) {
            this.hoveredItem = hoveredElement;
            this.hoveredItem.focus();
        }
    };
    handleKeydown = (event) => {
        if (['ArrowUp', 'ArrowDown'].includes(event.key)) {
            event.stopPropagation();
            event.preventDefault();
            const hoveredElement = event.target.closest('.sfe-list-item__trigger:not([disabled])');
            if (hoveredElement) {
                this.hoveredItem = hoveredElement;
            }
            const currentIndex = this.listedItem.indexOf(this.hoveredItem);
            const isArrowUp = event.key === 'ArrowUp';
            const nextIndex = isArrowUp
                ? currentIndex > 0
                    ? currentIndex - 1
                    : this.listedItem.length - 1
                : currentIndex < this.listedItem.length - 1
                    ? currentIndex + 1
                    : 0;
            this.hoveredItem = this.listedItem[nextIndex];
            this.hoveredItem.focus();
        }
    };
    handleInputChange = (inputText) => {
        this.searchQueryValue = inputText;
        this.searchQuery.emit(inputText);
    };
    handleInputEventChange(event) {
        const pluckedValue = event.detail.value;
        this.searchQueryValue = pluckedValue;
        this.searchQuery.emit(pluckedValue);
    }
    render() {
        /*  const defaultSlotCount =
          this.el.children && Array.from(this.el.children).filter((child) => child.slot === '').length */
        const usesDefaultSlot = hasDefaultSlot(this.el);
        const hasFooterSlot = hasNamedSlot(this.el, 'footer');
        return (h(Host, { key: 'be0c2fa203befd62c6fb726a4227c529f9696082', style: { '--width': this.width } }, h("div", { key: '8c003ee7413d5df49a48d5777b0f569fa8ef6747', class: `sfe-list-wrapper ${this.customClass}` }, this.searchable && (h("swc-input", { key: '5543283baf16d6cbc72b4e563d0e3c64911b535a', handleInputChange: this.handleInputChange, value: this.searchQueryValue, placeholder: this.placeholder, variant: "inline" }, h("span", { key: '426e89826748bfd00bfc880a53d43c3c5d7d1521', slot: "leftAddon", style: { display: 'flex', marginInlineStart: '8px' } }, h("svg", { key: '2325103584b1012e0d5ca5e255745f57369d4c23', xmlns: "http://www.w3.org/2000/svg", width: "16", height: "16", viewBox: "0 0 16 16", fill: "none", class: "ms-3" }, h("path", { key: '8d68a98d9a897973be28364460d0abac5ebe9d9a', d: "M7.68996 14.0465C4.18609 14.0465 1.33337 11.1938 1.33337 7.6899C1.33337 4.18603 4.18609 1.33331 7.68996 1.33331C11.1938 1.33331 14.0466 4.18603 14.0466 7.6899C14.0466 11.1938 11.1938 14.0465 7.68996 14.0465ZM7.68996 2.26355C4.69461 2.26355 2.26361 4.70076 2.26361 7.6899C2.26361 10.6791 4.69461 13.1163 7.68996 13.1163C10.6853 13.1163 13.1163 10.6791 13.1163 7.6899C13.1163 4.70076 10.6853 2.26355 7.68996 2.26355Z", fill: "black", "fill-opacity": "0.7" }), h("path", { key: '3e629cf8272970d29171182dfdc19a00bbbc0eaf', d: "M14.2016 14.6666C14.0838 14.6666 13.9659 14.6232 13.8729 14.5302L12.6326 13.2899C12.4528 13.1101 12.4528 12.8124 12.6326 12.6325C12.8124 12.4527 13.1101 12.4527 13.29 12.6325L14.5303 13.8728C14.7101 14.0527 14.7101 14.3504 14.5303 14.5302C14.4373 14.6232 14.3194 14.6666 14.2016 14.6666Z", fill: "black", "fill-opacity": "0.7" }))))), h("ul", { key: '18f173943becb27977ecb118b0be4bf2f7842d0f', class: 'sfe-list', style: { '--max-height': this.maxHeight }, "data-testid": "sfe-list", onMouseOver: this.handleMouseover, onMouseLeave: this.handleMouseLeave, onKeyDown: this.handleKeydown }, h("slot", { key: '94411475b2d8eb1f1bc573eeb2fcb3808b2e699b', name: "header" }), h("div", { key: 'cd9b9d1f04584a2e39e98d948c06cbb4662563e0', class: "scrollable-area" }, h("slot", { key: 'f289f7a0a1093cb5e94e3d45f6a833b288d2180b' }), !usesDefaultSlot && (h("div", { key: 'aa8d095359b5bbe844885b1da753bab5ebc4aab0' }, this.searchResult.map((option, index) => (h("swc-list-item", { key: index, disabled: option.disabled, selected: option.value === this.selection?.value,
            // eslint-disable-next-line react/jsx-no-bind
            onClick: () => this.handleSelection(option) }, option.label))), this.showEmptyState && (h("p", { key: '998fe49a17cd98b0ee297e162eb1a5d8a63ce8c4', class: "sfe-list__empty-text sfe-list__empty-state" }, "No result for \"", this.searchQueryValue, "\"")))), this.loading && (h("div", { key: '674ceda7d5c03cd3f85f32caa39fe00b51234218', class: "sfe-list__loading-state" }, h("swc-loader", { key: 'c6fa981d83e403913de508425ae7deb5b9507645' }))))), h("div", { key: '4b9fffa180cd2c47925ff983ed71de0ae10d03c7', class: { 'sfe-list-footer': hasFooterSlot } }, h("slot", { key: 'a5d3d203706c3514a823b66c7a6e0b656165893a', name: "footer" })))));
    }
    static get is() { return "swc-list"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-list.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-list.css"]
        };
    }
    static get properties() {
        return {
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width of the list"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'fit-content'"
            },
            "selection": {
                "type": "unknown",
                "attribute": "selection",
                "mutable": false,
                "complexType": {
                    "original": "Option",
                    "resolved": "Option | undefined",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/List/types.ts::Option"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "selection for the component"
                },
                "getter": false,
                "setter": false
            },
            "options": {
                "type": "unknown",
                "attribute": "options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[] | undefined",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/List/types.ts::Option"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "options"
                },
                "getter": false,
                "setter": false
            },
            "searchable": {
                "type": "boolean",
                "attribute": "searchable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "searchable prop to allow searching the list or not"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "placeholder text for the search field"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'Search'"
            },
            "loading": {
                "type": "boolean",
                "attribute": "loading",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "loading prop on the component rendering"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "maxHeight": {
                "type": "string",
                "attribute": "max-height",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "maxheight for the component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'auto'"
            },
            "customClass": {
                "type": "string",
                "attribute": "custom-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get states() {
        return {
            "hoveredItem": {},
            "searchQueryValue": {}
        };
    }
    static get events() {
        return [{
                "method": "searchQuery",
                "name": "searchQuery",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "registering the search:query event for the component"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }, {
                "method": "updateSelection",
                "name": "updateSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "registering update:selection event for updating the selected option"
                },
                "complexType": {
                    "original": "Option",
                    "resolved": "Option",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/List/types.ts::Option"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get listeners() {
        return [{
                "name": "change",
                "method": "handleInputEventChange",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=swc-list.js.map
