import { h } from "@stencil/core";
import tippy from "tippy.js";
import "tippy.js/dist/tippy.css";
import "tippy.js/dist/border.css";
import "tippy.js/animations/shift-toward.css";
import { useId } from "../../../utils/utils";
import { hideOnEsc } from "../../plugin";
export class SwcNavigationMenuItem {
    hostElement;
    position = 'bottom';
    showArrow = false;
    contentElementRef;
    triggerId = `sfe-navigation-menu-item-${useId().generate()}`;
    tippyInstance;
    get navId() {
        if (this.tippyInstance) {
            return `tippy-${this.tippyInstance.id}`;
        }
        else {
            return '';
        }
    }
    componentDidLoad() {
        const instance = tippy(this.hostElement.querySelector(`#${this.triggerId}`), {
            theme: 'nav-menu',
            content: this.contentElementRef?.innerHTML,
            animation: 'shift-toward',
            placement: this.position,
            allowHTML: true,
            trigger: 'mouseenter click',
            arrow: this.showArrow,
            interactive: true,
            role: 'nav',
            maxWidth: 'none',
            plugins: [hideOnEsc],
        });
        if (Array.isArray(instance) && instance.length > 0) {
            this.tippyInstance = instance[0];
        }
    }
    render() {
        return (h("div", { key: 'f1f3d6500fe87a4f7bf36f5f4e04c6ab1d1d3a6c', class: "menu-item" }, h("div", { key: '89ab262d7c56407e68c38e476e8685b434fd853a', style: { width: 'fit-content' }, "aria-describedby": this.navId, id: this.triggerId, class: "trigger" }, h("slot", { key: 'af67587880ead2e8874c994fa4849c5533ded292', name: "trigger" })), h("div", { key: 'c4bc52d41e579bbfa5971de70c004703fcdaccd8', ref: (el) => (this.contentElementRef = el), class: "content", style: { display: 'none' } }, h("slot", { key: 'fdf5827e62ae4ded78634b9611efcc3e60930634', name: "content" }))));
    }
    static get is() { return "swc-navigation-menu-item"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-navigation-menu-item.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-navigation-menu-item.css"]
        };
    }
    static get properties() {
        return {
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "Placement",
                    "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
                    "references": {
                        "Placement": {
                            "location": "import",
                            "path": "tippy.js",
                            "id": "../../node_modules/tippy.js/index.d.ts::Placement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'bottom'"
            },
            "showArrow": {
                "type": "boolean",
                "attribute": "show-arrow",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=swc-navigation-menu-item.js.map
