import { h } from "@stencil/core";
export class SwcPaginationButtonList {
    /** Current active page */
    currentPage;
    /** Total number of pages */
    numberOfPages;
    /** Last page number */
    lastPage;
    maxButtonCount = 5;
    buttonsBeforeEllipsis = 3;
    buttonsAfterEllipsis = 2;
    /** Emits an event when the current page changes */
    changeCurrentPage;
    emitPageChange = (page) => {
        this.changeCurrentPage.emit(page);
    };
    get conditionForEllipsisToShow() {
        return this.numberOfPages > this.maxButtonCount;
    }
    get generatedNumbersBeforeEllipsis() {
        return Array.from({ length: this.buttonsBeforeEllipsis }, (_, i) => i + 1);
    }
    get numbersBeforeEllipsis() {
        if (this.conditionForEllipsisToShow) {
            if (this.currentPage < this.lastPage - 1) {
                if (this.currentPage >= this.buttonsBeforeEllipsis) {
                    return [this.currentPage - 2, this.currentPage - 1, this.currentPage];
                }
                return this.generatedNumbersBeforeEllipsis;
            }
            return this.generatedNumbersBeforeEllipsis;
        }
        return [];
    }
    get numbersAfterEllipsis() {
        return this.conditionForEllipsisToShow ? [this.lastPage - 1, this.lastPage] : [];
    }
    get numbersWithoutEllipsis() {
        return this.conditionForEllipsisToShow
            ? []
            : Array.from({ length: this.lastPage }, (_, i) => i + 1);
    }
    get computedNumbers() {
        return this.conditionForEllipsisToShow
            ? this.numbersBeforeEllipsis
            : this.numbersWithoutEllipsis;
    }
    get dropdownNumbers() {
        if (this.conditionForEllipsisToShow) {
            const lowerLimit = this.numbersBeforeEllipsis[this.buttonsBeforeEllipsis - 1];
            const upperLimit = this.numbersAfterEllipsis[0];
            return Array.from({ length: upperLimit - lowerLimit - 1 }, (_, i) => lowerLimit + i + 1);
        }
        return [];
    }
    get ellipsisSeparatesCurrentPagefromNextPage() {
        return this.currentPage + 1 === this.numbersAfterEllipsis[0];
    }
    render() {
        return (h("div", { key: '30a4dd29b9f5ec86ca39e656cf6a163ff684e39b', class: "pagination-button-list" }, this.computedNumbers.map((i) => (h("swc-pagination-button", { number: i, currentPage: this.currentPage, onClickPage: () => this.emitPageChange(i) }))), this.conditionForEllipsisToShow && !this.ellipsisSeparatesCurrentPagefromNextPage && (h("swc-dropdown", { key: '3e5926fb8cf9060c34e9855386919a9b08e5bbb8' }, h("div", { key: 'f5109e65816dee65cf827ea5423464ce83f1e9ea', slot: "trigger" }, h("swc-dropdown-trigger", { key: 'fec3209dfd4b70f30f01bd551f8104bf83b3ef66', customClass: `pagination-ellipsis`, size: "xs", showDropdownIcon: false }, h("span", { key: 'b9ed1e1495ec349e9c92afeff1a7228754110a1f' }, "..."))), h("div", { key: '96e2beffc3224bfdc9b9a860c7696ef99bb7f29a', slot: "list" }, h("swc-list", { key: 'a75addc3bc456dd7302064ce32958f7b5a74fb13', maxHeight: "200px" }, this.dropdownNumbers.map((number) => (h("swc-list-item", { onClick: () => this.emitPageChange(number) }, number))))))), this.conditionForEllipsisToShow && (h("div", { key: '39a2f4148b5a9e241e044d04cf09b85a1d2c17c6', class: "pagination-button-list__numbers-after-ellipsis" }, this.numbersAfterEllipsis.map((i) => (h("swc-pagination-button", { number: i, currentPage: this.currentPage, onClickPage: () => this.emitPageChange(i) })))))));
    }
    static get is() { return "swc-pagination-button-list"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-pagination-button-list.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-pagination-button-list.css"]
        };
    }
    static get properties() {
        return {
            "currentPage": {
                "type": "number",
                "attribute": "current-page",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Current active page"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "numberOfPages": {
                "type": "number",
                "attribute": "number-of-pages",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Total number of pages"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "lastPage": {
                "type": "number",
                "attribute": "last-page",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Last page number"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "maxButtonCount": {},
            "buttonsBeforeEllipsis": {},
            "buttonsAfterEllipsis": {}
        };
    }
    static get events() {
        return [{
                "method": "changeCurrentPage",
                "name": "changeCurrentPage",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emits an event when the current page changes"
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-pagination-button-list.js.map
