import { h } from "@stencil/core";
export class SwcPagination {
    meta;
    limits = [5, 10, 15, 20];
    isSolid = false;
    type = 'basic';
    metaClone;
    firstPage = 1;
    isPerPageFromDB = true;
    defaultPerPage = 1;
    isCurrentPageSetFromInput = false;
    pageNumber;
    pageLimit;
    componentWillLoad() {
        this.metaClone = { ...this.meta };
    }
    get generatedPages() {
        return Array.from({ length: this.numberOfPages }, (_, i) => i + 1);
    }
    get numberOfPages() {
        return Math.ceil(this.metaClone.total / this.numberOfItemsPerPage);
    }
    get upperPerPageBound() {
        return this.metaClone.current_page === this.numberOfPages
            ? this.metaClone.total
            : this.metaClone.current_page * this.metaClone.per_page;
    }
    get lowerPerPageBound() {
        return this.metaClone.current_page === this.firstPage
            ? this.firstPage
            : (this.metaClone.current_page - 1) * this.metaClone.per_page + 1;
    }
    get numberOfItemsPerPage() {
        return this.isPerPageFromDB
            ? this.metaClone.per_page || this.metaClone.count_on_page
            : Number(this.metaClone.per_page) || this.defaultPerPage;
    }
    handleResultsPerPage(limit) {
        this.pageLimit.emit(limit);
        this.metaClone = { ...this.metaClone, per_page: limit };
    }
    setCurrentPage(page) {
        this.metaClone = { ...this.metaClone, current_page: page };
        this.pageNumber.emit(page);
    }
    goToFirstPage = () => this.setCurrentPage(this.firstPage);
    goToLastPage = () => this.setCurrentPage(this.numberOfPages);
    goToPreviousPage = () => this.setCurrentPage(this.metaClone.current_page - 1);
    goToNextPage = () => this.setCurrentPage(this.metaClone.current_page + 1);
    render() {
        return (this.numberOfPages && (h("nav", { key: 'd0376e0eae3b644f2a8ac5482e3969c276b89ec0', "aria-label": "pagination", class: `sfe-pagination ${this.isSolid ? 'is-solid' : ''}` }, h("ul", { key: 'be59bbd4999ae0ac06f6b6772dd73ee47a36975e', class: "sfe-pagination__list" }, h("li", { key: '426bcce64cf4a862d8c4d88b2cf5fcc244b48aac', class: "sfe-pagination__results-per-page" }, h("p", { key: '5c5a2847379ff818d07666748494b8efb5ebfa12', class: "sfe-pagination__results-per-page__text" }, "Results per page"), h("swc-pagination-input", { key: '591a76d0984935e39f2445b0be950d83c51bccea', class: "sfe-pagination__results-per-page__input", dropdownValues: this.limits, value: this.metaClone.per_page, onInput: (e) => this.handleResultsPerPage(e.detail), onClickedListItem: (e) => this.handleResultsPerPage(e.detail) })), this.type != 'lite' && (h("li", { key: '67028100131bfedecdaa840cb5a3c05d4f640ab1', class: "sfe-pagination__page-summary" }, `Showing ${this.lowerPerPageBound} - ${this.upperPerPageBound} of ${this.metaClone.total}`)), h("li", { key: '5effd1a1c9998adb7c185574d216f51ed89dc3ca', class: "sfe-pagination__double-arrow-left" }, h("swc-tooltip", { key: '17b8ac4b0158a194962389cb26be786087ea3f57', content: "Go to first page", showArrow: true, position: "top" }, h("span", { key: 'f4c7d1a962580a263b172e5b6ca0156b9b95bb2c', slot: "trigger" }, h("button", { key: '2b8fb65f5eb90c33876261dc50a0a43033574d79', disabled: this.metaClone.current_page === this.firstPage, onClick: this.goToFirstPage }, "\u00AB ", this.type == 'detailed' && 'First')))), h("li", { key: 'e44adfdfb9b8f61b53fdd3b9011b172a9eda54fd', class: "sfe-pagination__chevron-left" }, h("swc-tooltip", { key: 'c793d060a2d605ba60f134961a3c50d758b2db9e', content: "Go to previous page", showArrow: true, position: "top" }, h("span", { key: '652008e4578da95e9f4b421b161b19ee68699c5c', slot: "trigger" }, h("button", { key: '9710a8b8e6b4a4ee5051c6b9f6fa24a3b6eabc04', disabled: this.metaClone.current_page === this.firstPage, onClick: this.goToPreviousPage }, "\u2039 ", this.type == 'detailed' && 'Back')))), this.type != 'lite' ? (h("li", { class: "sfe-pagination__buttons" }, h("swc-pagination-button-list", { "current-page": this.metaClone.current_page, "last-page": this.numberOfPages, "number-of-pages": this.numberOfPages, onChangeCurrentPage: (e) => this.setCurrentPage(e.detail) }))) : (h("li", { class: "sfe-pagination-lite" }, h("p", { class: "sfe-pagination__results-per-page__text" }, "Page"), h("swc-pagination-input", { class: "sfe-pagination__results-per-page__input", dropdownValues: this.generatedPages, value: this.metaClone.current_page, onInput: (e) => this.setCurrentPage(e.detail), onClickedListItem: (e) => this.setCurrentPage(e.detail) }), "of", h("p", null, this.metaClone.total / this.metaClone.per_page))), h("li", { key: '185b95dcf6d2a15a63c9aa3001b2db8de55a713f', class: "sfe-pagination__chevron-right" }, h("swc-tooltip", { key: '44fb0cc2cd92fcdf7f37c0db781b108b6b24c778', content: "Go to next page", showArrow: true, position: "top" }, h("span", { key: '9d07ca0792752feb82ecef2a8f20274f2e538039', slot: "trigger" }, h("button", { key: '9d605a5133a66ca194c5bd44d320571bab924250', disabled: this.metaClone.current_page === this.numberOfPages, onClick: this.goToNextPage }, this.type == 'detailed' && 'Next', " \u203A")))), h("li", { key: '947cca4fac1aa1865318c75d8fc0134fff464b49', class: "sfe-pagination__double-arrow-right" }, h("swc-tooltip", { key: '70467a8dc5727eeca27cca1105c5459b07506117', content: "Go to last page", showArrow: true, position: "top" }, h("span", { key: '188e6dff38d80f6bfda126fc24069dfa687d009b', slot: "trigger" }, h("button", { key: 'e944ad39b0ae119847e5ca39b008500c94216d1e', disabled: this.metaClone.current_page === this.numberOfPages, onClick: this.goToLastPage }, this.type == 'detailed' && 'Last', " \u00BB"))))))));
    }
    static get is() { return "swc-pagination"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-pagination.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-pagination.css"]
        };
    }
    static get properties() {
        return {
            "meta": {
                "type": "any",
                "attribute": "meta",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "limits": {
                "type": "unknown",
                "attribute": "limits",
                "mutable": false,
                "complexType": {
                    "original": "number[]",
                    "resolved": "number[]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[5, 10, 15, 20]"
            },
            "isSolid": {
                "type": "boolean",
                "attribute": "is-solid",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "'detailed' | 'basic' | 'lite'",
                    "resolved": "\"basic\" | \"detailed\" | \"lite\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'basic'"
            }
        };
    }
    static get states() {
        return {
            "metaClone": {},
            "firstPage": {},
            "isPerPageFromDB": {},
            "defaultPerPage": {},
            "isCurrentPageSetFromInput": {}
        };
    }
    static get events() {
        return [{
                "method": "pageNumber",
                "name": "pageNumber",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }, {
                "method": "pageLimit",
                "name": "pageLimit",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-pagination.js.map
