import { h, Host } from "@stencil/core";
import { hasNamedSlot, onClickOutside } from "../../../utils/utils";
import { computePosition, autoUpdate, offset, flip as _flip, shift } from "@floating-ui/dom";
export class SwcMultiSelect {
    /**
     * selectedOptions the list item
     */
    selectedOptions;
    /**
     * original options
     */
    originalOptions = [];
    /**
     * filtered options when search is applied
     */
    filteredOptions = [];
    /**
     * placeholder the list items
     */
    placeholder = 'Select';
    /**
     * searchable the list items
     */
    searchable = false;
    /**
     * loading state
     */
    loading = false;
    /**
     * width the list items
     */
    width = '100%';
    /**
     * maxHeight the list items
     */
    maxHeight = '230px';
    /**
     * clearable the list items
     */
    clearable = false;
    /**
     * flip the list items
     */
    flip = true;
    /**
     * usingFooterSlot the list items
     */
    usingFooterSlot;
    /**
     * multiple the list items
     */
    multiple = false;
    /**
     * showCheckbox prop the element
     */
    showCheckbox = true;
    // Events
    /**
     * Event emitted when the search query changes
     */
    searchQuery;
    /**
     * Event emitted when the selection changes
     */
    select;
    /**
     * Event emitted when the all is selected
     */
    selectAll;
    /**
     * Event emitted when the selection is cleared
     */
    clearedSelection;
    /**
     * Event emitted when the selection is grouped
     */
    groupSelection;
    // State
    isAllSelected = false;
    shouldGroupSelections = false;
    isOpen = false;
    //watchers
    isAllSelectedHandler(newValue) {
        if (newValue) {
            this.selectAll.emit(newValue);
        }
        else {
            if (this.selectedOptions.length === 0 ||
                this.selectedOptions.length === this.filteredOptions.length) {
                this.selectAll.emit(false);
            }
        }
    }
    groupSelectionHandler(newValue) {
        this.groupSelection.emit(newValue);
    }
    selectedOptionsHandler(newValue) {
        this.isAllSelected = newValue.length > 0 && newValue.length === this.originalOptions.length;
    }
    // getters
    get selectedOptionsLabel() {
        return this.selectedOptions.map((option) => option.label);
    }
    get isIndeterminate() {
        if (this.selectedOptions.length > 0) {
            return this.selectedOptions.length < this.filteredOptions.length;
        }
    }
    // Miscellaneous
    hostEl;
    buttonRef;
    dropdownRef;
    handleClearSelection = (event) => {
        event.stopPropagation();
        this.clearedSelection.emit(null);
    };
    cleanupAutoUpdate;
    toggleDropdown = async () => {
        this.isOpen = !this.isOpen;
        if (this.isOpen) {
            await this.updatePosition();
            this.cleanupAutoUpdate = autoUpdate(this.buttonRef, this.dropdownRef, () => this.updatePosition());
        }
        else {
            if (this.cleanupAutoUpdate) {
                this.cleanupAutoUpdate();
            }
        }
    };
    updatePosition = async () => {
        if (!this.buttonRef || !this.dropdownRef)
            return;
        const { x, y } = await computePosition(this.buttonRef, this.dropdownRef, {
            placement: 'bottom-start',
            middleware: [offset(4), _flip(), shift()],
        });
        Object.assign(this.dropdownRef.style, {
            left: `${x}px`,
            top: `${y}px`,
        });
    };
    handleKeydown = (event) => {
        if (event.key === 'Escape') {
            this.isOpen = false;
        }
    };
    // Hooks
    disconnectedCallback() {
        if (this.cleanupAutoUpdate) {
            this.cleanupAutoUpdate();
        }
    }
    connectedCallback() {
        setTimeout(() => {
            onClickOutside(this.hostEl, () => {
                this.isOpen = false;
            });
        }, 1000);
    }
    render() {
        const usingFooterSlot = hasNamedSlot(this.hostEl, 'footer');
        return (h(Host, { key: 'ff65f7eeb1f0e236cea2a00e80d33ee18b603d9c' }, h("div", { key: '0c031e383e061ee6e9c225f782e1709092c66bb6', class: "sfe-dropdown", onKeyDown: this.handleKeydown }, h("swc-dropdown-trigger", { key: '5965e58ababce7e491b2988755df3cf300f5d294', ref: (el) => (this.buttonRef = el), onClick: this.toggleDropdown, class: "sfe-dropdown-trigger", width: this.width }, h("div", { key: 'a3d2642d5a7aa326206e77429f9b60a397cf8116', class: "w-100 d-flex-center" }, h("div", { key: 'e1747b05899c2dfec9e3dc1ee9f1d3bb1765be89', class: "sfe-dropdown-label" }, this.selectedOptionsLabel && this.selectedOptionsLabel.length > 0 && (h("div", { key: '6eb4991348b81a0ad59eb7f3b67aaf9528f29d6e' }, this.selectedOptionsLabel.length === 1 && (h("div", { key: '28c0b4bf8f8a6d4ccd72448e72d40b496adfbf5b' }, this.selectedOptionsLabel[0])), this.selectedOptionsLabel.length !== 1 && (h("div", { key: '5bcaf0ef809140738c1ab540de17d5a6efd86f0f' }, this.selectedOptionsLabel.length, " selected")))), !(this.selectedOptionsLabel && this.selectedOptionsLabel.length > 0) && (h("div", { key: '2c2e891ea1991d9cd1928bdc90ddb53d727b232b' }, this.placeholder))), h("div", { key: 'aa07e7e7792ae2a3c44b78c883e093212d645048', style: { display: 'flex', alignItems: 'center' } }, h("div", { key: 'f50974b15dfcae80cbac64490a6544295463d78b', style: { display: this.loading ? 'block' : 'none' } }, h("slot", { key: 'bc555a078727aef8c5a7ea820de9c18795f82d91', name: "loader" })), this.clearable && this.selectedOptionsLabel.length > 0 && (h("button", { key: 'e2996c2135e1fba7d66dd03a801b227a3f3f267b', "aria-label": "clear", class: {
                'ml-2': true,
                'clear-btn': true,
            }, onClick: this.handleClearSelection }, h("swc-svg-icon", { key: '753ca247e46ecf2b28d1058b44a560296e9bd2fd', name: "Dismiss", size: "12" })))))), h("swc-list", { key: '1633dea4911c3aeb4d6d3fc80eca7b66d4931571', class: "sfe-dropdown-list", width: "100%", maxHeight: this.maxHeight, searchable: this.searchable, onSearchQuery: (event) => this.searchQuery.emit(event.detail), ref: (el) => (this.dropdownRef = el), style: { display: this.isOpen ? 'block' : 'none' } }, h("div", { key: 'adda6f8bd183819c237d4b674223a5c6ff6cfb07', slot: "header" }, h("div", { key: 'c7b0ea196e05f89d5a0ca4a016a2bf97a2637eeb', class: "py-3 border-bottom" }, h("div", { key: 'b4ae67e3be3a40c149eacfb4f9c2f5316e6db04a', class: "mx-3 d-flex align-items-center justify-content-between" }, h("div", { key: '01ac8d49f13ef8228a158684a5956f9b338e69c7', class: "d-flex align-items-center" }, h("input", { key: '00daaed6b9c4b4b2a26fd30359952fc51832dc13', type: "checkbox", checked: this.isAllSelected, indeterminate: this.isIndeterminate, onChange: (event) => (this.isAllSelected = event.target.checked) }), h("swc-label", { key: '9ea01f2c81f9ff90254999acc7cd63bb8d9c5093', size: "xs", class: "ms-2 default-primary-text" }, "Select all")), h("div", { key: 'bf03ef0daed375a2fe14f43c1ecb0c6cebe85c21', class: "d-flex align-items-center" }, h("swc-label", { key: '23caca4149e16455f06ebb9f239ea3fd2567eff0', size: "xs", class: "me-2 default-primary-text", for: "group-selected" }, "Group selected"), h("swc-switch", { key: '64d8497fa3c3e081109451a6df98281ff2dda63f', id: "group-selected", checked: this.shouldGroupSelections, onChangeSwitch: (event) => (this.shouldGroupSelections = event.target.checked) }))))), h("div", { key: '9cd5375fc8e3732a287e90299e08bf7c0576b6c4' }, this.filteredOptions.map((option) => (h("swc-option", { key: option.value, value: option.value, label: option.label, disabled: option.disabled, SelectedOptions: this.selectedOptions, onSelect: (event) => this.select.emit(event.detail) })))), h("slot", { key: '82e8486d333979b5cbbc24ef2efaca1f62ef5a43', name: "emptyState" }), usingFooterSlot && h("slot", { key: '021ec184e878d0f5af2bd8336c8dbec022b20380', name: "footer" })))));
    }
    static get is() { return "swc-multi-select"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-multi-select.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-multi-select.css"]
        };
    }
    static get properties() {
        return {
            "selectedOptions": {
                "type": "unknown",
                "attribute": "selected-options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-multi-select/swc-multi-select.tsx",
                            "id": "src/components/Select/swc-multi-select/swc-multi-select.tsx::Option"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "selectedOptions the list item"
                },
                "getter": false,
                "setter": false
            },
            "originalOptions": {
                "type": "unknown",
                "attribute": "original-options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-multi-select/swc-multi-select.tsx",
                            "id": "src/components/Select/swc-multi-select/swc-multi-select.tsx::Option"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "original options"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "filteredOptions": {
                "type": "unknown",
                "attribute": "filtered-options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-multi-select/swc-multi-select.tsx",
                            "id": "src/components/Select/swc-multi-select/swc-multi-select.tsx::Option"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "filtered options when search is applied"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "placeholder the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'Select'"
            },
            "searchable": {
                "type": "boolean",
                "attribute": "searchable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "searchable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "attribute": "loading",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "loading state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'100%'"
            },
            "maxHeight": {
                "type": "string",
                "attribute": "max-height",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "maxHeight the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'230px'"
            },
            "clearable": {
                "type": "boolean",
                "attribute": "clearable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "clearable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "flip": {
                "type": "boolean",
                "attribute": "flip",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "flip the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            },
            "usingFooterSlot": {
                "type": "boolean",
                "attribute": "using-footer-slot",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "usingFooterSlot the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "multiple": {
                "type": "boolean",
                "attribute": "multiple",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "multiple the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "showCheckbox": {
                "type": "boolean",
                "attribute": "show-checkbox",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showCheckbox prop the element"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "isAllSelected": {},
            "shouldGroupSelections": {},
            "isOpen": {}
        };
    }
    static get events() {
        return [{
                "method": "searchQuery",
                "name": "searchQuery",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the search query changes"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }, {
                "method": "select",
                "name": "select",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the selection changes"
                },
                "complexType": {
                    "original": "Option",
                    "resolved": "{ value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-multi-select/swc-multi-select.tsx",
                            "id": "src/components/Select/swc-multi-select/swc-multi-select.tsx::Option"
                        }
                    }
                }
            }, {
                "method": "selectAll",
                "name": "selectAll",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the all is selected"
                },
                "complexType": {
                    "original": "Option | boolean",
                    "resolved": "boolean | { value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-multi-select/swc-multi-select.tsx",
                            "id": "src/components/Select/swc-multi-select/swc-multi-select.tsx::Option"
                        }
                    }
                }
            }, {
                "method": "clearedSelection",
                "name": "clearedSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the selection is cleared"
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }, {
                "method": "groupSelection",
                "name": "groupSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the selection is grouped"
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostEl"; }
    static get watchers() {
        return [{
                "propName": "isAllSelected",
                "methodName": "isAllSelectedHandler"
            }, {
                "propName": "shouldGroupSelections",
                "methodName": "groupSelectionHandler"
            }, {
                "propName": "selectedOptions",
                "methodName": "selectedOptionsHandler"
            }];
    }
}
//# sourceMappingURL=swc-multi-select.js.map
