import { h, Host } from "@stencil/core";
export class SwcSelect {
    /**
     * the selection prop for the two data binding
     */
    value;
    /**
     * options the list items
     */
    options = [];
    /**
     * placeholder the list items
     */
    placeholder = 'Select';
    /**
     * searchable the list items
     */
    searchable = false;
    /**
     * loading state
     */
    loading = false;
    /**
     * width the list items
     */
    width = '100%';
    /**
     * maxHeight the list items
     */
    maxHeight = '230px';
    /**
     * clearable the list items
     */
    clearable = false;
    /**
     * flip the list items
     */
    flip = true;
    /**
     * multiple the list items
     */
    multiple = false;
    /**
     * showCheckbox prop the element
     */
    showCheckbox = true;
    //Event emmited in the component
    searchQuery;
    changeSelection;
    clearedSelection;
    groupSelection;
    updateSelectedOptions;
    updateSelectedOption;
    //host element reference
    selectHostEl;
    // reactive state in  the component
    derivedOptions = [];
    shouldGroupSelections = false;
    searchQueryVal = '';
    searchQueryHandler(newValue) {
        this.searchQuery.emit(newValue);
    }
    componentDidLoad() {
        if (this.selectedOption)
            this.updateSelectedOption.emit(this.selectedOption);
        if (this.selectedOptions)
            this.updateSelectedOptions.emit(this.selectedOptions);
    }
    get filteredOptions() {
        let options = structuredClone(this.options);
        if (this.shouldGroupSelections) {
            const selectedOptions = options.filter((option) => Array.isArray(this.value) && this.value.includes(option.value));
            const unselectedOptions = options.filter((option) => Array.isArray(this.value) && !this.value.includes(option.value));
            // let the selected options appear first followed by the unselected options
            options = [...selectedOptions, ...unselectedOptions];
        }
        return options.filter((option) => {
            return String(option.label).toLowerCase().includes(this.searchQueryVal.toLowerCase());
        });
    }
    get selectedOptions() {
        const options = structuredClone(this.options);
        return options.filter((option) => Array.isArray(this.value) && this.value.includes(option.value));
    }
    get selectedOption() {
        const options = structuredClone(this.options);
        return options.find((option) => option.value === this.value);
    }
    handleSelection = (event) => {
        event.stopPropagation();
        const payload = event.detail;
        if (this.multiple && Array.isArray(this.value)) {
            if (this.value.includes(payload.value)) {
                const remainingValues = this.value.filter((value) => value !== payload.value);
                this.changeSelection.emit(remainingValues);
            }
            else {
                this.changeSelection.emit([...this.value, payload.value]);
            }
        }
        else {
            this.changeSelection.emit(payload.value);
        }
    };
    handleClearSelection = (event) => {
        event.stopPropagation();
        if (this.multiple) {
            this.changeSelection.emit([]);
        }
        else {
            this.changeSelection.emit('');
        }
        this.clearedSelection.emit();
    };
    handleGroupSelections = (payload) => {
        this.shouldGroupSelections = payload;
        this.groupSelection.emit(payload);
    };
    handleSelectAll = (event) => {
        event.stopPropagation();
        const selectAll = event.detail;
        if (selectAll) {
            const options = structuredClone(this.options);
            this.changeSelection.emit(options.map((option) => option.value));
        }
        else {
            this.changeSelection.emit([]);
        }
    };
    render() {
        return (h(Host, { key: '7688bafce4ee86f28a065b2156660b67da638402' }, h("div", { key: '996f4d1381f6ca85956c25ed2bbccb7c1c8ba880', style: { width: this.width } }, this.multiple && (h("swc-multi-select", { key: '457c7553e625f6eb54e2a57a9f950ec51bce1015', filteredOptions: this.filteredOptions, originalOptions: this.options, placeholder: this.placeholder, searchable: this.searchable, maxHeight: this.maxHeight, clearable: this.clearable, selectedOptions: this.selectedOptions, flip: this.flip, width: this.width, loading: this.loading, onSelect: this.handleSelection, onSelectAll: (event) => this.handleSelectAll(event), onSearchQuery: (event) => (this.searchQueryVal = event.detail), onClearedSelection: this.handleClearSelection, onGroupSelection: (event) => this.handleGroupSelections(event.detail) }, h("slot", { key: 'b85affe85c61656bb49e7d0275d030bdd56d7421' }), h("div", { key: '053923f59760278c9573281c354074c50e02b20a', slot: "loader" }, h("slot", { key: 'e53f6add0d071d7c12cea50333d09e679cee9ac8', name: "loader" }, h("swc-loader", { key: '1f19e3f9f2f4bb0c39ba670926fe8109ded41ca3', size: "sm" }))), h("div", { key: 'a486b055295a1c57fc26af456283c59f4af74114', slot: "emptyState", class: "swc-select-empty-state", style: {
                display: this.searchQueryVal && this.filteredOptions.length === 0 ? 'block' : 'none',
            } }, h("slot", { key: 'd4dd4a531759920b0cc0d2b112a963eae6558dfc', name: "emptyState" }, h("p", { key: 'c309c26be1494a682a00566cfc119c579dc434b0' }, " No result for \"", this.searchQueryVal, "\""))), h("slot", { key: 'c52da39ec0b04316351c7ecd838860adc49d9f6c', name: "footer" }))), !this.multiple && (h("swc-single-select", { key: '3d0408911117edeb0bf34eef48e827992f2b0d3d', options: this.filteredOptions, placeholder: this.placeholder, searchable: this.searchable, maxHeight: this.maxHeight, clearable: this.clearable, selectedOption: this.selectedOption, flip: this.flip, width: this.width, loading: this.loading, onSelect: this.handleSelection, onSearchQuery: (event) => (this.searchQueryVal = event.detail), onClearedSelection: this.handleClearSelection }, h("div", { key: '92958f3da88701234b9ce0c27ab9992cf5f80be7', slot: "loader" }, h("slot", { key: '42cfcbf97121f22f198aa721e3fafac70a52950e', name: "loader" }, h("swc-loader", { key: '86a1fe9ea63bd201278ffae5a202fa92dd69cf97', size: "sm" }))), h("div", { key: 'cdbf51eb30aae21c635ecb6f08e47254c1bdae43', slot: "emptyState", class: "swc-select-empty-state", style: {
                display: this.searchQueryVal && this.filteredOptions.length === 0 ? 'block' : 'none',
            } }, h("slot", { key: '855e3714bd48fc60e270c3440b85b38efd5b1179', name: "emptyState" }, h("p", { key: 'ebfef71412f236972c785e448b365a2b6f65b4be' }, " No result for \"", this.searchQueryVal, "\""))), h("slot", { key: '489e233254cc45e970dac1be83cc3c7c6ba20c41', name: "footer" }))))));
    }
    static get is() { return "swc-select"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-select.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-select.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "any",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string | number | any[]",
                    "resolved": "any[] | number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the selection prop for the two data binding"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "options": {
                "type": "unknown",
                "attribute": "options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../type",
                            "id": "src/components/Select/type.ts::Option"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "options the list items"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "placeholder the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'Select'"
            },
            "searchable": {
                "type": "boolean",
                "attribute": "searchable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "searchable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "attribute": "loading",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "loading state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'100%'"
            },
            "maxHeight": {
                "type": "string",
                "attribute": "max-height",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "maxHeight the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'230px'"
            },
            "clearable": {
                "type": "boolean",
                "attribute": "clearable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "clearable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "flip": {
                "type": "boolean",
                "attribute": "flip",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "flip the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            },
            "multiple": {
                "type": "boolean",
                "attribute": "multiple",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "multiple the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "showCheckbox": {
                "type": "boolean",
                "attribute": "show-checkbox",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showCheckbox prop the element"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "derivedOptions": {},
            "shouldGroupSelections": {},
            "searchQueryVal": {}
        };
    }
    static get events() {
        return [{
                "method": "searchQuery",
                "name": "searchQuery",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }, {
                "method": "changeSelection",
                "name": "changeSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "selectedValue",
                    "resolved": "(string | number)[] | Option[] | number | string | { value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "selectedValue": {
                            "location": "import",
                            "path": "../type",
                            "id": "src/components/Select/type.ts::selectedValue"
                        }
                    }
                }
            }, {
                "method": "clearedSelection",
                "name": "clearedSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }, {
                "method": "groupSelection",
                "name": "groupSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }, {
                "method": "updateSelectedOptions",
                "name": "updateSelectedOptions",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../type",
                            "id": "src/components/Select/type.ts::Option"
                        }
                    }
                }
            }, {
                "method": "updateSelectedOption",
                "name": "updateSelectedOption",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "Option",
                    "resolved": "{ value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "Option": {
                            "location": "import",
                            "path": "../type",
                            "id": "src/components/Select/type.ts::Option"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "selectHostEl"; }
    static get watchers() {
        return [{
                "propName": "searchQueryVal",
                "methodName": "searchQueryHandler"
            }];
    }
}
//# sourceMappingURL=swc-select.js.map
