/* eslint-disable @stencil-community/element-type */
/* eslint-disable react/jsx-no-bind */
/* eslint-disable @stencil-community/strict-boolean-conditions */
/* eslint-disable no-extra-boolean-cast */
import { h, Host, } from "@stencil/core";
import { hasNamedSlot, onClickOutside } from "../../../utils/utils";
import { computePosition, autoUpdate, offset, flip as _flip, shift } from "@floating-ui/dom";
export class SwcSingleSelect {
    /**
     * selectedOption the list item
     */
    selectedOption;
    /**
     * options the list items
     */
    options;
    /**
     * placeholder the list items
     */
    placeholder = 'Select';
    /**
     * searchable the list items
     */
    searchable = false;
    /**
     * loading state
     */
    loading = false;
    /**
     * width the list items
     */
    width = '100%';
    /**
     * maxHeight the list items
     */
    maxHeight = '230px';
    /**
     * clearable the list items
     */
    clearable = false;
    /**
     * flip the list items
     */
    flip = true;
    /**
     * multiple the list items
     */
    multiple = false;
    /**
     * showCheckbox prop the element
     */
    showCheckbox = true;
    /**
     * Emitted when a user searches for an option
     */
    searchQuery;
    /**
     * Emitted when an option is selected
     */
    select;
    /**
     * Emitted when the clear icon button is clicked
     */
    clearedSelection;
    // getter properties in the component
    get selectedOptionLabel() {
        return this.selectedOption?.label;
    }
    get selectedOptions() {
        return this.selectedOption;
    }
    handleClearSelection = (event) => {
        event.stopPropagation();
        this.clearedSelection.emit(null);
    };
    handleOptionSelection = (event) => {
        this.select.emit(event.detail);
    };
    isOpen = false;
    buttonRef; // HTMLButtonElement
    dropdownRef;
    hostEl;
    cleanupAutoUpdate;
    toggleDropdown = async () => {
        this.isOpen = !this.isOpen;
        if (this.isOpen) {
            await this.updatePosition();
            this.cleanupAutoUpdate = autoUpdate(this.buttonRef, this.dropdownRef, () => this.updatePosition());
        }
        else {
            if (!!this.cleanupAutoUpdate) {
                this.cleanupAutoUpdate();
            }
        }
    };
    updatePosition = async () => {
        if (!this.buttonRef || !this.dropdownRef)
            return;
        const { x, y } = await computePosition(this.buttonRef, this.dropdownRef, {
            placement: 'bottom-start',
            middleware: [offset(4), _flip(), shift()],
        });
        Object.assign(this.dropdownRef.style, {
            left: `${x}px`,
            top: `${y}px`,
        });
    };
    handleKeydown = (event) => {
        if (event.key === 'Escape') {
            this.isOpen = false;
        }
    };
    closeDropdownMenu() {
        this.isOpen = false;
    }
    disconnectedCallback() {
        if (this.cleanupAutoUpdate) {
            this.cleanupAutoUpdate();
        }
    }
    connectedCallback() {
        setTimeout(() => {
            onClickOutside(this.hostEl, () => {
                this.isOpen = false;
            });
        }, 1000);
    }
    render() {
        const emptySlotPresent = hasNamedSlot(this.hostEl, '');
        const usingFooterSlot = hasNamedSlot(this.hostEl, 'footer');
        return (h(Host, { key: '2d297b9a97db1bdad75ad9da66abd9abb57501cf' }, h("div", { key: '2a8ddfa2ddb94a076af4cd326fb7cdd5cdac822e', class: "sfe-dropdown", onKeyDown: this.handleKeydown }, h("swc-dropdown-trigger", { key: '125bb07970b8d972480e5050634ca0db6dc171c1', ref: (el) => (this.buttonRef = el), onClick: this.toggleDropdown, class: "sfe-dropdown-trigger", width: this.width }, h("div", { key: 'a1c59e825ff3dbe4c056b0fe77925a69b6bd9b30', class: "w-100 d-flex-center justify-content-between align-items-center" }, h("div", { key: '4d31f18f4090627622081854f50f6db677a3bc09', class: "sfe-dropdown-label" }, emptySlotPresent ? (h("div", { innerHTML: this.selectedOptionLabel || this.placeholder })) : (h("div", null, this.selectedOptionLabel || this.placeholder))), h("div", { key: 'deb7db5372fcb2e71e505a78a78b2ed5c8f018af', style: { display: 'flex', alignItems: 'center', columnGap: '8px' } }, h("div", { key: '27202fdd682dba830b009ec2084d87a82aab66cd', style: { display: this.loading ? 'block' : 'none' } }, h("slot", { key: '37ce076d3aab8af161eda59f6d13297bdc93cad1', name: "loader" })), this.clearable && this.selectedOptionLabel && (h("button", { key: '9d850611cdae5e8eb4e64f58b8302e0333f834e0', "aria-label": "clear", class: {
                'ml-2': true,
                'clear-btn': true,
            }, onClick: this.handleClearSelection }, h("swc-svg-icon", { key: '590817b584aeb7e2320647a5b75f092882213d69', name: "Dismiss", size: "12" })))))), h("swc-list", { key: 'c58bb7b327615292813934e03059c1f471f79665', class: "sfe-dropdown-list", width: "100%", maxHeight: this.maxHeight, searchable: this.searchable, onSearchQuery: (event) => this.searchQuery.emit(event.detail), ref: (el) => (this.dropdownRef = el), style: { display: this.isOpen ? 'block' : 'none' } }, this.options.map((option) => (h("swc-option", { key: option.value, value: option.value, label: option.label, disabled: option.disabled, SelectedOptions: this.selectedOptions, onSelect: this.handleOptionSelection }))), h("slot", { key: 'e2f4b6a79aec570029766c48308708ab7d386af4', name: "emptyState" }), usingFooterSlot && (h("span", { key: '092b22b26807c02d944064226efc5b8d58a3e7b4', slot: "footer" }, h("slot", { key: '5fa2c6a1d16e629ea348ed28236eb9d5790b1a3c', name: "footer" })))))));
    }
    static get is() { return "swc-single-select"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-single-select.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-single-select.css"]
        };
    }
    static get properties() {
        return {
            "selectedOption": {
                "type": "unknown",
                "attribute": "selected-option",
                "mutable": false,
                "complexType": {
                    "original": "Option",
                    "resolved": "undefined | { value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-single-select/swc-single-select.tsx",
                            "id": "src/components/Select/swc-single-select/swc-single-select.tsx::Option"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "selectedOption the list item"
                },
                "getter": false,
                "setter": false
            },
            "options": {
                "type": "unknown",
                "attribute": "options",
                "mutable": false,
                "complexType": {
                    "original": "Option[]",
                    "resolved": "Option[]",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-single-select/swc-single-select.tsx",
                            "id": "src/components/Select/swc-single-select/swc-single-select.tsx::Option"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "options the list items"
                },
                "getter": false,
                "setter": false
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "placeholder the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'Select'"
            },
            "searchable": {
                "type": "boolean",
                "attribute": "searchable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "searchable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "attribute": "loading",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "loading state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'100%'"
            },
            "maxHeight": {
                "type": "string",
                "attribute": "max-height",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "maxHeight the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'230px'"
            },
            "clearable": {
                "type": "boolean",
                "attribute": "clearable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "clearable the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "flip": {
                "type": "boolean",
                "attribute": "flip",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "flip the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            },
            "multiple": {
                "type": "boolean",
                "attribute": "multiple",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "multiple the list items"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "showCheckbox": {
                "type": "boolean",
                "attribute": "show-checkbox",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showCheckbox prop the element"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "isOpen": {}
        };
    }
    static get events() {
        return [{
                "method": "searchQuery",
                "name": "searchQuery",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emitted when a user searches for an option"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }, {
                "method": "select",
                "name": "select",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emitted when an option is selected"
                },
                "complexType": {
                    "original": "Option",
                    "resolved": "{ value: string | number; label: string; disabled?: boolean | undefined; }",
                    "references": {
                        "Option": {
                            "location": "local",
                            "path": "/Users/Oludayoogunyemi/projects/sfe/shr-ui/packages/wc-lib/src/components/Select/swc-single-select/swc-single-select.tsx",
                            "id": "src/components/Select/swc-single-select/swc-single-select.tsx::Option"
                        }
                    }
                }
            }, {
                "method": "clearedSelection",
                "name": "clearedSelection",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emitted when the clear icon button is clicked"
                },
                "complexType": {
                    "original": "null",
                    "resolved": "null",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostEl"; }
    static get listeners() {
        return [{
                "name": "closeDropdown",
                "method": "closeDropdownMenu",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=swc-single-select.js.map
