import { h } from "@stencil/core";
import { useId } from "../../../utils/utils";
export class SwcStepper {
    hostElement;
    /**
     * orientation of the stepper
     */
    orientation = 'horizontal';
    /**
     * index of the active step
     */
    activeIndex = 0;
    /**
     * show checkmark on completed steps
     */
    withCheckmark = true;
    /**
     * size of the lines in the stepper
     */
    lineSize = '150px';
    /**
     * event emitted when the active step changes
     */
    stepChanged;
    stepItemIds = [];
    provide = () => {
        const stepItems = this.hostElement.querySelectorAll('swc-stepper-item');
        stepItems.forEach((item, index) => {
            item.activeIndex = this.activeIndex;
            item.orientation = this.orientation;
            item.withCheckmark = this.withCheckmark;
            item.lineSize = this.lineSize;
            item.index = index;
            item.isLastItem = index === stepItems.length - 1;
            item.idProp = useId().generate(`sfe-stepper-item-${index}`);
            this.stepItemIds.push(item.idProp);
        });
    };
    render() {
        this.provide();
        return (h("div", { key: '999ba23126083745abe1c6f264a39180a8e2b2d6', "aria-orientation": this.orientation, class: `sfe-stepper ${this.orientation}`, "data-testid": "sfe-stepper" }, h("slot", { key: '8e319fa57545684421c986546ab3206d5d7e42d6' })));
    }
    static get is() { return "swc-stepper"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-stepper.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-stepper.css"]
        };
    }
    static get properties() {
        return {
            "orientation": {
                "type": "string",
                "attribute": "orientation",
                "mutable": false,
                "complexType": {
                    "original": "'horizontal' | 'vertical'",
                    "resolved": "\"horizontal\" | \"vertical\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "orientation of the stepper"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'horizontal'"
            },
            "activeIndex": {
                "type": "number",
                "attribute": "active-index",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "index of the active step"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "0"
            },
            "withCheckmark": {
                "type": "boolean",
                "attribute": "with-checkmark",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "show checkmark on completed steps"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "lineSize": {
                "type": "string",
                "attribute": "line-size",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of the lines in the stepper"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'150px'"
            }
        };
    }
    static get states() {
        return {
            "stepItemIds": {}
        };
    }
    static get events() {
        return [{
                "method": "stepChanged",
                "name": "stepChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event emitted when the active step changes"
                },
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=swc-stepper.js.map
