import { Host, h } from "@stencil/core";
export class SwcTableHead {
    /**
     * emitted when the sort button is clicked
     */
    sortCells;
    /**
     * the label for the table head cell
     */
    label;
    /**
     * determines whether the table head cell is sortable
     */
    sortable = false;
    /**
     * determines whether the table head cell is active (currently sorted)
     */
    isActive = false;
    state = 'neutral';
    isActiveWatchHandler(newValue) {
        if (!newValue) {
            this.state = 'neutral';
        }
    }
    toggleOrder = () => {
        const states = ['asc', 'desc', 'neutral'];
        const currentIndex = states.indexOf(this.state);
        this.state = states[(currentIndex + 1) % states.length];
        this.sortCells.emit(this.state);
    };
    render() {
        return (h(Host, { key: 'a5f23ccad069e338d5a3068b9aca444bfcb5dfc9', role: "table-head-cell", class: "sfe-table-head", "data-testid": "sfe-table-head" }, h("span", { key: '237ed7da3418ec9fef6d4d783f34a7e48c140882', class: "sfe-table-head__content", "data-sortable": this.sortable ? 'true' : 'false', onClick: () => this.sortable && this.toggleOrder() }, h("slot", { key: '5a12d94ff5ec17dfa4413c7778f9de5fe4dd7cce' }, this.label), this.sortable && (h("swc-icon-button", { key: 'e602ed0899cef3ac06aaefa8f4019c823240bd1d', intent: "neutral", variant: "bare", "aria-label": "Sort table" }, h("swc-svg-icon", { key: 'f43b20737de9312da2f7b67ac6b38fb09d96c86a', name: "Chevron Down", size: "16", class: {
                'sfe-table-head__content__sort-icon': true,
                [`sfe-table-head__content__sort-icon--${this.isActive ? this.state : 'neutral'}`]: true,
            } }))))));
    }
    static get is() { return "swc-table-head"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-table-head.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-table-head.css"]
        };
    }
    static get properties() {
        return {
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the label for the table head cell"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "sortable": {
                "type": "boolean",
                "attribute": "sortable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the table head cell is sortable"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "isActive": {
                "type": "boolean",
                "attribute": "is-active",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the table head cell is active (currently sorted)"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "state": {}
        };
    }
    static get events() {
        return [{
                "method": "sortCells",
                "name": "sortCells",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the sort button is clicked"
                },
                "complexType": {
                    "original": "state",
                    "resolved": "\"asc\" | \"desc\" | \"neutral\"",
                    "references": {
                        "state": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Table/types.ts::state"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "isActive",
                "methodName": "isActiveWatchHandler"
            }];
    }
}
//# sourceMappingURL=swc-table-head.js.map
