import { h } from "@stencil/core";
export class SwcTabTrigger {
    /**
     * Emitted when the trigger is clicked
     * @internal
     */
    updateActiveTab;
    /**
     * the value of the tab
     */
    value;
    /**
     * the disabled state of the tab
     */
    disabled;
    /**
     * the active tab of the tabs
     * @internal
     */
    activeTab;
    /**
     * the orientation of the tab
     * @internal
     */
    orientation = 'horizontal';
    /**
     * the variant of the tab
     * @internal
     */
    variant = 'underline';
    /**
     * the size of the tab
     * @internal
     */
    size = 'md';
    /**
     * the id of the tab trigger
     */
    idProp;
    /**
     * ids of the tab contents associated with this trigger
     * @internal
     */
    tabContentIds = [];
    /**
     * a unique class name for all the tab triggers within a tabs instance
     * @internal
     */
    tabClass;
    get tabContentId() {
        return this.tabContentIds?.find((id) => id.startsWith(`sfe-tab-content-${this.value}`)) || '';
    }
    handleClick = () => {
        this.updateActiveTab.emit(this.value);
    };
    render() {
        return (h("div", { key: 'df256e02934182dfbfd4ba9b0ead2ba783ed63f4' }, h("button", { key: 'aa37585d6ccbfb32caeac7bff70bf807a546317c', role: "tab", id: this.idProp, "aria-controls": this.tabContentId, "aria-selected": this.value === this.activeTab, "data-testid": "sfe-tab-trigger", disabled: this.disabled, tabindex: this.value === this.activeTab ? 0 : -1, class: {
                'sfe-tab-trigger': true,
                'sfe-tab-trigger--selected': this.value === this.activeTab,
                [`sfe-tab-trigger--${this.variant}`]: true,
                [`sfe-tab-trigger--${this.size}`]: true,
                [`sfe-tab-trigger--${this.orientation}`]: true,
                [this.tabClass]: true,
            }, onClick: this.handleClick }, h("slot", { key: '41a8bffe561693d451ea57e983d20d46432f6734' }))));
    }
    static get is() { return "swc-tab-trigger"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-tab-trigger.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-tab-trigger.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the value of the tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the disabled state of the tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "activeTab": {
                "type": "string",
                "attribute": "active-tab",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "the active tab of the tabs"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "orientation": {
                "type": "string",
                "attribute": "orientation",
                "mutable": false,
                "complexType": {
                    "original": "orientation",
                    "resolved": "\"horizontal\" | \"vertical\"",
                    "references": {
                        "orientation": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::orientation"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "the orientation of the tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'horizontal'"
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "variant",
                    "resolved": "\"button\" | \"shadowButton\" | \"underline\"",
                    "references": {
                        "variant": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::variant"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "the variant of the tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'underline'"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "size",
                    "resolved": "\"md\" | \"sm\"",
                    "references": {
                        "size": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::size"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "the size of the tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'md'"
            },
            "idProp": {
                "type": "string",
                "attribute": "id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the id of the tab trigger"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "tabContentIds": {
                "type": "unknown",
                "attribute": "tab-content-ids",
                "mutable": false,
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "ids of the tab contents associated with this trigger"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "tabClass": {
                "type": "string",
                "attribute": "tab-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "a unique class name for all the tab triggers within a tabs instance"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "updateActiveTab",
                "name": "updateActiveTab",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "Emitted when the trigger is clicked"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-tab-trigger.js.map
