import { useId } from "../../../utils/utils";
import { h } from "@stencil/core";
export class SwcTabs {
    hostElement;
    /**
     * emitted when active tab changes
     */
    viewActiveTab;
    /**
     * value of the default tab
     */
    defaultTab;
    /**
     * variant of the tabs
     */
    variant = 'underline';
    /**
     * orientation of the tabs.
     * Vertical orientation only applies to underline variant.
     */
    orientation = 'horizontal';
    /**
     * size of the tabs
     */
    size = 'md';
    activeTab;
    tabTriggerIds = [];
    tabContentIds = [];
    tabClass = `sfe-tab-trigger-${useId().generate()}`;
    /**
     * injects data into the child components within its instance
     */
    provide = () => {
        const tabTriggers = this.hostElement.querySelectorAll('swc-tab-trigger');
        const tabContents = this.hostElement.querySelectorAll('swc-tab-content');
        const tabContentList = this.hostElement.querySelector('swc-tab-list');
        tabTriggers.forEach((trigger) => {
            trigger.activeTab = this.activeTab;
            trigger.variant = this.variant;
            trigger.orientation = this.orientation;
            trigger.idProp = useId().generate(`sfe-tab-trigger-${trigger.value}`);
            trigger.tabContentIds = this.tabContentIds;
            trigger.tabClass = this.tabClass;
            this.tabTriggerIds.push(trigger.idProp);
        });
        tabContents.forEach((content) => {
            content.activeTab = this.activeTab;
            content.idProp = useId().generate(`sfe-tab-content-${content.value}`);
            content.tabTriggerIds = this.tabTriggerIds;
            this.tabContentIds.push(content.idProp);
        });
        tabContentList.orientation = this.orientation;
        tabContentList.variant = this.variant;
    };
    handleKeydown = (event) => {
        const activeElement = document.activeElement;
        const tabTriggers = Array.from(this.hostElement.querySelectorAll('.sfe-tab-trigger'));
        const currentIndex = tabTriggers.findIndex((el) => el.id === activeElement?.id);
        const isHorizontal = this.orientation === 'horizontal';
        const isVerticalUnderline = this.orientation === 'vertical' && this.variant === 'underline';
        const keyMap = {
            horizontal: { ArrowRight: 1, ArrowLeft: -1 },
            vertical: { ArrowDown: 1, ArrowUp: -1 },
        };
        let direction = 0;
        if (isHorizontal) {
            direction = keyMap.horizontal[event.key] || 0;
        }
        else if (isVerticalUnderline) {
            direction = keyMap.vertical[event.key] || 0;
        }
        if (direction !== 0) {
            let newIndex = currentIndex + direction;
            if (newIndex < 0)
                newIndex = tabTriggers.length - 1;
            if (newIndex >= tabTriggers.length)
                newIndex = 0;
            tabTriggers[newIndex].focus();
            tabTriggers[newIndex].click();
        }
    };
    handleUpdateActiveTab(event) {
        this.activeTab = event.detail;
        this.viewActiveTab.emit(event.detail);
    }
    componentWillLoad() {
        this.activeTab = this.defaultTab;
    }
    render() {
        // calling this.provide inside render ensures reactivity is enabled
        this.provide();
        return (h("div", { key: '8b3ab55380fae31a717ebc84f31145f16564eaf5', "aria-orientation": "orientation", class: `sfe-tabs sfe-tabs--${this.variant} sfe-tabs--${this.orientation}`, "data-testid": "sfe-tabs", onKeyDown: this.handleKeydown }, h("slot", { key: '3ca9503e388d092ebb626bdfbddb91d44bc69ba2' })));
    }
    static get is() { return "swc-tabs"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-tabs.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-tabs.css"]
        };
    }
    static get properties() {
        return {
            "defaultTab": {
                "type": "string",
                "attribute": "default-tab",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "value of the default tab"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "variant",
                    "resolved": "\"button\" | \"shadowButton\" | \"underline\"",
                    "references": {
                        "variant": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::variant"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant of the tabs"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'underline'"
            },
            "orientation": {
                "type": "string",
                "attribute": "orientation",
                "mutable": false,
                "complexType": {
                    "original": "orientation",
                    "resolved": "\"horizontal\" | \"vertical\"",
                    "references": {
                        "orientation": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::orientation"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "orientation of the tabs.\nVertical orientation only applies to underline variant."
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'horizontal'"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "size",
                    "resolved": "\"md\" | \"sm\"",
                    "references": {
                        "size": {
                            "location": "import",
                            "path": "../types",
                            "id": "src/components/Tabs/types.ts::size"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of the tabs"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'md'"
            }
        };
    }
    static get states() {
        return {
            "activeTab": {},
            "tabTriggerIds": {},
            "tabContentIds": {},
            "tabClass": {}
        };
    }
    static get events() {
        return [{
                "method": "viewActiveTab",
                "name": "viewActiveTab",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when active tab changes"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
    static get listeners() {
        return [{
                "name": "updateActiveTab",
                "method": "handleUpdateActiveTab",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=swc-tabs.js.map
