import { h } from "@stencil/core";
// defineEmits(['view:previous', 'view:next', 'dismiss:tour', 'end:tour'])
export class SwcTourGuideStep {
    /**
     * title of the tour step
     */
    heading;
    /**
     * content of the tour step
     */
    content;
    /**
     * determines whether the tour step should be dismissed
     */
    dismissible = false;
    /**
     * determines whether there is a previous step
     */
    hasPrevious = false;
    /**
     * determines whether there is a next step
     */
    hasNext = false;
    /**
     * determines whether the tour step is the last step
     */
    isLastStep = false;
    /**
     * the position of the current tour step
     */
    currentIndex = 0;
    /**
     * the number of steps in the tour guide
     */
    numberOfSteps = 1;
    /**
     * determines whether the tour should begin
     */
    startTour = false;
    /**
     * variant of the tour guide
     */
    variant;
    /**
     * emitted when the previous button is clicked
     */
    viewPrevious;
    /**
     * emitted when the next button is clicked
     */
    viewNext;
    /**
     * emitted when the next button is clicked
     */
    dismissTour;
    /**
     * emitted when the next button is clicked
     */
    endTour;
    handleDismissTour = () => {
        this.dismissTour.emit();
    };
    handleNext = () => {
        this.viewNext.emit();
    };
    handlePrevious = () => {
        this.viewPrevious.emit();
    };
    handleEndTour = () => {
        this.endTour.emit();
    };
    render() {
        return (this.startTour && (h("div", { key: '58af14186b6ec2e2bb4337aa13e38201687e9dfd', class: { [`sfe-tour-guide-step sfe-tour-guide-step--${this.variant}`]: true }, "data-testid": "sfe-tour-guide-step" }, h("div", { key: '549447c42fbffa03ad7ecbd41ccaa8561a45e16c', class: "flex-wrapper" }, h("p", { key: '2a77b6ddd96b9bf01777be20894d1cf035eb7c28', class: "sfe-tour-guide-step__title m-0", innerHTML: this.heading }), h("swc-icon-button", { key: 'dbf0501922b0d46d8e7b0c050f4981692e27616c', "v-if": "dismissible", "aria-label": "dismiss tour", intent: this.variant === 'light' ? 'neutral' : 'inverse', variant: "bare", size: "sm", round: true, onClick: this.handleDismissTour }, h("swc-svg-icon", { key: '211b2b569ac8992d389c3de1360a5bf2149f127c', name: "Dismiss", color: "currentColor", size: "12" }))), h("div", { key: '5a9bf51354ffa1ff71487ce4804b4787ef91722e', class: "sfe-tour-guide-step__content", innerHTML: this.content }), h("div", { key: '240c6b631f98ea3765c5b709a9ee97b6a7e13a06', class: "flex-wrapper col-gap-10" }, h("p", { key: 'c431da0e3a354cb3eea8e4d0ff44f0db2bcf6b66', class: "sfe-tour-guide-step__steps-info m-0" }, this.currentIndex + 1, " of ", this.numberOfSteps), h("div", { key: '08925f391474fad00b292c6cc0589e43f88cf0bc' }, this.hasPrevious && (h("swc-button", { key: '472fe0bd4e0a5ecb29a21593ec07a2d83a11436a', intent: this.variant === 'light' ? 'brand' : 'inverse', variant: "bare", size: "xs", class: "sfe-tour-guide-step__back-btn", onClick: this.handlePrevious }, "Back")), this.hasNext && (h("swc-button", { key: '49e6d45085cbb6c2d45a90ae5493011c599f7b1d', intent: this.variant === 'light' ? 'brand' : 'inverse', size: "xs", onClick: this.handleNext }, "Next")), this.isLastStep && (h("swc-button", { key: 'd40c1c4c061e638a3009c7043a4275da347d8372', intent: this.variant === 'light' ? 'brand' : 'inverse', size: "xs", onClick: this.handleEndTour }, "Done")))))));
    }
    static get is() { return "swc-tour-guide-step"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-tour-guide-step.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-tour-guide-step.css"]
        };
    }
    static get properties() {
        return {
            "heading": {
                "type": "string",
                "attribute": "heading",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "title of the tour step"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "content": {
                "type": "string",
                "attribute": "content",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "content of the tour step"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "dismissible": {
                "type": "boolean",
                "attribute": "dismissible",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the tour step should be dismissed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "hasPrevious": {
                "type": "boolean",
                "attribute": "has-previous",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether there is a previous step"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "hasNext": {
                "type": "boolean",
                "attribute": "has-next",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether there is a next step"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "isLastStep": {
                "type": "boolean",
                "attribute": "is-last-step",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the tour step is the last step"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "currentIndex": {
                "type": "number",
                "attribute": "current-index",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the position of the current tour step"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "0"
            },
            "numberOfSteps": {
                "type": "number",
                "attribute": "number-of-steps",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the number of steps in the tour guide"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "1"
            },
            "startTour": {
                "type": "boolean",
                "attribute": "start-tour",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the tour should begin"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'light' | 'brand'",
                    "resolved": "\"brand\" | \"light\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant of the tour guide"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "viewPrevious",
                "name": "viewPrevious",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the previous button is clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "viewNext",
                "name": "viewNext",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the next button is clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "dismissTour",
                "name": "dismissTour",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the next button is clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "endTour",
                "name": "endTour",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the next button is clicked"
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-tour-guide-step.js.map
