import { h } from "@stencil/core";
export class SwcButton {
    /**
     * the intent of the button
     */
    intent = 'brand';
    /**
     * the variant of the button
     */
    variant = 'solid';
    /**
     * the size of the button
     */
    size = 'md';
    /**
     * width of the button
     */
    width = 'auto';
    /**
     * determines whether the button is disabled
     */
    disabled = false;
    /**
     * the type of the button
     */
    type = 'button';
    /**
     * determines whether the button should be round in shape
     */
    round = false;
    /**
     * determines whether the button is an icon button
     * @internal
     */
    isIcon = false;
    customClass = '';
    /**
     * event emitted when the button is focused
     */
    focus;
    handleFocus = () => {
        this.focus.emit();
    };
    render() {
        return (h("button", { key: '59de105ba59613536ce67790d335a3096fa8ac32', disabled: this.disabled, type: this.type, class: {
                'sfe-btn': true,
                [`sfe-btn-${this.variant}-${this.intent}`]: true,
                [`sfe-btn-${this.size}`]: !this.isIcon,
                [`sfe-icon-btn-${this.size}`]: this.isIcon,
                'sfe-icon-btn-round': this.isIcon && this.round,
                [`${this.customClass}`]: true,
                'cursor-pointer': true,
            }, style: { width: this.width }, onFocus: this.handleFocus, "data-testid": "sfe-button" }, h("slot", { key: '9b49baf63f8eabc43043824425e6d799ccb7a456' })));
    }
    static get is() { return "swc-button"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-button.css"]
        };
    }
    static get properties() {
        return {
            "intent": {
                "type": "string",
                "attribute": "intent",
                "mutable": false,
                "complexType": {
                    "original": "'brand' | 'neutral' | 'critical' | 'positive' | 'inverse'",
                    "resolved": "\"brand\" | \"critical\" | \"inverse\" | \"neutral\" | \"positive\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the intent of the button"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'brand'"
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'solid' | 'outline' | 'faded' | 'ghost' | 'bare'",
                    "resolved": "\"bare\" | \"faded\" | \"ghost\" | \"outline\" | \"solid\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the variant of the button"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'solid'"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "'xs' | 'sm' | 'md' | 'lg'",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xs\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the size of the button"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'md'"
            },
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width of the button"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'auto'"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the button is disabled"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "'submit' | 'reset' | 'button'",
                    "resolved": "\"button\" | \"reset\" | \"submit\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "the type of the button"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'button'"
            },
            "round": {
                "type": "boolean",
                "attribute": "round",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the button should be round in shape"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "isIcon": {
                "type": "boolean",
                "attribute": "is-icon",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": undefined
                        }],
                    "text": "determines whether the button is an icon button"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "customClass": {
                "type": "string",
                "attribute": "custom-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get events() {
        return [{
                "method": "focus",
                "name": "focus",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event emitted when the button is focused"
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-button.js.map
