import { h, Host } from "@stencil/core";
import { tabbable } from "tabbable";
export class SwcModalRoot {
    el;
    isModalOpen = false;
    closeOnOverlayClick = true;
    closeOnEsc = true;
    initialFocusRef;
    closeModal;
    triggerElement = null;
    handleOpenChange(newValue) {
        if (newValue) {
            this.openDialog();
        }
        else {
            this.closeDialog();
        }
    }
    handleEscapeKey(event) {
        if (this.closeOnEsc && event.key === 'Escape') {
            this.closeDialog();
        }
    }
    openDialog() {
        this.triggerElement = document.activeElement;
        document.body.classList.add('sfe-body-scroll-disable');
        requestAnimationFrame(() => this.trapFocus());
    }
    closeDialog() {
        this.closeModal.emit();
        document.body.classList.remove('sfe-body-scroll-disable');
        if (this.triggerElement) {
            this.triggerElement.focus();
        }
    }
    handleOverlayClick(event) {
        if (this.closeOnOverlayClick &&
            this.closeOnEsc &&
            event.target.classList.contains('sfe-dialog-overlay')) {
            this.closeDialog();
        }
    }
    trapFocus() {
        const modalContent = this.el.querySelector('.modal-content');
        if (!modalContent)
            return;
        const focusableElements = tabbable(modalContent);
        if (focusableElements.length > 0) {
            ;
            focusableElements[0].focus();
        }
        modalContent.addEventListener('keydown', (event) => {
            const keyboardEvent = event;
            if (keyboardEvent.key === 'Tab') {
                const firstElement = this.initialFocusRef
                    ? this.initialFocusRef
                    : focusableElements[0];
                const lastElement = focusableElements[focusableElements.length - 1];
                if (keyboardEvent.shiftKey && document.activeElement === firstElement) {
                    keyboardEvent.preventDefault();
                    lastElement.focus();
                }
                else if (!keyboardEvent.shiftKey && document.activeElement === lastElement) {
                    keyboardEvent.preventDefault();
                    firstElement.focus();
                }
            }
        });
    }
    connectedCallback() {
        document.addEventListener('keydown', (event) => this.handleEscapeKey(event));
    }
    disconnectedCallback() {
        document.removeEventListener('keydown', (event) => this.handleEscapeKey(event));
    }
    render() {
        return (h(Host, { key: 'b4a9ead7f0153042a94dc767d66f9ec86301b485' }, h("div", { key: 'beb60d361bb55e20fecb3476242e30fd12aeca04', style: { display: `${this.isModalOpen ? 'flex' : 'none'}` }, class: "sfe-dialog-overlay", tabindex: "-1", onClick: (event) => this.handleOverlayClick(event) }, h("div", { key: '7ea4b61db3c98b1126e27e77655c0eff81e9e3e4', class: "modal-content" }, h("slot", { key: 'e23c50b58202a714b7aef48fa96e24bf1e3021ba' })))));
    }
    static get is() { return "swc-modal-root"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-modal-root.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-modal-root.css"]
        };
    }
    static get properties() {
        return {
            "isModalOpen": {
                "type": "boolean",
                "attribute": "is-modal-open",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "closeOnOverlayClick": {
                "type": "boolean",
                "attribute": "close-on-overlay-click",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "closeOnEsc": {
                "type": "boolean",
                "attribute": "close-on-esc",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "initialFocusRef": {
                "type": "unknown",
                "attribute": "initial-focus-ref",
                "mutable": false,
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement | undefined",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get events() {
        return [{
                "method": "closeModal",
                "name": "closeModal",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "isModalOpen",
                "methodName": "handleOpenChange"
            }];
    }
}
//# sourceMappingURL=swc-modal-root.js.map
