import { h, Host, } from "@stencil/core";
import { intentConfig, iconStyleConfig, styleConfig, variantConfig, positionConfig } from "./config";
export class SwcAlert {
    hostElement;
    /** Display message */
    message = 'Display the message here';
    /** Intent: solid | subtle */
    intent = intentConfig.solid;
    /** Variant: info | error | success | warning */
    variant = variantConfig.info;
    /** Position: top | bottom */
    position = positionConfig.top;
    isVisible = false;
    /** Aria label for dismiss button */
    iconButtonAriaLabel = 'Dismiss alert';
    alertDismissed;
    alertIcon = {};
    dismissIconColor = this.computeDismissIconColor();
    handlePropChange() {
        this.alertIcon = this.computeAlertIcon();
        this.dismissIconColor = this.computeDismissIconColor();
    }
    async show() {
        this.isVisible = true;
        return Promise.resolve();
    }
    async hide() {
        this.isVisible = false;
        this.alertDismissed.emit();
        return Promise.resolve();
    }
    computeAlertIcon() {
        const iconColor = this.intent === intentConfig.solid
            ? 'var(--sfe-color-icon-default-inverted-secondary)'
            : styleConfig[this.variant][this.intent].iconColor;
        const alertIconVariant = this.intent === intentConfig.solid ? iconStyleConfig.outline : iconStyleConfig.filled;
        return {
            name: styleConfig[this.variant].icon,
            color: iconColor,
            variant: alertIconVariant,
        };
    }
    computeDismissIconColor() {
        return this.intent === intentConfig.solid
            ? 'var(--sfe-color-icon-default-inverted-secondary)'
            : 'var(--sfe-color-icon-default-primary)';
    }
    dismissAlert = () => this.hide();
    componentWillLoad() {
        this.handlePropChange();
    }
    render() {
        return (h(Host, { key: 'd4c66e0f5f7ace4245a8cb2afafe96f543387a4e' }, this.isVisible && (h("div", { key: '0c5afa3f1c7852945afcef9d6f495a80afeebb01', role: "alert", class: `sfe-alert ${this.variant} ${this.intent} ${this.position}`, "aria-labelledby": "sfe-alert__display-text-id", "data-testid": "sfe-alert" }, h("div", { key: '00b21e2aacb9ccb9f4d495b6059500a05fc0eed0', class: "sfe-alert__message-group" }, h("swc-svg-icon", { key: 'fb9b98dfa885c696fb432425eba82f7a0165da94', name: this.alertIcon?.name, variant: 'filled', size: "16", color: this.alertIcon?.color }), h("p", { key: '5228494894b3ad36e85870f4f80014f71a7d8672', class: "sfe-alert__display-text", id: "sfe-alert__display-text-id" }, this.message)), h("div", { key: '2bcf4c71fb105827ddc57a58923c20fe435dda88', class: "sfe-alert__icon-group", onClick: this.dismissAlert }, h("swc-button", { key: '75173cd5874cbd08eb805f53b226886a4c582266', intent: "neutral", variant: "bare", "aria-label": this.iconButtonAriaLabel }, h("swc-svg-icon", { key: 'e0ca75873e8911c80eb54894920b1df22015cd90', name: "Dismiss", variant: "filled", size: "16", color: this.dismissIconColor })))))));
    }
    static get is() { return "swc-alert"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-alert.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-alert.css"]
        };
    }
    static get properties() {
        return {
            "message": {
                "type": "string",
                "attribute": "message",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Display message"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Display the message here'"
            },
            "intent": {
                "type": "string",
                "attribute": "intent",
                "mutable": false,
                "complexType": {
                    "original": "'solid' | 'subtle'",
                    "resolved": "\"solid\" | \"subtle\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Intent: solid | subtle"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "intentConfig.solid"
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'info' | 'error' | 'success' | 'warning'",
                    "resolved": "\"error\" | \"info\" | \"success\" | \"warning\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Variant: info | error | success | warning"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "variantConfig.info"
            },
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "'top' | 'bottom'",
                    "resolved": "\"bottom\" | \"top\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Position: top | bottom"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "positionConfig.top"
            },
            "isVisible": {
                "type": "boolean",
                "attribute": "is-visible",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "iconButtonAriaLabel": {
                "type": "string",
                "attribute": "icon-button-aria-label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Aria label for dismiss button"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Dismiss alert'"
            }
        };
    }
    static get states() {
        return {
            "alertIcon": {},
            "dismissIconColor": {}
        };
    }
    static get events() {
        return [{
                "method": "alertDismissed",
                "name": "alertDismissed",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "show": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "hide": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=swc-alert.js.map
