import { h } from "@stencil/core";
export class SwcBanner {
    /**
     * variant of the banner
     */
    variant = 'success';
    /**
     * determines whether the banner icon should be displayed
     */
    showTitleIcon = true;
    /**
     * determines whether the banner can be dismissed
     */
    dismissible = true;
    titleId = `banner-title-${this.generateUniqueId()}`;
    bodyId = `banner-body-${this.generateUniqueId()}`;
    /**
     * event emitted when the banner close icon is clicked
     */
    close;
    get classes() {
        let iconFill = '';
        let icon = 'Checkmark Circle';
        switch (this.variant) {
            case 'neutral':
                iconFill = 'var(--sfe-color-icon-default-secondary)';
                break;
            case 'info':
                iconFill = 'var(--sfe-color-icon-info-primary)';
                break;
            case 'warning':
                iconFill = 'var(--sfe-color-icon-warning-primary)';
                icon = 'Error Circle';
                break;
            case 'error':
                icon = 'Warning';
                iconFill = 'var(--sfe-color-icon-critical-primary)';
                break;
            case 'success':
                iconFill = 'var(--sfe-color-icon-positive-primary)';
                break;
        }
        return { iconFill, icon };
    }
    generateUniqueId() {
        return Math.random().toString(36).substring(2, 9);
    }
    handleCloseIconClick = () => {
        this.close.emit();
    };
    render() {
        const { variant, showTitleIcon, dismissible, titleId, bodyId, classes } = this;
        return (h("div", { key: 'dcfe35ab9c8f75705559f4eefcf3163f9b36accb', role: "banner", class: `d-flex sfe-banner__parent ${variant}`, "aria-labelledby": titleId, "aria-describedby": bodyId, "data-testid": "sfe-banner" }, showTitleIcon && (h("div", { key: '0dfa05e14ccd296723806638bcd6c559bf344d55', class: "sfe-banner__title-container" }, h("slot", { key: '6b4aedc0d217179b2ed9b32820599ca665a029c5', name: "titleIcon" }, h("swc-svg-icon", { key: '5fc6a7fbd3aeddc98ada0c673ffd137a261a0019', name: classes.icon, variant: "filled", color: classes.iconFill, size: "20" })), h("span", { key: '6f43fb540a18472c9a508ae7b8b30136fd00b2f2', id: titleId, class: "sfe-banner__title" }, h("slot", { key: 'e4b9f714d785fafcec6ad588a1e52cfa25bb8274', name: "title" })), dismissible && (h("button", { key: 'e07977b79b7fb79acfffe51c272d66e4d468e770', id: "close_icon", class: "sfe-banner__close-icon ml-auto", "aria-label": "Close banner", onClick: this.handleCloseIconClick }, h("slot", { key: 'f53238bb3ca1796f3ac1ed91ca9b0acb2263d3f3', name: "closeIcon" }, h("swc-svg-icon", { key: '7cd262cf70f6238c84b6127c76f2002b4e984fea', name: "Dismiss", size: "16" })))))), h("div", { key: '5e4e3e175c4d4eed31fb265fc30cfcf96c1714a4' }, h("section", { key: '87dba236d36a6f6bf2f82df7d3b065bb7c73b470', id: bodyId, class: "sfe-banner__body" }, h("slot", { key: '63b655be8b05cf2b770a1a791c4021fb650aacd1', name: "body" })), h("section", { key: '76f0edcb1b40574aeee7f60c8124d176264cdea5', class: "sfe-banner__footer" }, h("slot", { key: '478aa91ec31e74316e535ed4c6f15a588bd1b6a5', name: "footer" })))));
    }
    static get is() { return "swc-banner"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-banner.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-banner.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant of the banner"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'success'"
            },
            "showTitleIcon": {
                "type": "boolean",
                "attribute": "show-title-icon",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the banner icon should be displayed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "dismissible": {
                "type": "boolean",
                "attribute": "dismissible",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the banner can be dismissed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "titleId": {},
            "bodyId": {}
        };
    }
    static get events() {
        return [{
                "method": "close",
                "name": "close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event emitted when the banner close icon is clicked"
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
}
//# sourceMappingURL=swc-banner.js.map
