import { h, Host } from "@stencil/core";
import { useId } from "../../utils/utils";
export class SwcCheckbox {
    /**
     * value for the checkbox component
     */
    value;
    /**
     * checked value for the checkbox component
     */
    checked = false;
    /**
     * error detector for the checkbox component
     */
    error = false;
    /**
     * disabled for the checkbox component
     */
    disabled = false;
    /**
     * falseValue for the checkbox component
     */
    falseValue;
    /**
     * label for the checkbox component
     */
    label;
    /**
     * isIndeterminate for the checkbox component
     */
    isIndeterminate = false;
    /**
     * updateSelection event for the checkbox component
     */
    checkboxChange;
    checkboxHostElement;
    checkboxId = `${useId().generate('_checkbox_')}`;
    handleChange = (event) => {
        const checkedEvent = event.target.checked;
        this.checked = checkedEvent;
        if (checkedEvent) {
            if (typeof this.value === 'boolean') {
                this.checkboxChange.emit({ value: true, checked: checkedEvent });
            }
            else {
                this.checkboxChange.emit({ value: this.value, checked: checkedEvent });
            }
        }
        else {
            // this.checkboxChange.emit({ value: this.falseValue ?? false, checked: checkedEvent })
            if (typeof this.value === 'boolean') {
                this.checkboxChange.emit({ value: this.falseValue ?? false, checked: false });
            }
            else {
                this.checkboxChange.emit({ value: this.value, checked: false });
            }
        }
    };
    render() {
        const idAttribute = this.checkboxHostElement.getAttribute('id');
        return (h(Host, { key: 'c8b5098d60f6972ab93717f65d83d1e85e18b8b8' }, h("div", { key: '24d83cd6bd00512c1580a0d4c28d29e1afbdb47b', class: "sfe-checkbox-container" }, h("input", { key: '3ef87a4edc5558c73c23d71bd31ea8965672c646', type: "checkbox", id: idAttribute || this.checkboxId, value: this.value, checked: this.checked, "data-testid": "sfe-checkbox", disabled: this.disabled, class: {
                'sfe-checkbox': true,
                'sfe-checkbox--error': this.error,
                checked: this.checked,
            }, indeterminate: this.isIndeterminate, onChange: this.handleChange }), this.label && (h("swc-label", { key: 'dcb73b896e320357197eda92916e76d978601dca', for: idAttribute || this.checkboxId, disabled: this.disabled, size: "md", class: "sfe-checkbox-label", "data-for": this.checkboxId || idAttribute }, this.label)))));
    }
    static get is() { return "swc-checkbox"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-checkbox.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-checkbox.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "value for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "checked": {
                "type": "boolean",
                "attribute": "checked",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "checked value for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "error": {
                "type": "boolean",
                "attribute": "error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "error detector for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "falseValue": {
                "type": "string",
                "attribute": "false-value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "falseValue for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "label for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "isIndeterminate": {
                "type": "boolean",
                "attribute": "is-indeterminate",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "isIndeterminate for the checkbox component"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "checkboxChange",
                "name": "checkboxChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "updateSelection event for the checkbox component"
                },
                "complexType": {
                    "original": "{ value: string | boolean; checked: boolean }",
                    "resolved": "{ value: string | boolean; checked: boolean; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "checkboxHostElement"; }
}
//# sourceMappingURL=swc-checkbox.js.map
