import { h } from "@stencil/core";
export class SwcCircularProgress {
    /**
     * value of the circular progress
     */
    value = 0;
    /**
     * color of the circular progress
     */
    color = '--sfe-color-border-brand-solid';
    /**
     * determines if the value should be shown
     */
    showValue = true;
    /**
     * maximum value of the circular progress
     */
    max = 100;
    /**
     * size of the circular progress
     */
    size = 'md';
    progression = 0;
    intervalId;
    get computedPercentage() {
        if (this.value < 0)
            return 0;
        if (this.value > this.max)
            return 100;
        return Math.round((this.value / this.max) * 100);
    }
    get circleAttributes() {
        return this.size === 'sm'
            ? { cx: 12, cy: 12, r: 10.5 }
            : this.size === 'md'
                ? { cx: 20, cy: 20, r: 18.5 }
                : { cx: 28, cy: 28, r: 26.5 };
    }
    get circumference() {
        return 2 * Math.PI * this.circleAttributes.r;
    }
    get offset() {
        return this.circumference - (this.progression / 100) * this.circumference;
    }
    get viewBoxSize() {
        return this.size === 'sm' ? 24 : this.size === 'md' ? 40 : 56;
    }
    animateProgression() {
        clearInterval(this.intervalId);
        this.intervalId = setInterval(() => {
            if (this.progression >= this.computedPercentage) {
                clearInterval(this.intervalId);
            }
            else {
                this.progression++;
            }
        }, 20);
    }
    componentDidLoad() {
        this.animateProgression();
    }
    render() {
        return (h("div", { key: '2d9a5d7397f3d5ffe430bbc258318daa714d15ce', class: `sfe-circular-progress sfe-circular-progress--${this.size}`, role: "progressbar", "aria-valuenow": this.progression }, h("svg", { key: 'cd678a0529d29f819dbd54120f031d8b4d4a1b07', class: "sfe-circular-progress__svg", viewBox: `0 0 ${this.viewBoxSize} ${this.viewBoxSize}` }, h("circle", { key: '0d7f2b9c92247cc1ddfbbae7f4012d052d780f39', class: "sfe-circular-progress__background", cx: this.circleAttributes.cx, cy: this.circleAttributes.cy, r: this.circleAttributes.r, fill: "none", stroke: "var(--sfe-color-border-brand-surface, #E4EDFC)", "stroke-width": "3" }), h("circle", { key: '245fa07587630a7de632d6e87c2b24a3dc98dbd6', class: "sfe-circular-progress__progress", cx: this.circleAttributes.cx, cy: this.circleAttributes.cy, r: this.circleAttributes.r, fill: "none", stroke: `var(${this.color})`, "stroke-width": "3", "stroke-linecap": "round", style: {
                strokeDasharray: `${this.circumference} ${this.circumference}`,
                strokeDashoffset: `${this.offset}`,
            } })), this.showValue && this.size !== 'sm' && (h("span", { key: '75334eaf64c744fba1007dc2d15cbe385b112041', class: "sfe-circular-progress__percentage" }, `${this.progression}%`))));
    }
    static get is() { return "swc-circular-progress"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-circular-progress.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-circular-progress.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "number",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "value of the circular progress"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "0"
            },
            "color": {
                "type": "string",
                "attribute": "color",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "color of the circular progress"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'--sfe-color-border-brand-solid'"
            },
            "showValue": {
                "type": "boolean",
                "attribute": "show-value",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines if the value should be shown"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "max": {
                "type": "number",
                "attribute": "max",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "maximum value of the circular progress"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "100"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "'sm' | 'md' | 'lg'",
                    "resolved": "\"lg\" | \"md\" | \"sm\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of the circular progress"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'md'"
            }
        };
    }
    static get states() {
        return {
            "progression": {}
        };
    }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "animateProgression"
            }];
    }
}
//# sourceMappingURL=swc-circular-progress.js.map
