import { h } from "@stencil/core";
export class SwcClickable {
    /**
     * The HTML tag to be rendered on the DOM
     */
    as = 'button';
    /**
     * disabled state
     */
    disabled = false;
    /**
     * emitted when the element is clicked
     */
    click;
    el;
    handleClick = (event) => {
        if (this.disabled) {
            event.preventDefault();
            event.stopPropagation();
            return;
        }
    };
    handleKeyDown = (event) => {
        if (this.disabled)
            return;
        if (event.key === 'Enter' || event.key === ' ') {
            this.click.emit(event);
        }
    };
    render() {
        const Tag = this.as;
        const attrs = Array.from(this.el.attributes)
            .filter((attr) => attr.name !== 'as') // Remove "as" attribute
            .reduce((acc, attr) => {
            acc[attr.name] = attr.value;
            return acc;
        }, {});
        return (h(Tag, { "data-testid": "sfe-clickable", disabled: this.disabled, tabindex: this.disabled ? -1 : 0, role: this.as === 'button' ? 'null' : 'button', class: { clickable: true, disabled: this.disabled }, onClick: this.handleClick, onKeyDown: this.handleKeyDown, ...attrs }, h("slot", null)));
    }
    static get is() { return "swc-clickable"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-clickable.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-clickable.css"]
        };
    }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "attribute": "as",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The HTML tag to be rendered on the DOM"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'button'"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled state"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "click",
                "name": "click",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "emitted when the element is clicked"
                },
                "complexType": {
                    "original": "Event",
                    "resolved": "Event",
                    "references": {
                        "Event": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "../../node_modules/@stencil/core/internal/stencil-core/index.d.ts::Event"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=swc-clickable.js.map
