import { Host, h } from "@stencil/core";
export class SwcInput {
    /**
     * variant of the input
     */
    variant = 'outline';
    /**
     * determines whether a clear icon should be displayed
     */
    clearable = false;
    /**
     * determines whether the input has error
     */
    hasError = false;
    /**
     * determines whether the input is disabled
     */
    disabled = false;
    /**
     * the class name of the input container
     */
    containerClass = '';
    /**
     * default value of the input
     */
    value;
    /**
     * handleInputChange
     */
    handleInputChange;
    /**
     * default value of the input
     */
    placeholder = '';
    /**
     * type prop
     */
    type = '';
    hostElement;
    /**
     * change event
     */
    change;
    handleInput = (event) => {
        const input = event.target;
        this.change.emit(input);
    };
    clearInput = () => {
        this.handleInputChange('');
    };
    get className() {
        let inputedStyle = '';
        if (this.disabled || this.hasError) {
            inputedStyle = this.disabled ? `disabled ${this.variant}` : `input_error ${this.variant}`;
        }
        else {
            inputedStyle = this.variant;
        }
        return inputedStyle;
    }
    get showClearable() {
        return !this.disabled && this.clearable && this.value;
    }
    get searchInput() {
        if (this.hostElement.getAttribute('type') === 'search') {
            return 'search';
        }
        else {
            return '';
        }
    }
    render() {
        return (h(Host, { key: 'e6199141aa698c48783200b6a1529a92296ec082' }, h("div", { key: 'd61d5f353599036283202f68686380c5587c85ce', style: { display: 'flex', alignItems: 'center' }, class: `input_wrapper ${this.className} ${this.searchInput} ${this.containerClass}`, "data-testid": "sfe-input" }, h("slot", { key: '2c2e9be9b68e5a285af44663500155fcee208205', name: "leftAddon" }), h("input", { key: 'ad90cc60219474d0343d988ae43e9ac2672d5a44', type: this.type,
            min: 0,
            placeholder: this.placeholder,
            value: this.value,
            class: 'px-2 w-100 input-field',
            disabled: this.disabled,
            onInput: this.handleInput }), this.showClearable && (h("span", { key: 'c082a2764a70521fc13c832afeea14e72de91344', class: `material-icons ${!this.disabled ? 'cursor-pointer' : ''}`, role: "button", onClick: this.clearInput }, "cancel")), h("span", { key: 'e4c02ed150cf13525ea6ea36a99d19f8b8c92495', class: "slot" }, h("slot", { key: '26814dd58c4956975297faee95f62e3826fd4ca2', name: "rightAddon" })))));
    }
    static get is() { return "swc-input"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-input.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-input.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'outline' | 'faded' | 'ghost' | 'inline'",
                    "resolved": "\"faded\" | \"ghost\" | \"inline\" | \"outline\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant of the input"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'outline'"
            },
            "clearable": {
                "type": "boolean",
                "attribute": "clearable",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "determines whether a clear icon should be displayed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "hasError": {
                "type": "boolean",
                "attribute": "has-error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "determines whether the input has error"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "determines whether the input is disabled"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "containerClass": {
                "type": "string",
                "attribute": "container-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "the class name of the input container"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "default value of the input"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "handleInputChange": {
                "type": "unknown",
                "attribute": "handle-input-change",
                "mutable": false,
                "complexType": {
                    "original": "(value: string) => void",
                    "resolved": "(value: string) => void",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "handleInputChange"
                },
                "getter": false,
                "setter": false
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "default value of the input"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "type prop"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get events() {
        return [{
                "method": "change",
                "name": "change",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "change event"
                },
                "complexType": {
                    "original": "HTMLInputElement",
                    "resolved": "HTMLInputElement",
                    "references": {
                        "HTMLInputElement": {
                            "location": "global",
                            "id": "global::HTMLInputElement"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=swc-input.js.map
