import { h } from "@stencil/core";
export class SwcLabel {
    /**
     * determines whether text field the label describes is a required field
     */
    required = false;
    /**
     * determines whether text field the label describes is disabled
     */
    disabled = false;
    /**
     * size of the label
     */
    size = 'sm';
    /**
     * determines whether the label emphasizes the field's content
     */
    emphasis = 'subtle';
    /**
     * position of the label's caption
     */
    captionPlacement = 'vertical';
    /**
     * determines whether to show the icon in the label
     */
    showLabelIcon = true;
    /**
     * for attribute
     */
    for;
    get labelClasses() {
        return {
            [`sfe-label--${this.size}`]: true,
            [`sfe-label--${this.emphasis}`]: true,
            'sfe-label--disabled': this.disabled,
            [`sfe-label-${this.captionPlacement}`]: true,
        };
    }
    get captionClasses() {
        return `sfe-label-${this.captionPlacement}`;
    }
    render() {
        return (h("label", { key: 'cbd38cff8cb8ce938aff1c8d7d8de684d11c9130', htmlFor: this.for, class: { ...this.labelClasses }, "data-testid": "sfe-label" }, h("span", { key: '9917f6804574bae64b6ce81b51b0ee0d79ee5a75', class: { 'sfe-label--required': this.required, 'sfe-label sfe-label-content': true } }, h("span", { key: '5ffd47e466bc34e0d1555254e58418b9caf73ffe' }, h("slot", { key: 'c7ad32d0c43251791cc601a01ce79523acbba1ff' })), this.captionPlacement === 'horizontal' && (h("div", { key: 'e8aaa9e177d623c60ba30231ec29b2c448e31073', class: this.captionClasses }, h("slot", { key: 'a84aadbc58e365f26a45cc02abe5cdebfdb039d0', name: "caption" }))), this.showLabelIcon && (h("span", { key: 'c8449ff656749604c2353ece57350bb708b9cac2', style: { 'margin-left': '8px' } }, h("slot", { key: '76211cfcfe24a311f27857f44011e5f88a5747a3', name: "icon" })))), this.captionPlacement === 'vertical' && (h("div", { key: '3986ca7a08d9827a987915cbee2332ab3456b30b', class: this.captionClasses }, h("slot", { key: '4e200994a8441708e806262d3889f142408317e2', name: "caption" })))));
    }
    static get is() { return "swc-label"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-label.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-label.css"]
        };
    }
    static get properties() {
        return {
            "required": {
                "type": "boolean",
                "attribute": "required",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether text field the label describes is a required field"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether text field the label describes is disabled"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "'xs' | 'sm' | 'md' | 'lg'",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xs\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of the label"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'sm'"
            },
            "emphasis": {
                "type": "string",
                "attribute": "emphasis",
                "mutable": false,
                "complexType": {
                    "original": "'subtle' | 'solid'",
                    "resolved": "\"solid\" | \"subtle\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the label emphasizes the field's content"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'subtle'"
            },
            "captionPlacement": {
                "type": "string",
                "attribute": "caption-placement",
                "mutable": false,
                "complexType": {
                    "original": "'vertical' | 'horizontal'",
                    "resolved": "\"horizontal\" | \"vertical\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "position of the label's caption"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'vertical'"
            },
            "showLabelIcon": {
                "type": "boolean",
                "attribute": "show-label-icon",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether to show the icon in the label"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "for": {
                "type": "string",
                "attribute": "for",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "for attribute"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=swc-label.js.map
