import { Host, h } from "@stencil/core";
import { useId } from "../../utils/utils";
import tippy from "tippy.js";
import { hideOnEsc } from "../plugin";
export class SwcPopover {
    /** * content of the popover which is a string display when the popover appears, default value is empty string */
    content = '';
    /** * showArrow determine if the popover will display arrow pointer or not */
    showArrow = true;
    /**
     * showContent determines if the content of the tooltip should be shown
     */
    showContent = true;
    /** * position tells the placement of the popover in relation to the trigger element */
    position = 'top';
    hostElement;
    triggerId = `sfe-popover-trigger-${useId().generate()}`;
    contentElementRef;
    tippyInstance;
    initPopover = () => {
        const instance = tippy(this.hostElement.querySelector(`#${this.triggerId}`), {
            theme: this.showContent ? 'popover' : 'hide',
            content: this.computedPopoverContent,
            animation: 'shift-toward',
            placement: this.position,
            allowHTML: true,
            trigger: 'click',
            arrow: this.showArrow,
            interactive: true,
            role: 'dialog',
            maxWidth: 'none',
            plugins: [hideOnEsc],
            zIndex: 999999,
        });
        if (Array.isArray(instance) && instance.length > 0) {
            this.tippyInstance = instance[0];
        }
    };
    get getPopoverId() {
        if (this.tippyInstance) {
            return `tippy-${this.tippyInstance.id}`;
        }
        else {
            return '';
        }
    }
    get computedPopoverContent() {
        if (this.contentElementRef) {
            return this.contentElementRef.innerHTML?.trim().length > 0
                ? this.contentElementRef.innerHTML
                : this.content;
        }
        return this.content;
    }
    componentDidLoad() {
        this.initPopover();
    }
    disconnectedCallback() {
        if (this.tippyInstance) {
            this.tippyInstance.destroy();
        }
    }
    render() {
        return (h(Host, { key: '49e98ed0e44307190a636eb3071d984a828922fa' }, h("div", { key: '72c7a7fa1eb7621e391b155ea30fca565fd6e50c', class: "sfe-popover", "data-testid": "sfe-popover" }, h("div", { key: 'ca00baba232495fc7c48511ed5d739918024f650' }, h("div", { key: '72e66675d46e3f8b0baf05ed68a2f5959ae30115', id: this.triggerId, "aria-haspopup": "dialog", "aria-describedby": this.getPopoverId, style: { width: 'fit-content' } }, h("slot", { key: '036666f3cc71dfa4ccfc0c2f1ba196999f9d00b0', name: "trigger" }))), h("div", { key: 'cb163d6501db8a8318f836538f73cea2de177b0f', ref: (el) => (this.contentElementRef = el), style: { display: 'none' } }, h("slot", { key: '9cccb06ec12b8dbb92273b96ed84815ef8048a7b', name: "content" })))));
    }
    static get is() { return "swc-popover"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-popover.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-popover.css"]
        };
    }
    static get properties() {
        return {
            "content": {
                "type": "string",
                "attribute": "content",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "* content of the popover which is a string display when the popover appears, default value is empty string"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "showArrow": {
                "type": "boolean",
                "attribute": "show-arrow",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "* showArrow determine if the popover will display arrow pointer or not"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "showContent": {
                "type": "boolean",
                "attribute": "show-content",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showContent determines if the content of the tooltip should be shown"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "Placement",
                    "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
                    "references": {
                        "Placement": {
                            "location": "import",
                            "path": "tippy.js",
                            "id": "../../node_modules/tippy.js/index.d.ts::Placement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "* position tells the placement of the popover in relation to the trigger element"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'top'"
            }
        };
    }
    static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=swc-popover.js.map
