import { useId } from "../../utils/utils";
import { h, Host } from "@stencil/core";
export class SwcRadioInput {
    /**
     * value state
     */
    value;
    /**
     * selectedValue prop
     */
    selectedValue;
    /**
     * disabled state
     */
    disabled = false;
    /**
     * disabled state
     */
    error = false;
    /**
     * checked state
     */
    checked = false;
    /**
     * label attribute
     */
    label;
    /**
     * event emitted when the user clicks on the switch
     */
    changeRadio;
    hostEl;
    radioId = useId().generate('swc-radio-');
    handleRadioChange = (event) => {
        event.preventDefault();
        const emmitedValue = event.target.value;
        this.changeRadio.emit(emmitedValue);
    };
    render() {
        const attrs = Array.from(this.hostEl.attributes).reduce((acc, attribute) => {
            acc[attribute.name] = attribute.value;
            return acc;
        }, {});
        return (h(Host, null, h("span", { class: "swc-radio-wrapper", "data-testid": "sfe-radio-input" }, h("input", { ...attrs, type: "radio", id: this.radioId, value: this.value, checked: this.checked || this.value.toLowerCase() === this.selectedValue.toLowerCase(), disabled: this.disabled, class: {
                'sfe-radio': true,
                'sfe-radio--error': this.error,
            }, onChange: this.handleRadioChange }), this.label && (h("label", { htmlFor: this.radioId, class: `ms-2 ${this.disabled ? 'cursor-not-allowed' : 'cursor-pointer'}` }, this.label)))));
    }
    static get is() { return "swc-radio-input"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-radio-input.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-radio-input.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "value state"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "selectedValue": {
                "type": "string",
                "attribute": "selected-value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "selectedValue prop"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "error": {
                "type": "boolean",
                "attribute": "error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "checked": {
                "type": "boolean",
                "attribute": "checked",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "checked state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "label attribute"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "changeRadio",
                "name": "changeRadio",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event emitted when the user clicks on the switch"
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "hostEl"; }
}
//# sourceMappingURL=swc-radio-input.js.map
