import { Host, h } from "@stencil/core";
export class SwcSkeleton {
    /**
     * determines if the skeleton loader be a circle
     */
    round = false;
    /**
     * size of the skeleton loader
     */
    size = '50px';
    /**
     * height of the skeleton loader
     */
    height = '20px';
    /**
     * width of the skeleton loader
     */
    width = '100%';
    /**
     * border radius of the skeleton loader
     */
    borderRadius = 'var(--sfe-sizing-radius-large, 12px)';
    DEFAULT_PROPS_VALUE = {
        size: '50px',
        height: '20px',
        width: '100%',
        borderRadius: 'var(--sfe-sizing-radius-large, 12px)',
    };
    isValidSize(value) {
        return /^(auto|(\d+(\.\d+)?(px|em|rem|%)))$/.test(value);
    }
    get validatedSize() {
        return this.isValidSize(this.size) ? this.size : this.DEFAULT_PROPS_VALUE.size;
    }
    get validatedWidth() {
        return this.isValidSize(this.width) ? this.width : this.DEFAULT_PROPS_VALUE.width;
    }
    get validatedHeight() {
        return this.isValidSize(this.height) ? this.height : this.DEFAULT_PROPS_VALUE.height;
    }
    get validatedBorderRadius() {
        return this.isValidSize(this.borderRadius)
            ? this.borderRadius
            : this.DEFAULT_PROPS_VALUE.borderRadius;
    }
    get shimmerStyleProps() {
        const width = this.round ? this.validatedSize : this.validatedWidth;
        const height = this.round ? this.validatedSize : this.validatedHeight;
        const borderRadius = this.round ? '50%' : this.validatedBorderRadius;
        return {
            width,
            height,
            borderRadius,
        };
    }
    render() {
        return (h(Host, { key: 'd4c3be97ca75144c5691d5f31558d1b0ab873d02' }, h("div", { key: '73ff393b62aba69fc1dba8ad865ceab78cc1b1fe', class: "skeleton-loader", "data-testid": "sfe-skeleton" }, h("div", { key: 'e10b769559bfedcc3f7503b1e5768b3849b5d0c7', class: "skeleton-item", "aria-hidden": "true", style: { ...this.shimmerStyleProps } }))));
    }
    static get is() { return "swc-skeleton"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-skeleton.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-skeleton.css"]
        };
    }
    static get properties() {
        return {
            "round": {
                "type": "boolean",
                "attribute": "round",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines if the skeleton loader be a circle"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "size of the skeleton loader"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'50px'"
            },
            "height": {
                "type": "string",
                "attribute": "height",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "height of the skeleton loader"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'20px'"
            },
            "width": {
                "type": "string",
                "attribute": "width",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "width of the skeleton loader"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'100%'"
            },
            "borderRadius": {
                "type": "string",
                "attribute": "border-radius",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "border radius of the skeleton loader"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'var(--sfe-sizing-radius-large, 12px)'"
            }
        };
    }
}
//# sourceMappingURL=swc-skeleton.js.map
