import { Host, h } from "@stencil/core";
export class SwcStatusBadge {
    /**
     * The variant of the badge
     */
    variant = 'solid';
    /**
     * The intent of the badge
     */
    intent = 'neutral';
    validateVariant(newValue) {
        const acceptedValues = ['solid', 'outline', 'faded', 'bare'];
        return this.validateComponentProps(acceptedValues, newValue, 'variant');
    }
    validateIntent(newValue) {
        const acceptedValues = ['neutral', 'info', 'positive', 'critical', 'warning'];
        return this.validateComponentProps(acceptedValues, newValue, 'intent');
    }
    validateComponentProps(acceptedValues, newValue, propName) {
        const validProp = acceptedValues.includes(newValue.toLowerCase());
        if (!validProp) {
            shrConsole.safeLog(`Invalid value for ${propName} prop, the accepted values are ${acceptedValues.join(' | ')} `);
        }
        return validProp;
    }
    componentWillLoad() {
        this.validateComponentProps(['solid', 'outline', 'faded', 'bare'], this.variant, 'variant');
        this.validateComponentProps(['neutral', 'info', 'positive', 'critical', 'warning'], this.intent, 'intent');
    }
    render() {
        return (h(Host, { key: 'd1cdf74a1d21bd92c4cd40b5f7963637113b478e' }, h("div", { key: '90d843092266e5b9cc84bf7a9e5b30b2fdced86e', style: { display: 'flex', alignItems: 'center', gap: '4px' }, class: `d-flex align-items-center sfe-status-badge sfe-status-badge-${this.variant}-${this.intent}`, "data-test-id": "sfe-status-badge" }, h("div", { key: 'a9ef46c194601c66fd08cd6cad235d7ead0772cc', class: "sfe-status-badge__dot" }), h("slot", { key: '0d5dc4cb390a901e7e65cabf9bb0e7098890fbf8' }))));
    }
    static get is() { return "swc-status-badge"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-status-badge.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-status-badge.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'solid' | 'outline' | 'faded' | 'bare'",
                    "resolved": "\"bare\" | \"faded\" | \"outline\" | \"solid\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The variant of the badge"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'solid'"
            },
            "intent": {
                "type": "string",
                "attribute": "intent",
                "mutable": false,
                "complexType": {
                    "original": "'neutral' | 'info' | 'positive' | 'critical' | 'warning'",
                    "resolved": "\"critical\" | \"info\" | \"neutral\" | \"positive\" | \"warning\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The intent of the badge"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'neutral'"
            }
        };
    }
    static get watchers() {
        return [{
                "propName": "variant",
                "methodName": "validateVariant"
            }, {
                "propName": "intent",
                "methodName": "validateIntent"
            }];
    }
}
//# sourceMappingURL=swc-status-badge.js.map
