import { h } from "@stencil/core";
import { IconPaths } from "./IconPaths";
import { useId } from "../../utils/utils";
export class SwcSvgIcon {
    iconPaths = IconPaths;
    /**
     * The name of the icon as seen on figma
     */
    name;
    /**
     * The variant of the icon (filled or outline)
     */
    variant = 'outline';
    /**
     * The size of the icon
     */
    size = '24';
    /**
     * The color of the icon
     */
    color = '#000000';
    /**
     * The opacity of the icon
     */
    opacity = '0.9';
    /**
     * The accessible text for the icon.
     * Sets attribute to 'title' since 'title' prop
     * is invalid as title is a reserved word in HTML.
     */
    titleProp;
    titleId = useId().generate('svg-icon');
    render() {
        return (h("svg", { key: '62cac797b6b59d1945d2d5b6ab4bb7d7ea930c6f', xmlns: "http://www.w3.org/2000/svg", width: this.size, height: this.size, viewBox: this.iconPaths[this.name]['viewBox'], fill: "none", role: "img", "aria-labelledby": this.titleProp ? this.titleId : undefined, "aria-hidden": !this.titleProp, "data-testid": "swc-svg-icon" }, h("path", { key: 'f9335817de5b1a9995e1e37a99678a6b16136129', d: this.iconPaths[this.name][this.variant], fill: this.color, "fill-opacity": this.opacity }), this.titleProp && h("title", { key: 'c9a476e96221666047b55b785b71a5ec425218e2', id: this.titleId }, this.titleProp)));
    }
    static get is() { return "swc-svg-icon"; }
    static get encapsulation() { return "scoped"; }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "attribute": "name",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the icon as seen on figma"
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'outline' | 'filled'",
                    "resolved": "\"filled\" | \"outline\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The variant of the icon (filled or outline)"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'outline'"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The size of the icon"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'24'"
            },
            "color": {
                "type": "string",
                "attribute": "color",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The color of the icon"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'#000000'"
            },
            "opacity": {
                "type": "string",
                "attribute": "opacity",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The opacity of the icon"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "'0.9'"
            },
            "titleProp": {
                "type": "string",
                "attribute": "title",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The accessible text for the icon.\nSets attribute to 'title' since 'title' prop\nis invalid as title is a reserved word in HTML."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
}
//# sourceMappingURL=swc-svg-icon.js.map
