import { useId } from "../../utils/utils";
import { h } from "@stencil/core";
export class SwcSwitch {
    /**
     * disabled state
     */
    disabled = false;
    /**
     * checked state
     */
    checked = false;
    /**
     * custom color
     */
    color = '--sfe-color-interaction-brand-solid-subtle';
    /**
     * label attribute
     */
    label = '';
    /**
     * event emitted when the user clicks on the switch
     */
    changeSwitch;
    el;
    checkboxEl;
    handleClick = () => {
        if (!this.disabled) {
            this.checked = !this.checked;
            this.changeSwitch.emit(this.checked);
        }
        if (this.checkboxEl) {
            this.checkboxEl.focus();
        }
    };
    handleKeydown = (event) => {
        if (!this.disabled && (event.code === 'Space' || event.code === 'Enter')) {
            this.handleClick();
        }
    };
    handleChange = (event) => {
        event.stopPropagation();
        this.changeSwitch.emit(event.target.checked);
    };
    get backgroundColor() {
        return this.checked ? `var(${this.color})` : 'var(--sfe-color-interaction-neutral-faded-subtle)';
    }
    render() {
        const id = useId().generate('swc-switch');
        const attrs = Array.from(this.el.attributes).reduce((acc, attr) => {
            acc[attr.name] = attr.value;
            return acc;
        }, {});
        return (h("div", { class: "sfe-switch-parent" }, h("div", { role: "switch", tabIndex: this.disabled ? -1 : 0, class: {
                'sfe-switch': true,
                checked: this.checked,
                disabled: this.disabled,
            }, style: { '--bg-color': this.backgroundColor }, onClick: this.handleClick, onKeyDown: this.handleKeydown }, h("input", { id: attrs.id || id, type: "checkbox", ref: (el) => (this.checkboxEl = el), checked: this.checked, disabled: this.disabled, class: "sfe-switch__checkbox", onChange: this.handleChange })), this.label && (h("swc-label", { for: id, size: "md", disabled: this.disabled, class: "ml-2" }, this.label))));
    }
    static get is() { return "swc-switch"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-switch.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-switch.css"]
        };
    }
    static get properties() {
        return {
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "checked": {
                "type": "boolean",
                "attribute": "checked",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "checked state"
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            },
            "color": {
                "type": "string",
                "attribute": "color",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "custom color"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'--sfe-color-interaction-brand-solid-subtle'"
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "label attribute"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get events() {
        return [{
                "method": "changeSwitch",
                "name": "changeSwitch",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event emitted when the user clicks on the switch"
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=swc-switch.js.map
