import { Host, h } from "@stencil/core";
export class SwcTagsInput {
    /**
     * an array of tags
     */
    value = [];
    /**
     * maximum number of of tags to accept on the input
     */
    max = Infinity;
    /**
     * Placeholder text for the input
     */
    placeholder = 'Add a tag';
    /**
     * disabled state
     */
    disabled = false;
    /**
     * error state
     */
    hasError = false;
    newTag = '';
    isFocused = false;
    focusedTagIndex = null;
    tags = [...(this.value ?? [])];
    /**
     * event fired when the input changes
     */
    handleChange;
    addTag = () => {
        const trimmedTag = this.newTag.trim();
        if (trimmedTag && this.tags.length < this.max) {
            this.tags = [...this.tags, trimmedTag];
            this.newTag = '';
        }
    };
    removeTag = (tagIndex) => {
        if (this.disabled)
            return;
        this.tags = this.tags.filter((_, index) => tagIndex !== index);
        this.focusedTagIndex = null;
    };
    handleBackspace = () => {
        if (!this.newTag) {
            if (this.focusedTagIndex === null && this.tags.length > 0) {
                this.focusedTagIndex = this.tags.length - 1;
            }
            else if (this.focusedTagIndex !== null) {
                this.removeTag(this.focusedTagIndex);
            }
        }
    };
    handleClickTagRemoval = (index) => {
        this.focusedTagIndex = index;
        this.removeTag(this.focusedTagIndex);
    };
    handleFocus = () => {
        this.isFocused = true;
        this.focusedTagIndex = null;
    };
    handleBlur = () => {
        this.isFocused = true;
        this.focusedTagIndex = null;
    };
    handleKeyDown = (ev) => {
        if (ev.key.toLowerCase() === 'backspace') {
            this.handleBackspace();
        }
        if (ev.key.toLowerCase() === 'enter') {
            ev.preventDefault();
            this.addTag();
        }
    };
    handleInputChange = (event) => {
        const targettedEl = event.target;
        const trimmedVal = targettedEl.value.trim();
        this.newTag = trimmedVal;
    };
    valueChangeHandler(newValue) {
        if (Array.isArray(newValue)) {
            this.tags = [...(newValue ?? [])];
        }
    }
    tagsChangeHandler(newValue) {
        this.handleChange.emit(newValue);
    }
    componentWillLoad() {
        if (Array.isArray(this.value)) {
            this.tags = [...(this.value ?? [])];
        }
    }
    render() {
        return (h(Host, { key: '3307ccad703d8f3116bbae74844a44af97d7353a' }, h("div", { key: '165911f688abbbb2ecf4bf7effbd84ed3e6e7ee0', class: `sfe-tags-input 
            ${this.hasError ? 'has-error' : ''} 
            ${this.disabled} 
            ${this.isFocused ? 'focused' : ''}`, "data-testid": "sfe-tags-input" }, h("div", { key: '601737919279ec8973e391c6fd98894aa4c711c9', class: "tags-wrapper" }, this.tags.map((tag, index) => (h("swc-tag", { key: index, instanceId: index, dismissible: !this.disabled, class: this.focusedTagIndex === index ? 'focused' : '', "on-dismiss": () => this.handleClickTagRemoval(index) }, tag))), h("input", { key: '17c0eb0f8ad9a3aa4f3bdbc51c9c9e105994b5b1', type: "text", placeholder: this.placeholder, disabled: this.disabled, class: "tag-input", value: this.newTag, onInput: this.handleInputChange, onBlur: this.handleBlur, onFocus: this.handleFocus, onKeyDown: this.handleKeyDown })))));
    }
    static get is() { return "swc-tags-input"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-tagsInput.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-tagsInput.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "unknown",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "an array of tags"
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "max": {
                "type": "number",
                "attribute": "max",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "maximum number of of tags to accept on the input"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "Infinity"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Placeholder text for the input"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Add a tag'"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled state"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "hasError": {
                "type": "boolean",
                "attribute": "has-error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "error state"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "newTag": {},
            "isFocused": {},
            "focusedTagIndex": {},
            "tags": {}
        };
    }
    static get events() {
        return [{
                "method": "handleChange",
                "name": "handleChange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "event fired when the input changes"
                },
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "valueChangeHandler"
            }, {
                "propName": "tags",
                "methodName": "tagsChangeHandler"
            }];
    }
}
//# sourceMappingURL=swc-tagsInput.js.map
