import { Host, h } from "@stencil/core";
export class SwcTextarea {
    /**
     * variant type for the textarea component
     */
    variant = 'outline';
    /**
     * hasError prop for either error or not
     */
    hasError = false;
    /**
     * disabled text field for the component or not
     */
    disabled = false;
    /**
     * for the class declaration
     */
    containerClass = '';
    /**
     * value of the textarea field
     */
    value;
    /**
     * handleChange function that manages the textArea value
     */
    handleChange;
    handleTextInput = (event) => {
        const input = event.target;
        this.handleChange(input.value);
    };
    get className() {
        let inputedStyle = '';
        if (this.disabled || this.hasError) {
            inputedStyle = this.disabled ? `disabled ${this.variant}` : 'textarea_error';
        }
        else {
            inputedStyle = this.variant;
        }
        return inputedStyle;
    }
    render() {
        return (h(Host, { key: 'e0187114c83da7e4023ea5d5ef990a46d27afde1' }, h("div", { key: '69a3b2f90bf4c75dec8c3ba9f10d12784652896b', style: { display: 'flex', alignItems: 'center' }, class: `textarea_wrapper ${this.className} ${this.containerClass}`, "data-testid": "sfe-textarea" }, h("textarea", { key: 'ad7c086a54302e02a16bd4a3a05012d3c36fe745', value: this.value, class: 'w-100', disabled: this.disabled, onInput: this.handleTextInput }))));
    }
    static get is() { return "swc-textarea"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-textarea.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-textarea.css"]
        };
    }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'outline' | 'filled'",
                    "resolved": "\"filled\" | \"outline\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant type for the textarea component"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'outline'"
            },
            "hasError": {
                "type": "boolean",
                "attribute": "has-error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "hasError prop for either error or not"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "disabled text field for the component or not"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "containerClass": {
                "type": "string",
                "attribute": "container-class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "for the class declaration"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "value of the textarea field"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "handleChange": {
                "type": "unknown",
                "attribute": "handle-change",
                "mutable": false,
                "complexType": {
                    "original": "(value: string) => void",
                    "resolved": "(value: string) => void",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "handleChange function that manages the textArea value"
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=swc-textarea.js.map
