import { h } from "@stencil/core";
import { StyleConfig } from "./types";
export class SwcToast {
    /**
     * toast type
     */
    type = 'success';
    /**
     * toast position
     */
    position = 'top-center';
    /**
     * title of the toast
     */
    _title;
    /**
     * message of the toast
     */
    message;
    /**
     * duration of the toast in milliseconds
     */
    timeout = 5000;
    /**
     * determines whether the title should be displayed
     */
    showTitle = true;
    /**
     * determines whether the toast can be dismissed
     */
    dismissible = true;
    /**
     * determines whether the toast is visible
     */
    isVisible = false;
    /**
     * timeout id from setTimeout function
     */
    timeoutId;
    transitionDuration = 300;
    get resolvedStyle() {
        const config = StyleConfig[this.type];
        return {
            config,
            styles: {
                'background-color': this.showTitle ? '#FFF' : config.subtleBgColor,
                'inline-size': this.showTitle ? '273px' : '332px',
                'padding-inline': this.showTitle ? '14px' : '12px',
                'border-left-width': this.showTitle ? '4px' : '2px',
            },
        };
    }
    /**
     * show toast
     */
    // eslint-disable-next-line
    async showToast() {
        this.isVisible = true;
        this.timeoutId = setTimeout(() => {
            this.hideToast();
        }, this.timeout);
    }
    /**
     * hide toast
     */
    hideToast() {
        const swcToast = document.querySelector('swc-toast');
        if (swcToast) {
            swcToast.isVisible = false;
            clearTimeout(swcToast.timeoutId);
            setTimeout(() => {
                swcToast.reset();
                swcToast.remove();
            }, this.transitionDuration);
        }
    }
    /**
     * resets the toast state
     */
    // eslint-disable-next-line @stencil-community/async-methods
    async reset() {
        this.type = 'success';
        this.position = 'top-center';
        this._title = '';
        this.message = '';
        this.timeout = 5000;
        this.showTitle = true;
        this.isVisible = false;
        this.dismissible = true;
    }
    render() {
        return (h("div", { key: 'b19d10eb0bb0b62d5b2208bed9d474024980bb9f', role: "alert", "aria-live": "assertive", "aria-labelledby": "shr-toast-title", "aria-describedby": "shr-toast-message", "data-testid": "sfe-toast", "data-state": this.isVisible ? 'showing' : 'hidden', class: `shr-toast ${this.position}`, style: {
                '--transition-duration': `${this.transitionDuration}ms`,
                '--title-color': this.resolvedStyle.config.titleColor,
                '--message-color': this.showTitle
                    ? 'var(--sfe-color-text-default-primary, rgba(0, 0, 0, 0.80))'
                    : 'var(--sfe-color-text-default-primary, rgba(0, 0, 0, 0.95))',
                '--border-left-color': this.resolvedStyle.config.borderLeftColor,
                ...this.resolvedStyle.styles,
            } }, this.showTitle && (h("div", { key: '80cca50c441716d2f241754bd5a5c45f51e29c1c', class: "shr-toast--with-title" }, h("div", { key: '3e4cfb5c7d372b070f03e36f9f6dda0ee5fd8ca0', class: "d-flex justify-content-between align-items-center mb-1" }, h("div", { key: '2087681865434249105d3bf4c8b5cff87b545726', class: "d-flex align-items-center mr-3" }, h("swc-svg-icon", { key: 'e35329888efa10e3d2792a11803d9ad505520ae2', name: this.resolvedStyle.config.icon, variant: "filled", color: this.resolvedStyle.config.iconColor, size: "16" }), h("span", { key: 'fb871abe234371b4aa1b7357e192f032ddcc19fa', id: "shr-toast-title", class: "shr-toast__title ml-1" }, ' ', this._title)), this.dismissible && (h("swc-icon-button", { key: '23155e72dabbb180d3e993ec17cda4363aca4b79', intent: "neutral", variant: "bare", round: true, "aria-label": "Close toast", onClick: this.hideToast }, h("swc-svg-icon", { key: 'c5a2c79c9c3255dee5f06db3048d8416a61d8f17', name: "Dismiss", size: "16" })))), h("div", { key: 'fa0f25e92928efe15abe65254cea7e9367a1022b', id: "shr-toast-message", class: "shr-toast__message fs-12" }, ' ', this.message))), !this.showTitle && (h("div", { key: '98175e94d4cd2bd9e83961885b59d92f2c8e4932', class: "shr-toast--without-title" }, h("div", { key: 'c832a674ee58d473465729bb84211906e64aa22c', class: "d-flex justify-content-between align-items-center" }, h("div", { key: 'f6a9dd5b8017beae283f2cb0c9e122687a1eb90c', class: "d-flex align-items-center mr-3" }, h("swc-svg-icon", { key: '63939cf6144bae6b11dc0e5bb1b2093d22cc35a9', name: this.resolvedStyle.config.icon, variant: "outline", color: this.resolvedStyle.config.iconColor, size: "16" }), h("p", { key: '41e2398d6b4d6bb4b43eda105580659d18887787', id: "shr-toast-message", class: "m-0 shr-toast__message fs-14 ml-1" }, this.message)), this.dismissible && (h("swc-icon-button", { key: '9257e4e8c49ed11b15b09a48b08388a4b4a4a9bc', intent: "neutral", variant: "bare", round: true, "aria-label": "Close toast", onClick: this.hideToast }, h("swc-svg-icon", { key: 'cc5275dc2309e9ec9c9ae81b6f5998baa94f2c52', name: "Dismiss", size: "16" }))))))));
    }
    static get is() { return "swc-toast"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-toast.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-toast.css"]
        };
    }
    static get properties() {
        return {
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": true,
                "complexType": {
                    "original": "ToastTypes",
                    "resolved": "\"error\" | \"info\" | \"success\" | \"warning\"",
                    "references": {
                        "ToastTypes": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/swc-toast/types.ts::ToastTypes"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "toast type"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'success'"
            },
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": true,
                "complexType": {
                    "original": "ToastPositions",
                    "resolved": "\"bottom-center\" | \"bottom-left\" | \"bottom-right\" | \"top-center\" | \"top-left\" | \"top-right\"",
                    "references": {
                        "ToastPositions": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/swc-toast/types.ts::ToastPositions"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "toast position"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'top-center'"
            },
            "_title": {
                "type": "string",
                "attribute": "_title",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "title of the toast"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "message": {
                "type": "string",
                "attribute": "message",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "message of the toast"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "timeout": {
                "type": "number",
                "attribute": "timeout",
                "mutable": true,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "duration of the toast in milliseconds"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "5000"
            },
            "showTitle": {
                "type": "boolean",
                "attribute": "show-title",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the title should be displayed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "dismissible": {
                "type": "boolean",
                "attribute": "dismissible",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the toast can be dismissed"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "isVisible": {
                "type": "boolean",
                "attribute": "is-visible",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "determines whether the toast is visible"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "timeoutId": {
                "type": "unknown",
                "attribute": "timeout-id",
                "mutable": true,
                "complexType": {
                    "original": "ReturnType<typeof setTimeout>",
                    "resolved": "Timeout",
                    "references": {
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "timeout id from setTimeout function"
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get methods() {
        return {
            "showToast": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "show toast",
                    "tags": []
                }
            },
            "reset": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "resets the toast state",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=swc-toast.js.map
