import { Host, h } from "@stencil/core";
import { useId, hasNamedSlot } from "../../utils/utils";
import tippy from "tippy.js";
import { hideOnEsc } from "../plugin";
export class SwcTooltip {
    /**
     * content of the tooltip which is a string display when the tooltip appears, default value is empty string
     */
    content = '';
    /**
     * showArrow determine if the tooltip will display arrow pointer or not
     */
    showArrow = true;
    /**
     * showContent determines if the content of the tooltip should be shown
     */
    showContent = true;
    /**
     * interactive is prop set for the initialization of the tippy.js instance object, it virtually makes the tooltip interactive
     */
    interactive = false;
    /**
     * variant determines the display type and color of the tooltip, either light or brand
     */
    variant = 'light';
    /**
     * position tells the placement of the tooltip in relation to the trigger element
     */
    position = 'top';
    triggerId = `sfe-tooltip-trigger-${useId().generate()}`;
    tooltipId = '';
    // @State() slotContent: string
    hostEl;
    // private contentElementRef?: HTMLDivElement
    initTooltip = () => {
        tippy(this.hostEl.querySelector(`#${this.triggerId}`), {
            theme: this.showContent ? this.variant : 'hide',
            content: this.computedTooltipContent,
            animation: 'shift-toward',
            placement: this.position,
            allowHTML: true,
            trigger: 'mouseenter focusin',
            arrow: this.showArrow,
            interactive: this.interactive,
            role: 'tooltip',
            maxWidth: 'none',
            plugins: [hideOnEsc],
            zIndex: 999999,
        });
    };
    get computedTooltipContent() {
        const hasContentSlot = hasNamedSlot(this.hostEl, 'content');
        if (hasContentSlot) {
            const targettedEl = this.hostEl.querySelector(`[slot="content"]`);
            return targettedEl?.innerHTML;
        }
        else {
            return this.content;
        }
    }
    componentDidLoad() {
        this.initTooltip();
    }
    render() {
        return (h(Host, { key: '65f7912072ba25012d6710846a14eaf6e25c189c' }, h("div", { key: '311bb28a410ca10fe3192d26d564454ece4c67ca', class: "sfe-tooltip", "data-testid": "sfe-tooltip" }, h("div", { key: '2f4808c6d9391e49c71bca02eeaf1b5e7e41eed1' }, h("div", { key: '395bee07915c35aea9dd5754c34243c06be83943', id: this.triggerId, "aria-describedby": this.triggerId, style: { width: 'fit-content' } }, h("slot", { key: '39dd2894545f5ba89053d5fdf413e6cd3a397ceb', name: "trigger" }))), h("div", { key: '89368c9674ce5e2bab08c8d73f714301c586757a', style: { display: 'none' } }, h("slot", { key: 'd537013b98ec320fc2f8681dd936b6577ef1e39f', name: "content" })))));
    }
    static get is() { return "swc-tooltip"; }
    static get originalStyleUrls() {
        return {
            "$": ["swc-tooltip.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["swc-tooltip.css"]
        };
    }
    static get properties() {
        return {
            "content": {
                "type": "string",
                "attribute": "content",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "content of the tooltip which is a string display when the tooltip appears, default value is empty string"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "showArrow": {
                "type": "boolean",
                "attribute": "show-arrow",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showArrow determine if the tooltip will display arrow pointer or not"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "showContent": {
                "type": "boolean",
                "attribute": "show-content",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "showContent determines if the content of the tooltip should be shown"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "interactive": {
                "type": "boolean",
                "attribute": "interactive",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "interactive is prop set for the initialization of the tippy.js instance object, it virtually makes the tooltip interactive"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "'light' | 'brand'",
                    "resolved": "\"brand\" | \"light\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "variant determines the display type and color of the tooltip, either light or brand"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'light'"
            },
            "position": {
                "type": "string",
                "attribute": "position",
                "mutable": false,
                "complexType": {
                    "original": "Placement",
                    "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
                    "references": {
                        "Placement": {
                            "location": "import",
                            "path": "tippy.js",
                            "id": "../../node_modules/tippy.js/index.d.ts::Placement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "position tells the placement of the tooltip in relation to the trigger element"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'top'"
            }
        };
    }
    static get states() {
        return {
            "tooltipId": {}
        };
    }
    static get elementRef() { return "hostEl"; }
}
//# sourceMappingURL=swc-tooltip.js.map
