export const format = (first, middle, last) => {
    let name = first != undefined ? first + ' ' : '';
    name += middle != undefined ? middle + ' ' : '';
    name += last != undefined ? last + ' ' : '';
    return name.trim();
    //return ((first + ' ' || '') + (middle + ' ' || '') + (last + ' ' || '')).trim()
};
/**
 * Use this function only when shadow is set to true in a component @shrfe/styles is needed
 *
 * @param tag The component's tag used as html element
 */
export const loadShrStyles = (tag) => {
    const link = document.createElement('link');
    link.type = 'text/css';
    link.rel = 'stylesheet preload';
    link.href = 'https://cdn.seamlesshr.com/css/shrfe-styles.css';
    link.as = 'style';
    const el = document.querySelector(tag)?.shadowRoot;
    el?.prepend(link);
};
/**
 * Generates a unique ID.
 * Useful for generating unique ids when dealing with accessibility
 * requirements such as aria-labelledby and aria-describedby.
 *
 * Inspired by Radix-vue https://github.com/radix-vue/radix-vue/blob/main/packages/radix-vue/src/shared/useId.ts
 *
 */
let idCounter = 0;
export const useId = () => {
    const increment = () => {
        return `${++idCounter}`;
    };
    /*
     * @param {string} [prefix=''] - Optional prefix for the generated ID.
     * @returns {string} A unique ID string.
     */
    const generate = (prefix = '') => {
        const uniqueId = increment();
        return prefix ? `${prefix}-${uniqueId}` : uniqueId;
    };
    return { generate };
};
export const hasNamedSlot = (el, slotName) => {
    return !!el.querySelector(`[slot="${slotName}"]`);
};
/**
 * Checks if the component has content in its default slot.
 * @param el - The host element (usually `this` in a Stencil component).
 * @returns `true` if content exists in the default slot.
 */
export const hasDefaultSlot = (el) => {
    // Get the default slot (unnamed slot)
    const slot = el.querySelector('slot:not([name])');
    // Check if the slot exists and has assigned nodes (excluding whitespace text nodes)
    return slot
        ? slot
            .assignedNodes({ flatten: true })
            .filter((node) => node.nodeType === Node.ELEMENT_NODE ||
            (node.nodeType === Node.TEXT_NODE && node.textContent?.trim())).length > 0
        : false;
};
/**
 * Detects clicks or touches outside a specified element and invokes a callback.
 * @param element - The element to monitor for outside interactions.
 * @param callback - The function to call when an outside interaction is detected.
 * @returns A cleanup function to remove the event listeners.
 */
export function onClickOutside(element, callback) {
    const handleOutsideInteraction = (event) => {
        if (!element.contains(event.target)) {
            callback(event);
        }
    };
    // Listen for both mouse and touch events
    document.addEventListener('click', handleOutsideInteraction, true);
    document.addEventListener('touchstart', handleOutsideInteraction, true);
    // Return a cleanup function
    return () => {
        document.removeEventListener('click', handleOutsideInteraction, true);
        document.removeEventListener('touchstart', handleOutsideInteraction, true);
    };
}
//# sourceMappingURL=utils.js.map
