import { r as registerInstance, c as createEvent, h, H as Host } from './index-DnIVQjp-.js';

const swcTagsInputCss = ".sc-swc-tags-input-h .sfe-tags-input.sc-swc-tags-input{display:flex;flex-wrap:wrap;align-items:flex-start;border-radius:var(--sfe-sizing-radius-small, 4px);border:1px solid var(--sfe-form-input-color-border-default, #9ea8b3);padding:10px;transition:border-color 0.2s}.sc-swc-tags-input-h .sfe-tags-input.disabled.sc-swc-tags-input{opacity:0.4;pointer-events:none}.sc-swc-tags-input-h .sfe-tags-input.sc-swc-tags-input:hover,.sc-swc-tags-input-h .sfe-tags-input.sc-swc-tags-input .focused.sc-swc-tags-input{border:1px solid var(--sfe-form-input-color-border-hover, #4080e0)}.sc-swc-tags-input-h .sfe-tags-input.has-error.sc-swc-tags-input{border:1px solid var(--sfe-form-input-color-border-error, #a22827)}.sc-swc-tags-input-h .tags-wrapper.sc-swc-tags-input{display:flex;flex-wrap:wrap;gap:5px;width:100%}.sc-swc-tags-input-h input[type=text].sc-swc-tags-input{min-width:100px;flex-grow:1;outline:none;border:none;background:transparent}.sc-swc-tags-input-h input[type=text].sc-swc-tags-input:disabled{cursor:not-allowed;background:transparent;opacity:0.4}";

const SwcTagsInput = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.handleChange = createEvent(this, "handleChange");
    }
    /**
     * an array of tags
     */
    value = [];
    /**
     * maximum number of of tags to accept on the input
     */
    max = Infinity;
    /**
     * Placeholder text for the input
     */
    placeholder = 'Add a tag';
    /**
     * disabled state
     */
    disabled = false;
    /**
     * error state
     */
    hasError = false;
    newTag = '';
    isFocused = false;
    focusedTagIndex = null;
    tags = [...(this.value ?? [])];
    /**
     * event fired when the input changes
     */
    handleChange;
    addTag = () => {
        const trimmedTag = this.newTag.trim();
        if (trimmedTag && this.tags.length < this.max) {
            this.tags = [...this.tags, trimmedTag];
            this.newTag = '';
        }
    };
    removeTag = (tagIndex) => {
        if (this.disabled)
            return;
        this.tags = this.tags.filter((_, index) => tagIndex !== index);
        this.focusedTagIndex = null;
    };
    handleBackspace = () => {
        if (!this.newTag) {
            if (this.focusedTagIndex === null && this.tags.length > 0) {
                this.focusedTagIndex = this.tags.length - 1;
            }
            else if (this.focusedTagIndex !== null) {
                this.removeTag(this.focusedTagIndex);
            }
        }
    };
    handleClickTagRemoval = (index) => {
        this.focusedTagIndex = index;
        this.removeTag(this.focusedTagIndex);
    };
    handleFocus = () => {
        this.isFocused = true;
        this.focusedTagIndex = null;
    };
    handleBlur = () => {
        this.isFocused = true;
        this.focusedTagIndex = null;
    };
    handleKeyDown = (ev) => {
        if (ev.key.toLowerCase() === 'backspace') {
            this.handleBackspace();
        }
        if (ev.key.toLowerCase() === 'enter') {
            ev.preventDefault();
            this.addTag();
        }
    };
    handleInputChange = (event) => {
        const targettedEl = event.target;
        const trimmedVal = targettedEl.value.trim();
        this.newTag = trimmedVal;
    };
    valueChangeHandler(newValue) {
        if (Array.isArray(newValue)) {
            this.tags = [...(newValue ?? [])];
        }
    }
    tagsChangeHandler(newValue) {
        this.handleChange.emit(newValue);
    }
    componentWillLoad() {
        if (Array.isArray(this.value)) {
            this.tags = [...(this.value ?? [])];
        }
    }
    render() {
        return (h(Host, { key: '3307ccad703d8f3116bbae74844a44af97d7353a' }, h("div", { key: '165911f688abbbb2ecf4bf7effbd84ed3e6e7ee0', class: `sfe-tags-input 
            ${this.hasError ? 'has-error' : ''} 
            ${this.disabled} 
            ${this.isFocused ? 'focused' : ''}`, "data-testid": "sfe-tags-input" }, h("div", { key: '601737919279ec8973e391c6fd98894aa4c711c9', class: "tags-wrapper" }, this.tags.map((tag, index) => (h("swc-tag", { key: index, instanceId: index, dismissible: !this.disabled, class: this.focusedTagIndex === index ? 'focused' : '', "on-dismiss": () => this.handleClickTagRemoval(index) }, tag))), h("input", { key: '17c0eb0f8ad9a3aa4f3bdbc51c9c9e105994b5b1', type: "text", placeholder: this.placeholder, disabled: this.disabled, class: "tag-input", value: this.newTag, onInput: this.handleInputChange, onBlur: this.handleBlur, onFocus: this.handleFocus, onKeyDown: this.handleKeyDown })))));
    }
    static get watchers() { return {
        "value": ["valueChangeHandler"],
        "tags": ["tagsChangeHandler"]
    }; }
};
SwcTagsInput.style = swcTagsInputCss;

export { SwcTagsInput as swc_tags_input };
//# sourceMappingURL=swc-tags-input.entry.js.map

//# sourceMappingURL=swc-tags-input.entry.js.map